/*
 *  swimactech.h
 *  swimac
 *
 *  Created by Jerry Pickering on 1/18/08.
 *  Copyright 2008 Sierra Wireless, Inc. All rights reserved.
 *
 */

#ifdef __cplusplus
extern "C"	{
#endif

#import "swimacrcodes.h"
#import "swimacdatatypes.h"
#import "swimacstructs.h"

//**********************************************************************************
//		These are part of the tech. or engineering methods.
//			but because of the need to set some static variables
//			that are in the swimacapi.c file.. that is where they
//			reside...
//
//	SwiRtnReset - Resets the modem to factory
//
//	SwiResetModem - Resets the modem
//**********************************************************************************




//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetTechSID - SWI_TYPE_Notify variant
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE	SwiGetTechSID(SWI_U16 *systemID, SWI_U32 timeout);
//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetTechNID - SWI_TYPE_Notify variant
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE	SwiGetTechNID(SWI_U16 *networkID, SWI_U32 timeout);
//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetTechFrame - SWI_TYPE_Notify variant
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE	SwiGetTechFrame(SWI_U32* totalFrames, SWI_U32* badFrames, SWI_U32 timeout);
//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetTechBandClass - SWI_TYPE_Notify variant
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE	SwiGetTechBandClass(SWI_TYPE_TechBandClass *bandClass, SWI_U32 timeout);
//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetTechFinger - SWI_TYPE_Notify variant
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE	SwiGetTechFinger(SWI_STRUCT_TechFinger* pTechFing, SWI_U32 timeout);
//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetTechBSInfo - Get geographical coordinates of base station
//
// Purpose:     This function reports the geographical coordindates of the
//              base station the modem is currently using
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//              longitude[OUT]          Longitude reported in geographical
//                                      seconds (see Notes)
//              latitude[OUT]           Latitude reported in geographical
//                                      seconds (see Notes)
//
// Return:      No special handling.
//              See SwiRcodes.h    
//
// Notes:       The geographical coordinates may not be necessilary provided by
//              all base stations.
//
//              Below is an example of how to convert the longitude geographical 
//              seconds into degrees/minutes/seconds.  Latitude is computed 
//              identically.
//              
//              int iMin, iSec, iDeg, iGeoSecs;
//
//              iGeoSecs = iLongitude / 4;
//              iDeg = iGeoSecs / 3600;
//              iMin = (iGeoSecs - iDeg * 3600) / 60;
//              iSec = iGeoSecs - iDeg * 3600 - iMin * 60;
//
//              GeoDeg = iDeg;
//              GeoMin = abs(iMin);
//              GeoSec = abs(iSec);
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetTechBSInfo(SWI_S32 *longitude, SWI_S32 *latitude, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetTechActiveSet - SWI_TYPE_Notify variant
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE	SwiGetTechActiveSet(SWI_STRUCT_TechActiveSet* pTechActSet, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetTechPacketZone - Get Packet Zone ID
//
// Purpose:     This function gets the Packet Zone ID value. 
//
// Parameters:  packetZoneID[IN]        The Packet Zone ID setting
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       None.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetTechPacketZone(SWI_U16 *packetZoneID, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetAKey - SWI_TYPE_Notify variant
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE	SwiSetAKey(char *szAKey, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetERI
//
// Purpose:     Write the ERI data to the modem. Before calling this API, make sure
//				that the modem is SPC (or MSL) unlocked. After calling this API, 
//              whether the operation is successfull or not, should call SwiResetModem
//
// Parameters:  
//              pERIBuffer[IN]		pointer to the entire ERI data buffer
//				nERIBufLen[IN]		size of the ERI data
//              timeout[IN]         Function timeout in milliseconds
//
// Return:      No special handling.
//
// Notes:       None.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE	SwiSetERI(SWI_U8* pBuffer, SWI_U16 nBufLen, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetECIO - SWI_TYPE_Notify variant
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE	SwiGetECIO(SWI_U16* pEcio, SWI_U32 timeout);
//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetTransmitPower - SWI_TYPE_Notify variant
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE	SwiGetTransmitPower(SWI_U16* TxPower, SWI_U32 timeout);
//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetReceivePower - SWI_TYPE_Notify variant
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE	SwiGetReceivePower(SWI_U16* RxPower, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetTemperature - to retrieve the modem's temperature information
//
// Purpose:     This function reports the temperature of the radio within the modem
//
//              A request is sent to the modem.  The modem's response contains the
//              modem's temperature.
//
//              The caller must specify the amount of time to wait for the modem
//              to respond to the request.    
//			
// Parameters:
//
//			    iTemperature[OUT]:	temperature in degrees C
//
//			    timeout[IN]:		response timeout value in milliseconds
//
// Return:	    SWI_RCODE_OK - the request has been received by the modem
//			    SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			    See SWI_RCODE for other error return codes
//
// Notes:	    The modem firmware monitors the radio temperature to protect electronics 
//			    and prevent drift from specification. Consult the product specification
//			    for the specific type of unit you are using to determine the way the 
//			    modem handles high temperatures.
//
//			    Monitoring the temperature is not provided in a notification.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetTemperature(SWI_S32 *iTemperature, SWI_U32 timeout);


//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetCurrentBaseStation - Get base station protocol
//
// Purpose:     This function retrieves the protocol revision
//              (service type) of the base station currently
//              serving the modem.
//
// Parameters:  P_PRV[OUT]              The destination in which the base
//                                      station protocol revision is
//                                      returned:
//                                      1 = JSTD-008 (PCS Japan)
//                                      2 = IS-95
//                                      3 = IS-95A (Cellular)
//                                      4 = IS-95B minimum req.
//                                      5 = IS-95B full requirements
//                                      6 = CDMA2000 Revision 0
//                                      7 = CDMA2000 Revision 1
//                                      Values of 6 or above indicate
//                                      1xRTT coverage. Values below 6
//                                      indicate IS-95 coverage.
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       This command is used to determine if making
//              1xRTT calls is possible.
//
//              Protocol revision 1 is not supported.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetCurrentBaseStation(SWI_U16 *P_PRV, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetRssiEcio - Get RSSI and EcIo for CDMA and EVDO
//
// Purpose:     This function gets the current RSSI and EcIo values for Signal 
//              Stregth reporting.
//
// Parameters:  stRssiEcio[OUT]	  Struct with RSSI and EcIo values.
//              
// Return:      SWI_RCODE_OK            The function executed normally. 
//              SWI_RCODE_FAILED        The operation failed in the modem. 
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  
//
// Notes:       See SwiStructs.h for SWI_STRUCT_Rssi_Ecio definition.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetRssiEcio(SWI_STRUCT_Rssi_Ecio *stRssiEcio, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetChannelNumber - to get the active channel number.
//
// Purpose:	This function returns the current channel number.
//
//			A request is sent to the modem.  The modem's response contains the
//			current channel number.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			nChannelNumber[OUT]:	channel number
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetChannelNumber(SWI_U32 *nChannelNumber, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetPRL
//
// Purpose:     Upload the PRL binary data to the modem. If this API returns error
//				then call it one more time with the same parameters. Before calling this
//				API, make sure that the modem is SPC (or MSL) unlocked. After calling this
//				API, whether the operation is successfull or not, should call SwiResetModem
//
// Parameters:  NamIndex[IN]			NAM index
//              PRLBuffer[IN]			pointer to the entire binary data of PRL to upload
//				nPRLBufLen[IN]			size of the binary data
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       None.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetPRL(const SWI_U16 NamIndex, SWI_U8 *PRLBuffer, SWI_U16 nPRLBufLen, SWI_U32 timeout);


//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetPRLEx
//
// Purpose:     Same as SwiSetPRL, however does not require the user to unlock the modem
//				first.
//
// Parameters:  NamIndex[IN]			NAM index
//              PRLBuffer[IN]			pointer to the entire binary data of PRL to upload
//				nPRLBufLen[IN]			size of the binary data
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       See SwiSetPRL
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetPRLEx(const SWI_U16 NamIndex, SWI_U8 *PRLBuffer, SWI_U16 nPRLBufLen, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name: SwiGetTechHdrMacIndex 
//
// Purpose: Get the device HDR MAC index value
//
// Parameters:  pTechHdrMacIndex[OUT]          Mac Index. (see SWI_STRUCT_Tech_Hdr_Mac_Index)
//              timeout[IN]                    Api timeout
//
// Return:      See SwiRcodes.h
//              
// Notes:   
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetTechHdrMacIndex(SWI_STRUCT_Tech_Hdr_Mac_Index *pTechHdrMacIndex, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetTechDominantPilots 
//
// Purpose:     Returns dominant pilot for 1x and dominant pilot for EVDO if
//              respective service is acquired.  Otherwise, it shall return 0 to
//              indicate that pilot information is not available.
//
// Parameters:  oneXDominantPilot[OUT]     pointer to uint16 size memory to hold
//                                         1x dominant pilot
//              evdoDominantPilot[OUT]     pointer to uint16 size memory to hold
//                                         evdo dominant pilot
//              timeout[IN]                API timeout
//
// Return:      See SwiRcodes.h
//
// Notes:
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetTechDominantPilots( SWI_U16 * const oneXDominantPilot, SWI_U16 * const evdoDominantPilot, SWI_U32 timeout );

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetTechPacketCallControlState 
//
// Purpose:     Returns the last call control state.
//
// Parameters:  callState[OUT]  pointer to SWI_ENUM_Tech_Packet_Call_Control_State
//                              size memory to hold call control state
//              timeout[IN]     API timeout
//
// Return:      See SwiRcodes.h
//
// Notes:       Packet call control state (uint16)
//                  Enum name                  Value   Description
//                  CALL_STATE_NO_SERVICE        0     No service or Idle
//                  CALL_STATE_CONNECTING        1     Connecting
//                  CALL_STATE_AUTHENTICATING    2     Authenticating
//                  CALL_STATE_CONNECTED_ACTIVE  3     Connected Active
//                  CALL_STATE_CONNECTED_DORMANT 4     Connected Dormant
//                  CALL_STATE_DISCONNECTING     5     Disconnecting
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetTechPacketCallControlState( SWI_STRUCT_Tech_Packet_Call_Control_State * const callState, SWI_U32 timeout );

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetTech1xPilotSet 
//
// Purpose:     Return requested pilot set information (channel, PN offset and
//              strength) for 1x service if acquired. Otherwise, it will return all
//              0s.  Only pilots with energy are reported.
//
//              Pilot strength (Ec/Io) reading is a hexadecimal value. To convert
//              this value in terms of dBm, a constant of 0.5 must be multiplied
//              to this value.
//
// Parameters:  requestedPilotSet[IN]  Requested pilot set (see table, below)
//              pilotSet[OUT]          Pointer to SWI_STRUCT_Pilot_Set size memory
//                                     to hold requested pilot set information.
//              timeout[IN]            API timeout
//
// Return:      See SwiRcodes.h
//
// Notes:       Pilot sets (uint16)
//                  Enum name              Value      Pilot set
//                  PILOT_SET_ACTIVE       0x0000     Active Set
//                  PILOT_SET_NEIGHBOR     0x0001     Neighbor Set
//                  PILOT_SET_CANDIDATE    0x0002     Candidate Set
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetTech1xPilotSet( SWI_ENUM_Requested_Pilot_Set const requestedPilotSet, SWI_STRUCT_Pilot_Set * const pilotSet, SWI_U32 timeout );

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetTechHdrPilotSet 
//
// Purpose:     Return requested pilot set information (channel, PN offset and
//              strength) for EVDO service if acquired. Otherwise, it will return all
//              0s.  Only pilots with energy are reported.
//
//              Pilot strength (Ec/Io) reading is a hexadecimal value. To convert
//              this value in terms of dBm, a constant of 0.5 must be multiplied
//              to this value.
//
// Parameters:  requestedPilotSet[IN]  Requested pilot set (see table, below)
//              pilotSet[OUT]          Pointer to SWI_STRUCT_Pilot_Set size memory
//                                     to hold requested pilot set information.
//              timeout[IN]            API timeout
//
// Return:      See SwiRcodes.h
//
// Notes:       Pilot sets (uint16)
//                  Enum name              Value      Pilot set
//                  PILOT_SET_ACTIVE       0x0000     Active Set
//                  PILOT_SET_NEIGHBOR     0x0001     Neighbor Set
//                  PILOT_SET_CANDIDATE    0x0002     Candidate Set
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetTechHdrPilotSet( SWI_ENUM_Requested_Pilot_Set const requestedPilotSet, SWI_STRUCT_Pilot_Set * const pilotSet, SWI_U32 timeout );

//**********************************************************************************
//	SwiGetTechData
//		This call returns all the Tech data in one structure
//		the primary use is to check all the "GET" calls for
//		tech
//**********************************************************************************
typedef struct
{
	SWI_RCODE						_ret[16];
	
	SWI_U16							_systemID;
	SWI_U16							_networkID;
	SWI_U32							_totalFrames;
	SWI_U32							_badFrames;
	SWI_TYPE_TechBandClass			_bandClass;
	SWI_STRUCT_TechFinger			_pTechFinger;
	SWI_S32							_longitude;
	SWI_S32							_latitude;
	SWI_STRUCT_TechActiveSet		_pTechActSet;
	SWI_U16								_packetZoneID;
	SWI_U16							_pEcio;
	SWI_U16							_TxPower;
	SWI_U16							_RxPower;
	SWI_S32							_iTemperature;
	SWI_U16								_P_PRV;
	SWI_STRUCT_Rssi_Ecio			_stRssiEcio;
	SWI_U32								_nChannelNumber;
	SWI_STRUCT_Tech_Hdr_Mac_Index	_hdrMacIndex;
	
} TECH_DATA;

SWI_RCODE SwiGetTechData(TECH_DATA *data);

#ifdef __cplusplus
}
#endif
