/*
 *  swimacusbnotification.h
 *  swimac
 *
 *  Created by Mark de Jong on 8/6/08.
 *  Copyright 2008 Sierra Wireless, Inc. All rights reserved.
 *
 */

#ifndef __SWIMACUSBNOTIFICATION__
#define __SWIMACUSBNOTIFICATION__

#ifdef __cplusplus
extern "C"	{
#endif

#import "swimacdatatypes.h"
#import "swimacrcodes.h"

#define SWI_DEVICE_DETAILS_MODEM_NAME_LENGTH	32
#define SWI_DEVICE_DETAILS_BSD_PATH_LENGTH		64
#define SWI_DEVICE_DETAILS_SERVICE_TYPE_LENGTH	32
#define SWI_DEVICE_DETAILS_PORT_NAME_LENGTH		32
#define SWI_DEVICE_MAX_NUMBER_OF_PORTS			10	// very arbitrary; currently, we have 4 (data, control, nmea, dm); this leaves room for 6 more

typedef enum SWI_DEVICE_PORT_TYPE
{
	SWI_PORT_UNKNOWN,
	SWI_PORT_DATA,
	SWI_PORT_CONTROL,
	SWI_PORT_NMEA,
	SWI_PORT_DM,
	SWI_PORT_AT2,
	SWI_PORT_MASS_STORAGE_MEDIA,
} SWI_DEVICE_PORT_TYPE;

typedef struct SWI_PORT_DETAILS
{
	SWI_CHAR				modemName[SWI_DEVICE_DETAILS_MODEM_NAME_LENGTH];
	SWI_CHAR				bsdPath[SWI_DEVICE_DETAILS_BSD_PATH_LENGTH];
	SWI_CHAR				serviceType[SWI_DEVICE_DETAILS_SERVICE_TYPE_LENGTH];
	SWI_DEVICE_PORT_TYPE	portType;
	SWI_CHAR				portTypeName[SWI_DEVICE_DETAILS_PORT_NAME_LENGTH];
} SWI_PORT_DETAILS;

typedef struct SWI_DEVICE_DETAILS
{
	SWI_U32					sizeStruct;			// size of this struct; reflects total size, including all ports found
	SWI_U16					vendorID;			// should always be 0x1199, for Sierra
	SWI_U16					productID;
	SWI_U32					locationID;			// USB address
	SWI_CHAR				*usbProductName;	// formerly the "friendly name"
	void					*reserved1;			// reserved for framework use
	SWI_U16					numberOfPorts;		// number of I/O ports 
	SWI_PORT_DETAILS		ports[];
} SWI_DEVICE_DETAILS; // or should we pack this? __attribute__((packed)) SWI_DEVICE_DETAILS;

typedef struct SWI_STRUCT_USB_Device_Arrival_Status
{
	SWI_U32	detailSize;
	SWI_DEVICE_DETAILS	*deviceDetails;
} SWI_STRUCT_USB_Device_Arrival_Status;

typedef struct SWI_STRUCT_USB_Device_Removal_Status
{
	SWI_U32	detailSize;
	SWI_DEVICE_DETAILS	*deviceDetails;
} SWI_STRUCT_USB_Device_Removal_Status;

// ---
// Public functions
	
SWI_RCODE SwiGetConnectedSierraDevices( CFArrayRef *deviceArray );
SWI_RCODE SwiRegisterForSerialPortChangeNotifications( SWI_U32 timeout );
SWI_RCODE SwiUnregisterForSerialPortChangeNotifications( SWI_U32 timeout );

// Convenience functions
// All data returned from these functions are "read-only". Writing to the returned
// pointers may result in memory overruns and crashes

// -- 
SWI_RCODE SwiGetPortByType( const SWI_DEVICE_DETAILS *aDevice, SWI_DEVICE_PORT_TYPE portType, SWI_PORT_DETAILS const **aPort );
SWI_RCODE SwiGetDeviceFromDataRef( CFDataRef aDeviceRef, SWI_DEVICE_DETAILS const **aDevice );
const SWI_DEVICE_DETAILS *SwiGetDevicePtrFromDataRef( CFDataRef aDeviceRef );
const SWI_CHAR *SwiGetDeviceUSBProductNamePtr( SWI_DEVICE_DETAILS const *aDevice );

// -- control port
SWI_RCODE SwiGetControlPort( const SWI_DEVICE_DETAILS *aDevice, SWI_PORT_DETAILS const **aPort );
const SWI_PORT_DETAILS *SwiGetControlPortPtr( const SWI_DEVICE_DETAILS *aDevice );
SWI_RCODE SwiGetControlPortInDataRef( CFDataRef aDevice, SWI_PORT_DETAILS const **aPort );
const SWI_CHAR *SwiGetControlPortBSDPathPtr( const SWI_DEVICE_DETAILS *aDevice );
	
// -- data port
SWI_RCODE SwiGetDataPort( const SWI_DEVICE_DETAILS *aDevice, SWI_PORT_DETAILS const **aPort );
const SWI_PORT_DETAILS *SwiGetDataPortPtr( const SWI_DEVICE_DETAILS *aDevice );
SWI_RCODE SwiGetDataPortInDataRef( CFDataRef aDevice, SWI_PORT_DETAILS const **aPort );
const SWI_CHAR *SwiGetDataPortBSDPathPtr( const SWI_DEVICE_DETAILS *aDevice );
	
// -- nmea port
SWI_RCODE SwiGetNMEAPort( const SWI_DEVICE_DETAILS *aDevice, SWI_PORT_DETAILS const **aPort );
const SWI_PORT_DETAILS *SwiGetNMEAPortPtr( const SWI_DEVICE_DETAILS *aDevice );
SWI_RCODE SwiGetNMEAPortInDataRef( CFDataRef aDevice, SWI_PORT_DETAILS const **aPort );
const SWI_CHAR *SwiGetNMEAPortBSDPathPtr( const SWI_DEVICE_DETAILS *aDevice );

// -- dm port
SWI_RCODE SwiGetDMPort( const SWI_DEVICE_DETAILS *aDevice, SWI_PORT_DETAILS const **aPort );
const SWI_PORT_DETAILS *SwiGetDMPortPtr( const SWI_DEVICE_DETAILS *aDevice );
SWI_RCODE SwiGetDMPortInDataRef( CFDataRef aDevice, SWI_PORT_DETAILS const **aPort );
const SWI_CHAR *SwiGetDMPortBSDPathPtr( const SWI_DEVICE_DETAILS *aDevice );
	
// -- mass storage
SWI_RCODE SwiGetMSMPort( const SWI_DEVICE_DETAILS *aDevice, SWI_PORT_DETAILS const **aPort );
const SWI_PORT_DETAILS *SwiGetMSMPortPtr( const SWI_DEVICE_DETAILS *aDevice );
SWI_RCODE SwiGetMSMPortInDataRef( CFDataRef aDevice, SWI_PORT_DETAILS const **aPort );
const SWI_CHAR *SwiGetMSMPortBSDPathPtr( const SWI_DEVICE_DETAILS *aDevice );
	
	
#ifdef __cplusplus
}
#endif

#endif __SWIMACUSBNOTIFICATION__
