/*
 *  swimacsructs.h
 *  swimac
 *
 *  Created by Russ Winsper on 12/30/06.
 *  Copyright 2006 Sierra Wireless. All rights reserved.
 *
 */
 
#ifndef __SWIMACSTRUCTS__
#define __SWIMACSTRUCTS__

#ifdef __cplusplus
extern "C"	{
#endif

#import "swimacdatatypes.h"
#import "swimacomadmStructs.h"
#import "swimacfwupdate.h"
#import "swimacusbnotification.h"

#import "swifota.h"

#define SWI_MAC_SDK_VERSION				"${CURRENT_PROJECT_VERSION}"

#define LENGTH_CallNumber				32		// Maximum Caller ID length
#define LENGTH_CallExtendedNumber		64		// Maximum Extended Caller ID length

#define LENGTH_Mdn						15		// Maximum length of Mobile directory number
#define LENGTH_Min						10		// Maximum length of ISMI

#define LENGTH_PinPassword				4
#define LENGTH_EFilename				8

#define LENGTH_NvMnHaSs					16
#define LENGTH_NvMnAaaSs				16
#define LENGTH_HdrSectorID				16
#define LENGTH_HdrUati					16

#define LENGTH_AKey						20
#define LENGTH_AKeyChecksum				26

#define LENGTH_ProvisioningDate			8

#define MAX_SMSI_TL_ADDRESS				50		// Maximum SMS address length
#define MAX_SMSI_CALL_BACK				32		// Maximum SMS callback length

#define MAX_WalshCode					2
#define MAX_FingerSet					6
#define MAX_ActiveSet					6	// This must be the larger than/same with MIP_MAX_PROFILES


#define DIAG_HOST_AP_F					0xc8	// DIAG Msg ID - HI (every HI packet starts with this)
#define DIAG_ASYNC_CONTROL_CHAR			0x7E	// Flag character value. Corresponds to the ~ character
#define DIAG_ASYNC_ESC_CHAR				0x7D	// Escape sequence 1st character value
#define DIAG_ASYNC_ESC_MASK				0x20	// Escape sequence complement value

#define CNS_PDSM_MAX_NUM_SV				12

#define	SWI_PORT_NAME_SIZE				32		// length of COM port name
#define	SWI_FRIENDLY_NAME_SIZE			256		// maximum length of the instance ID 
												// string for devices and ports
#define SWI_INSTANCE_ID_SIZE			256		// maximum length of the instance ID 
												// string for devices and ports
#define SWI_SUFFIX_ID_SIZE				16		// maximum length for unique device and port prefixes

#define	LENGTH_NV_1X_CONNECTOID_NAME_I	20		// maxiumum length of a connectoid name returned from the device
#define CHAR_64 64 

	// Mode term
	
typedef enum
{
	SWI_MODE_TERM_NONE			=	-1,
	SWI_MODE_TERM_PERMANENT,				// Permanent mode change */
	SWI_MODE_TERM_PWR_CYCLE,				// Until power cycle
	SWI_MODE_TERM_1_CALL,					// Until end of next call or power-cycle
	SWI_MODE_TERM_1_CALL_OR_TIME,			// Until end of next call, specified timeout or power-cycle
	SWI_MODE_TERM_CM_1_CALL,
	SWI_MODE_TERM_CM_1_CALL_PLUS,
	SWI_MODE_TERM_CM_MO_SMS,
	SWI_MODE_TERM_MAX
} SWI_TYPE_Mode_Term;

	// Band preferences
	
typedef enum
{
	SWI_BAND_PREF_NONE			= 0,		// Acquire no system
	SWI_BAND_PREF_BC0_A			= 0x01,		// Acquire band class 0, A-Side systems only (US Cellular A 800 MHz)
	SWI_BAND_PREF_BC0_B			= 0x02,		// Acquire band class 0, B-Side systems only (US Cellular B 800 MHz)
	SWI_BAND_PREF_BC0			= 0x03,		// Acquire band class 0 systems only (US Cellular A/B 800 MHz)
	SWI_BAND_PREF_BC1			= 0x04,		// Acquire band class 1 systems only (US PCS 1900 MHz)
	SWI_BAND_PREF_BC3			= 0x10,		// Acquire band class 3 systems only (Japanese Cellular 800 MHz)
	SWI_BAND_PREF_BC4			= 0x20,		// Acquire band class 4 systems only (Korean PCS 1800 MHz)
	SWI_BAND_PREF_BC5			= 0x40,		// Acquire band class 5 systems only (450 MHz)
	SWI_BAND_PREF_BC6			= 0x80,		// Acquire band class 6 systems only (IMT2000)
	SWI_BAND_PREF_ANY			= 0xFFFF,	// Acquire any band class systems
	SWI_BAND_PREF_NO_CHANGE		= 0x10000,	// Do not change the band preference
	SWI_BAND_PREF_MAX
} SWI_TYPE_Band_Pref;

	// Roam preferences
	
typedef enum 
{
	SWI_ROAM_PREF_NONE			= -1,
	SWI_ROAM_PREF_HOME			= 0x01,		// Acquire only systems for which the roaming indication is off
	SWI_ROAM_PREF_AFFIL			= 0x03,		// Acquire only systems for which the roaming indication is off or ** solid on - i.e. not flashing
	SWI_ROAM_PREF_ANY			= 0xFF,		// Acquire systems regardless of their roaming indication
	SWI_ROAM_PREF_NO_CHANGE,				// Do not change the roam preference
	SWI_ROAM_PREF_MAX
} SWI_TYPE_Roam_Pref;

	// GUI Settings
	
typedef enum
{
	SWI_PRI_GUI_LOGOS					= 0x0001,	// carrier-specific logos
	SWI_PRI_GUI_TEXT					= 0x0002,	// carrier-specific trademark text
	SWI_PRI_GUI_DORMANCY				= 0x0004,	// Dormancy GUI support
	SWI_PRI_GUI_CALLGUARD				= 0x0008,	// Call Guard feature
	SWI_PRI_GUI_WARN_VOICECALL			= 0x0010,	// Voice call warning
	SWI_PRI_GUI_SHOW_IMSI				= 0x0020,	// Allow IMSI to be visible thru-out watcher (e.g. About Screen)
	SWI_PRI_GUI_SHOW_BYTE_COUNTER		= 0x0040,	// Cumulative Byte Counter in the Call Log
	SWI_PRI_GUI_RUIM_SUPPORT			= 0x0080,	// RUIM support enabled
	SWI_PRI_GUI_SINGLENAM				= 0x0100,	// Single NAM support
	
	SWI_PRI_GUI_SWI_LOGO				= 0x0200,	// SWI specific logo
	SWI_PRI_GUI_CM						= 0x0400,	// Enable indicator

	SWI_PRI_GUI_NET_MODE				= 0x0800,	// Network mode selection

	SWI_PRI_GUI_DORM_DISC				= 0x1000,	// Dormant Disconnect feature

	SWI_PRI_GUI_ALL						= 0xFFFF,

	SWI_PRI_GUI_MASK_ENABLED			= 0x8000	// Enabled bit
	
} SWI_TYPE_PRI_GUIMask;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_CallState - Call State enumeration
//
// Purpose:     This enumeration type identifies the elements of
//				a bit-mapped call state.  More than one bit can be
//				set at one time.
//
// Members:  	SWI_CALL_STATE_Idle			- No call
//				SWI_CALL_STATE_CnsAsyncData	- Async Data call
//				SWI_CALL_STATE_VoiceCall	- Voice call
//				SWI_CALL_STATE_Packet		- Packet 1xRtt call
// 
//				SWI_CALL_STATE_AtAsyncData	- Async Data call (via AT cmds)
//				SWI_CALL_STATE_AtVoiceCall 	- Voice call (via AT cmds)	
// 				SWI_CALL_STATE_AtPacket	   	- Packet 1xRtt call (via AT cmds)
//
//				SWI_CALL_STATE_Fax			- Fax call
// 				SWI_CALL_STATE_Sms			- SMS
//				SWI_CALL_STATE_OTA			- OTA
//				SWI_CALL_STATE_Test			- not used
// 				SWI_CALL_STATE_Cw			
//				SWI_CALL_STATE_NotUsed		- not used	
//
// 				SWI_CALL_STATE_Dormant		- Data connection is in dormant state
//
//				SWI_CALL_STATE_Emergency	- An emergency (E911) call
//
// Notes:	    For descriptions on the meaning of the various states,
//				see SWI_TYPE_CallType.
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_CALL_STATE_Idle				= 0x0000,
	SWI_CALL_STATE_CnsAsyncData		= 0x0001,
	SWI_CALL_STATE_VoiceCall		= 0x0002,
	SWI_CALL_STATE_Packet			= 0x0004,
	SWI_CALL_STATE_AtAsyncData		= 0x0010,
	SWI_CALL_STATE_AtVoiceCall		= 0x0020,
	SWI_CALL_STATE_AtPacket			= 0x0040,
	SWI_CALL_STATE_Fax				= 0x0080,
	SWI_CALL_STATE_Sms				= 0x0200,
	SWI_CALL_STATE_OTA				= 0x0400,
	SWI_CALL_STATE_Test				= 0x0800,
	SWI_CALL_STATE_Cw				= 0x1000,
	SWI_CALL_STATE_NotUsed			= 0x2000,
	SWI_CALL_STATE_Dormant			= 0x4000,
	SWI_CALL_STATE_Emergency		= 0x8000
} SWI_TYPE_CallState;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_CallType - Call Type enumeration
//
// Purpose:     The call type is used for various call management notifications.
//
// Members:  	SWI_CALL_TYPE_Voice			- Standard voice call and originating an
//											  OTASP call. Used by both AirCard 555 and
//											  SB555 products for originating a voice call.
//
//				SWI_CALL_TYPE_VoiceAlert	- Call waiting (Incoming only)
//
// 				SWI_CALL_TYPE_AsyncData		- Asynchronous Data.  Used by the AirCards
//											  for originating a QNC data call.
//
//				SWI_CALL_TYPE_PacketData	- Packet Data.  Used by the AirCards for
//											  originating a 1xRTT packet data connection.
//
//				SWI_CALL_TYPE_Fax			- Fax.  Standard G3 facsimile call.
//
// 				SWI_CALL_TYPE_Sms			- SMS.  Not used for application originated calls.
// 											  This indicates the connection being made is for
// 											  SMS transactions.
//
//				SWI_CALL_TYPE_Test			- Test (not used)
//
//				SWI_CALL_TYPE_Otapa			- OTAPA.  A call from a special number to
//											  update network settings in the modem.
//											  (Incoming only)
//
// 				SWI_CALL_TYPE_StandardOtasp	- Standard OTASP.  Not used in call origination
//											  or termination (answering). When OTASP is
//											  established a voice call may change to this type.
//
//				SWI_CALL_TYPE_NonstandardOtasp
//											- Nonstandard OTASP	(not used)
//
//				SWI_CALL_TYPE_E911			- E911.  An emergency mode call.
//
// 				SWI_CALL_TYPE_EVDO			- EVDO call 
//
//				SWI_CALL_TYPE_None			- Call Type None - (not used)
//
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_CALL_TYPE_Voice				= 0x0000,
	SWI_CALL_TYPE_VoiceAlert		= 0x0100,
	SWI_CALL_TYPE_AsyncData			= 0x0001,
	SWI_CALL_TYPE_PacketData		= 0x0101,
	SWI_CALL_TYPE_Fax				= 0x0201,
	SWI_CALL_TYPE_Sms				= 0x0002,
	SWI_CALL_TYPE_Test				= 0x0003,
/*	pre 3.1qc
	SWI_CALL_TYPE_Otapa				= 0x0004,
	SWI_CALL_TYPE_StandardOtasp		= 0x0005,
	SWI_CALL_TYPE_NonstandardOtasp	= 0x0006,
	SWI_CALL_TYPE_E911				= 0x0007,
*/
	SWI_CALL_TYPE_Otapa				= 0x0005,
	SWI_CALL_TYPE_StandardOtasp		= 0x0006,
	SWI_CALL_TYPE_NonstandardOtasp	= 0x0007,
	SWI_CALL_TYPE_E911				= 0x0008,
	SWI_CALL_TYPE_EVDO				= 0x0009,
	SWI_CALL_TYPE_None				= 0xffff
} SWI_TYPE_CallType;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_AnswerState - Answer State enumeration
//
// Purpose:     The modes of operation the modem uses to
// 				determine how to answer the next incoming
// 				voice call.
//
// Parameters:  SWI_ANSWER_STATE_VoiceAsVoice     
//											- Answer voice as voice
//				SWI_ANSWER_STATE_VoiceAsFaxOnce,   
//											- Answer voice as fax once
//											  (for the next 10 minutes)
//				SWI_ANSWER_STATE_VoiceAsFaxAlways, 
//											- Answer voice as fax always 
//				SWI_ANSWER_STATE_VoiceAsModemOnce, 
//											- Answer voice as modem once
//											  (for the next 10 minutes)
//				SWI_ANSWER_STATE_VoiceAsModemAlways
//											- Answer voice as modem always
//
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum 
{
	SWI_ANSWER_STATE_VoiceAsVoice,       
	SWI_ANSWER_STATE_VoiceAsFaxOnce,     
	SWI_ANSWER_STATE_VoiceAsFaxAlways,   
	SWI_ANSWER_STATE_VoiceAsModemOnce,   
	SWI_ANSWER_STATE_VoiceAsModemAlways  
} SWI_TYPE_AnswerState;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_FlashContext - Flash Context enumeration
//
// Purpose:     Values for use with the SwiSetCallFlashCmd function.
//
// Members:  	SWI_FLASH_CONTEXT_DontCare	- Don√≠t Care This passes the call 
// 											  number to the call manager without checking that the 
// 											  flash command is valid in the present call state. Use
// 											  this context when you want manual control over
// 											  the flash command. If enabled, the [CallError]
// 											  notifications are sent if the flash is invoked in an
// 											  inappropriate call state.
//				SWI_FLASH_CONTEXT_CallWaiting
//											- Call Waiting This indicates to the call manager
//											  that the flash is for servicing a waiting call.
//											  When first invoked, it puts the current call on
//											  hold and connects the second call that is waiting.
//											  hold and connects the second call that is waiting.
//											  original call and holds the second call.
//     			SWI_FLASH_CONTEXT_ThreewaySetup		
//											- Threeway Setup This indicates to the call
//											  manager that the flash is for setting up a threeway
//											  call. A call number must be provided or
//											  else an error message will be returned as the
//											  response. This context sends two flashes to the
//											  base station, the first without a phone number
//											  and the second with a phone number.
//				SWI_FLASH_CONTEXT_ThreewayConnect
//											- Threeway Connect This indicates to the call
//											  manager that the flash is to connect all three
//											  parties. For this context, a call number must not
//											  be provided, otherwise an error message is
//											  returned as the response. Use the Don't Care
//											  flash context with an empty call number to
//											  disconnect the last connected party.
//				SWI_FLASH_CONTEXT_AnswerHold
//											- Answer Hold Not implemented.	 
//     			SWI_FLASH_CONTEXT_AnswerForward	
//											- Answer Forward Not implemented.	
//
// Notes:	    SWI_FLASH_CONTEXT_DontCare can be typically used for all
//				scenarios.
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_FLASH_CONTEXT_DontCare		    = 0x0000,
	SWI_FLASH_CONTEXT_CallWaiting	    = 0x0001,
	SWI_FLASH_CONTEXT_ThreewaySetup		= 0x0002,
	SWI_FLASH_CONTEXT_ThreewayConnect	= 0x0003,
	SWI_FLASH_CONTEXT_AnswerHold	    = 0x0004,
	SWI_FLASH_CONTEXT_AnswerForward		= 0x0005,
} SWI_TYPE_FlashContext;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_EndReason - Reason for call termination
//
// Purpose:     This reports the reason a call is disconnected
//
// Members:  	SWI_END_REASON_Offline		- Phone is offline
//
//				SWI_END_REASON_CdmaLockedUntilPowerCycle		
//											- Phone is CDMA locked until power-cycle
//
//    			SWI_END_REASON_NoService						
//											- Phone has no service
//
//				SWI_END_REASON_CallEndedAbnormally				
//											- Call has ended abnormally
//
//				SWI_END_REASON_ReceivedInterceptFromBs			
//											- Received intercept from BS (Orig. only)
//
//    			SWI_END_REASON_ReceivedReorderFromBs			
//											- Received release from BS (Orig. only)
//
//				SWI_END_REASON_ReceivedReleaseFromBsNoReason	
//											- Received release from BS - no reason given
//
//				SWI_END_REASON_ReceivedInterceptFromBsSoReject	
//											- Received release from BS - SO reject
//
//    			SWI_END_REASON_ReceivedIncomingCallFromBs		
//											- Received incoming call from BS
//
//				SWI_END_REASON_ReceivedAlertStopFromBs			
//											- Received alert stop from BS (incoming only)
//
//				SWI_END_REASON_ClientEndedCall					
//											- Client ended the call
//
//    			SWI_END_REASON_ReceivedEndActivation			
//											- Received end activation (OTASP call only)
//
//				SWI_END_REASON_McAborts						
//											- Obsolete
//
//				SWI_END_REASON_NdssFailure						
//											- NDSS failure
//
//    			SWI_END_REASON_MaxAccessProbesTransmitted		
//											- Max access probes transmitted
//
//				SWI_END_REASON_PersistenceTestFailure			
//											- Persistence test failure
//
//				SWI_END_REASON_RuimNotPresent					
//											- RUIM not present
//
//    			SWI_END_REASON_AccessAttemptAlreadyInProgress	
//											- Access attempt already in progress
//
//				SWI_END_REASON_AccessFailureReasonUnspecified	
//											- Access failure for reason other than the above reason
//
//				SWI_END_REASON_ReceivedRetryOrder				
//											- Received retry order (Orig. only)
//    
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_END_REASON_Offline,
	SWI_END_REASON_CdmaLockedUntilPowerCycle,
	SWI_END_REASON_NoService,
	SWI_END_REASON_CallEndedAbnormally,
	SWI_END_REASON_ReceivedInterceptFromBs,
	SWI_END_REASON_ReceivedReorderFromBs,
	SWI_END_REASON_ReceivedReleaseFromBsNoReason,
	SWI_END_REASON_ReceivedInterceptFromBsSoReject,
	SWI_END_REASON_ReceivedIncomingCallFromBs,
	SWI_END_REASON_ReceivedAlertStopFromBs,
	SWI_END_REASON_ClientEndedCall,
	SWI_END_REASON_ReceivedEndActivation,
	SWI_END_REASON_McAborts,
	SWI_END_REASON_NdssFailure,
	SWI_END_REASON_MaxAccessProbesTransmitted,
	SWI_END_REASON_PersistenceTestFailure,
	SWI_END_REASON_RuimNotPresent,
	SWI_END_REASON_AccessAttemptAlreadyInProgress,
	SWI_END_REASON_AccessFailureReasonUnspecified,
	SWI_END_REASON_ReceivedRetryOrder
} SWI_TYPE_EndReason;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_CallSource - Call Source (AT Cmds or API) enumeration
//
// Purpose:     This enumerates the call source options which identify if a call
//				was connected using AT commands or using the CnS
//				protocol (used by the API).
//
// Members:  	SWI_CALL_SOURCE_At			- AT Commands
//				SWI_CALL_SOURCE_Cns			- CNS (API)
// 	    
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_CALL_SOURCE_At,
	SWI_CALL_SOURCE_Cns
} SWI_TYPE_CallSource;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_PhoneKey - Dialpad keys enumeration
//
// Purpose:     This enumeration type identifies the dial pad keys.
//
// Members:  	SWI_PHONE_KEY_Pound			- '#' key, ASCII '#'                      
//				SWI_PHONE_KEY_Star			- '*' key, ASCII '*'                      
//     			SWI_PHONE_KEY_0				- '0' key, ASCII '0'                      
//				SWI_PHONE_KEY_1				- '1' key, ASCII '1'                      
//				SWI_PHONE_KEY_2				- '2' key, ASCII '2'                      
//     			SWI_PHONE_KEY_3				- '3' key, ASCII '3'                      
//				SWI_PHONE_KEY_4				- '4' key, ASCII '4'                      
//				SWI_PHONE_KEY_5				- '5' key, ASCII '5'                      
//     			SWI_PHONE_KEY_6				- '6' key, ASCII '6'                      
//				SWI_PHONE_KEY_7				- '7' key, ASCII '7'                      
//				SWI_PHONE_KEY_8				- '8' key, ASCII '8'                      
//     			SWI_PHONE_KEY_9				- '9' key, ASCII '9'                      
//				SWI_PHONE_KEY_Send			- Send key                                
//				SWI_PHONE_KEY_End			- End key or Power key (Based on Target)  
//     			SWI_PHONE_KEY_Clear			- Clear key                               
//				SWI_PHONE_KEY_Store			- Store key                               
//				SWI_PHONE_KEY_Up			- Up-arrow key was pressed                
//     			SWI_PHONE_KEY_Down			- Down-arrow key was pressed              
//				SWI_PHONE_KEY_Mute			- Mute Key                                
//				SWI_PHONE_KEY_Recall		- Recall key                              
//     
// Notes:	    Only digit keys 0-9, #, and * have any real use (i.e., DTMF tones
//				are played accordingly)
//
//				Command keys (Send, End, Recall, etc) have no effect and are not
//				used
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_PHONE_KEY_Pound  = 0x23,
	SWI_PHONE_KEY_Star	= 0x2A,		
	SWI_PHONE_KEY_0		= 0x30,     
	SWI_PHONE_KEY_1		= 0x31,     
	SWI_PHONE_KEY_2		= 0x32,     
	SWI_PHONE_KEY_3		= 0x33,     
	SWI_PHONE_KEY_4		= 0x34,     
	SWI_PHONE_KEY_5		= 0x35,     
	SWI_PHONE_KEY_6		= 0x36,     
	SWI_PHONE_KEY_7		= 0x37,     
	SWI_PHONE_KEY_8		= 0x38,     
	SWI_PHONE_KEY_9		= 0x39,     
	SWI_PHONE_KEY_Send	= 0x50,     
	SWI_PHONE_KEY_End	= 0x51,     
	SWI_PHONE_KEY_Clear	= 0x52,     
	SWI_PHONE_KEY_Store	= 0x53,     
	SWI_PHONE_KEY_Up	= 0x54,     
	SWI_PHONE_KEY_Down	= 0x55,     
	SWI_PHONE_KEY_Mute	= 0x56,     
	SWI_PHONE_KEY_Recall = 0x57     
} SWI_TYPE_PhoneKey;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWIHW_TYPE_Power - HW Power State enumeration
//
// Purpose:     Defines the Hardware Power States.
//
// Members:    SWIHW_TYPE_PowerUnknown, - Power state not determined yet.
//             SWIHW_TYPE_PowerOn       - Hardware is powered on, but HW switch can be in ON position.
//             SWIHW_TYPE_PowerOff      - Hardware is powered off, but HW switch can be in ON position
//             SWIHW_TYPE_PowerDisabled - Hardware is powered off because HW switch is in OFF position
//             SWIHW_TYPE_NotPresent	- Hardware not present
//
// Notes:      None.
//
///////////////////////////////////////////////////////////////////
typedef enum
{
  SWIHW_TYPE_PowerUnknown   = 0,
  SWIHW_TYPE_PowerOn        = 1,
  SWIHW_TYPE_PowerOff       = 2,
  SWIHW_TYPE_PowerDisabled  = 3,
  SWIHW_TYPE_NotPresent		= 4,
} SWIHW_TYPE_Power;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_RoamingState - Roaming State enumeration
//
// Purpose:	This type definition covers the possible return values of the function 
//			SwiGetRoamingStatus, and the SWI_NOTIFY_RoamingStatus notification.
//
// Members:	SWI_ROAMING_Home			- Not Roaming
//
//			SWI_ROAMING_Roaming			- Roaming
//
//			SWI_ROAMING_NonPref			- Interpretation of values above 2 (NonPref) 
//										  are service provider dependent.
//
//			SWI_ROAMING_None   			- Unknown
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
    SWI_ROAMING_Home,
    SWI_ROAMING_Roaming,
	SWI_ROAMING_NonPref,
    SWI_ROAMING_None
} SWI_TYPE_RoamingState;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_RoamingStatus - Roaming State notification 
//										   data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_RoamingStatus.  Refer to the description of 
//				SWI_NOTIFY_RoamingStatus for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				eRoamingStatus				- Roaming status.  See 
//											  SWI_TYPE_RoamingState for details.
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct SWI_STRUCT_RoamingStatus
{
    SWI_U32                  sizeStruct;     
	SWI_TYPE_RoamingState	eRoamingStatus;
} SWI_STRUCT_RoamingStatus;

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_ServiceIndication - service indication enumeration
//
// Purpose:	This enumeration contains the service indication states.
//
// Members:	SWI_SERVICE_INDICATION_None		- no service
//
//			SWI_SERVICE_INDICATION_Analog	- analog
//
//			SWI_SERVICE_INDICATION_Digital	- digital
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
typedef enum 
{
	SWI_SERVICE_INDICATION_None,
	SWI_SERVICE_INDICATION_Analog,
	SWI_SERVICE_INDICATION_Digital
} SWI_TYPE_ServiceIndication;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_ServiceIndication - Service indication notification 
//											   data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_ServiceIndication.  Refer to the description of 
//				SWI_NOTIFY_ServiceIndication for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				eServiceIndicator			- Service indication.  See 
//											  SWI_TYPE_ServiceIndication for details.
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct SWI_STRUCT_ServiceIndication
{
    SWI_U32						sizeStruct;
	SWI_TYPE_ServiceIndication	eServiceIndicator;
} SWI_STRUCT_ServiceIndication;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_PrevValue - Protocol Revision enumeration
//
// Purpose:     This enumerates the protocol revision 
//				supported by the serving base station.
//
// Members:  	SWI_PREV_VALUE_Jstd008	 	- Not supported
//				SWI_PREV_VALUE_Is95			- IS95
// 	    		SWI_PREV_VALUE_Is95A		- IS95A
// 	    		SWI_PREV_VALUE_MinIs95B		- Minimum IS95B
// 	    		SWI_PREV_VALUE_FullIs95B	- Full IS95B
// 	    		SWI_PREV_VALUE_Cdma2000Rev0	- CDMA 2000 Rev 0
// 	    		SWI_PREV_VALUE_Cdma2000Rev1	- CDMA 2000 Rev 1
// 	    
// Notes:	    Values of 6 or 7 (Cdma2000) indicate 1xRTT
//				coverage is availble. Value 1 (Jstd008) is not
//				supported.
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_PREV_VALUE_Jstd008			= 1,
	SWI_PREV_VALUE_Is95,
	SWI_PREV_VALUE_Is95A,
	SWI_PREV_VALUE_MinIs95B,
	SWI_PREV_VALUE_FullIs95B,
	SWI_PREV_VALUE_Cdma2000Rev0,
	SWI_PREV_VALUE_Cdma2000Rev1
} SWI_TYPE_PrevValue;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_Prev - Protocol Revision notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_Prev.  Refer to the description of
//				SWI_NOTIFY_Prev for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				eValue						- Protocal Revision value.  See
//											  SWI_TYPE_PrevValue for details.
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct
{
    SWI_U32				sizeStruct;     
	SWI_TYPE_PrevValue	eValue;
} SWI_STRUCT_Prev;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_ActiveNam - Active Nam notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_ActiveNam.  Refer to the description of SWI_NOTIFY_ActiveNam
//				for more detail.
//
// Members:  	sizeStruct		- size of this structure
//				iActiveNam		- Active Nam index
//
// Notes:	    Consult the reference for SwiPstGetCurrentNam for details
//				on the Nam index.
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct
{
    SWI_U32			sizeStruct;
	SWI_U16			iActiveNam;
} SWI_STRUCT_ActiveNam;

// Service state

typedef enum
{
	INVALID_STATE   = -1,
	NO_SERVICE		= 0,
	ACTIVE,
	IS95A_ONLY,
	IS95B_ONLY,
	ONEXRTT_ONLY,
	ONEXEVDO_ONLY,
	ONEXEVDO_IS95A,
	ONEXEVDO_IS95B,
	ONEXEVDO_ONEXRTT
} SERVICE_STATE;

// Packet Data Status

typedef enum
{
	ONEX_ADV_PD_NONE=-1,		// FOR INTERNAL USE ONLY!
	ONEX_ADV_PD_NULL,
	ONEX_ADV_PD_DORM,
	ONEX_ADV_PD_ACTIVE_1XEV,
	ONEX_ADV_PD_ACTIVE_1XRTT,
	ONEX_ADV_PD_ACTIVE_95,
	ONEX_ADV_PD_MAX				// FOR INTERNAL USE ONLY!
} ONEX_ADV_PD_E_TYPE;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_Rssi - RSSI notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_Rssi.  Refer to the description of SWI_NOTIFY_Rssi
//				for more detail.
//
// Members:  	sizeStruct		- size of this structure
//				iRssi			- RSSI in dBm
//
// Notes:	    Consult the reference for SwiGetRssi for details
//				on the value iRssi.
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct
{
    SWI_U32			sizeStruct;
	SWI_U16			iRssi;
} SWI_STRUCT_Rssi;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_ChannelNumber - Channel # notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_ChannelNumber.  Refer to the description of
//				SWI_NOTIFY_ChannelNumber for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				nChannelNumber				- Channel #
//
// Notes:	    Consult the reference for SwiGetChannelNumber
//				for details on the value nChannelNumber.
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct
{
    SWI_U32				sizeStruct;
	SWI_U32				nChannelNumber;
} SWI_STRUCT_ChannelNumber;

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_ChannelState - channel state
//
// Purpose:	This enumerates the channel state
//
// Members:	SWI_CHANNEL_Aquired		- acquired
//
//			SWI_CHANNEL_Sleep		- sleep
//
//			SWI_CHANNEL_Scan		- scan
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_CHANNEL_Sleep	= 0,	// sleep
	SWI_CHANNEL_Aquired = 1,	// aquired 
	SWI_CHANNEL_Scan	= 5		// scan 
} SWI_TYPE_ChannelState;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_ChannelState - Channel State notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_ChannelState.  Refer to the description of 
//				SWI_NOTIFY_ChannelState for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				eChannelState				- Channel state.  See 
//											  SWI_TYPE_ChannelState for details.
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct
{
    SWI_U32					sizeStruct;
	SWI_TYPE_ChannelState	eChannelState;
} SWI_STRUCT_ChannelState;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_TechBandClass - Bandclass enumeration
//
// Purpose:     The data enumerates as either cellular or PCS.
//
// Members:  	SWI_TECH_BANDCLASS_Cellular	- Cellular
//				SWI_TECH_BANDCLASS_Pcs		- PCS
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_TECH_BANDCLASS_Cellular	= 0,
	SWI_TECH_BANDCLASS_Pcs
} SWI_TYPE_TechBandClass;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_TechBandClass - Bandclass notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_TechBandClass.  Refer to the description of
//				SWI_NOTIFY_TechBandClass for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				eBandClass					- Bandclass.  See
//											  SWI_TYPE_TechBandClass for details.
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct
{
    SWI_U32					sizeStruct; 
	SWI_TYPE_TechBandClass	eBandClass;
} SWI_STRUCT_TechBandClass;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_Rssi_Ecio - RSSI and EcIo data structure
//
// Purpose:     This data structure is used to hold RSSI and EcIo data.
//
// Members:		sizeStruct		- size of this structure
//				iCdmaRssi;		- Cdma RSSI
//				iCdmaEcio;		- Cdma EcIo
//				iHdrRssi;		- HDR RSSI
//				iHdrEcio;		- HDR EcIo
//
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct
{
    SWI_U32			sizeStruct;     
    SWI_U16			iCdmaRssi;   
    SWI_U16			iCdmaEcio;
    SWI_U16			iHdrRssi;
    SWI_U16			iHdrEcio;
} SWI_STRUCT_Rssi_Ecio;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_Hdr_Roam_Status - Hdr Roaming Status
//
// Purpose:     This enumerates the Hdr Roam status 
//				returned in the notification.
//
// Members:  	SWI_HDR_ROAM_STATUS_NO_ROAMING
//				SWI_HDR_ROAM_STATUS_ROAMING_WITH_GAURANTEED_VALID_SIDS
// 	    		SWI_HDR_ROAM_STATUS_ROAMING_WITHOUT_GAURANTEED_SIDS
// 	    
// Notes:	    
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_HDR_ROAM_STATUS_NO_ROAMING							= 0,
	SWI_HDR_ROAM_STATUS_ROAMING_WITH_GAURANTEED_VALID_SIDS,
	SWI_HDR_ROAM_STATUS_ROAMING_WITHOUT_GAURANTEED_SIDS
} SWI_TYPE_Hdr_Roam_Status;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_Hdr_Roam_Status - Hdr Roam Status data structure
//
// Purpose:     This data structure is used to hold the Hdr Roaming status.
//
// Members:		sizeStruct		- size of this structure
//				iHdrRoamStatus	- status (see SWI_TYPE_Hdr_Roam_Status)
//
// Notes:	    
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct
{
    SWI_U32						sizeStruct;     
	SWI_TYPE_Hdr_Roam_Status	iHdrRoamStatus;   
} SWI_STRUCT_Hdr_Roam_Status;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_Hdr_Rssi - Hdr RSSI data structure
//
// Purpose:     This data structure is used to hold the Hdr RSSI data.
//
// Members:		sizeStruct		- size of this structure
//				iRssi			- RSSI
//
// Notes:	    This is deprecated use Rssi Ecio data.
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct 
{
    SWI_U32			sizeStruct;     
	SWI_U16			iRssi;
} SWI_STRUCT_Hdr_Rssi;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_Hdr_Srv_State - Hdr Service State
//
// Purpose:     This enumerates the Hdr Service state 
//				returned in the notification.
//
// Members:  	SWI_HDR_SRV_STATE_NO_SERVICE
//				SWI_HDR_SRV_STATE_DIGITAL_SERVICE
// 	    		SWI_HDR_SRV_STATE_DIGITAL_SERVICE_Rev0
//				SWI_HDR_SRV_STATE_DIGITAL_SERVICE_RevA
// 	    
// Notes:	    
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_HDR_SRV_STATE_NO_SERVICE			= 0,
	SWI_HDR_SRV_STATE_DIGITAL_SERVICE		= 2,
	SWI_HDR_SRV_STATE_DIGITAL_SERVICE_Rev0	= SWI_HDR_SRV_STATE_DIGITAL_SERVICE,
	SWI_HDR_SRV_STATE_DIGITAL_SERVICE_RevA	= 4
} SWI_TYPE_Hdr_Srv_State;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_Hdr_Srv_State - Hdr Service State data structure
//
// Purpose:     This data structure is used to hold the Hdr Service state.
//
// Members:		sizeStruct		- size of this structure
//				iHdrSrvState	- state (see SWI_TYPE_Hdr_Srv_State)
//
// Notes:	    
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct
{
    SWI_U32					sizeStruct;     
    SWI_TYPE_Hdr_Srv_State	iHdrSrvState;
} SWI_STRUCT_Hdr_Srv_State;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_Hdr_Hybr_Pref - Hdr Hybrid Pref
//
// Purpose:     This enumerates the Hdr Hybrid Pref 
//				returned in the notification.
//
// Members:  	SWI_HDR_HYBR_PREF_MODE_OFF
//				SWI_HDR_HYBR_PREF_MODE_ON
// 	    
// Notes:	    
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_HDR_HYBR_PREF_MODE_OFF	= 0,
	SWI_HDR_HYBR_PREF_MODE_ON
} SWI_TYPE_Hdr_Hybr_Pref;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_Hdr_Hybr_Pref - Hdr Hybrid Pref data structure
//
// Purpose:     This data structure is used to hold the Hdr Hybrid preference.
//
// Members:		sizeStruct		- size of this structure
//				iHdrHybrPref	- preference (see SWI_TYPE_Hdr_Hybr_Pref)
//
// Notes:	    
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct
{
    SWI_U32					sizeStruct;     
    SWI_TYPE_Hdr_Hybr_Pref	iHdrHybrPref;   
} SWI_STRUCT_Hdr_Hybr_Pref;

// Phone Mode Preference

typedef enum
{
	CM_MODE_PREF_ANALOG_ONLY = 0x00,
	CM_MODE_PREF_DIGITAL_ONLY = 0x01,
	CM_MODE_PREF_AUTOMATIC = 0x02,
	CM_MODE_PREF_E911 = 0x03,
	CM_MODE_PREF_PCS_CDMA_ONLY = 0x04,
	CM_MODE_PREF_CELL_CDMA_ONLY = 0x05,
	CM_MODE_PREF_CDMA_ONLY = 0x09,
	CM_MODE_PREF_HDR_ONLY = 0x0A,
	CM_MODE_PREF_CDMA_AMPS_ONLY = 0x0B,
	CM_MODE_PREF_GPS_ONLY = 0x0C,
	CM_MODE_PREF_GSM_ONLY = 0x0D,
	CM_MODE_PREF_WCDMA_ONLY = 0x0E,
	CM_MODE_PREF_PERSISTENT = 0x0D,
	CM_MODE_PREF_NO_CHANGE = 0x0F
} CM_MODE_PREF_E_TYPE;

// Mode Preference Terms

typedef enum
{
	CM_MODE_TERM_PERMANENT = 0x00,
	CM_MODE_TERM_PWR_CYCLE = 0x01,
	CM_MODE_TERM_1_CALL = 0x02,
	CM_MODE_TERM_1_CALL_OR_TIME = 0x03,
	CM_MODE_TERM_CM_1_CALL = 0x04,
	CM_MODE_TERM_CM_1_CALL_PLUS = 0x05,
	CM_MODE_TERM_CM_MO_SMS = 0x06
}CM_MODE_TERM_E_TYPE;

// Roam Prefence

typedef enum
{
	CM_ROAM_PREF_NONE   =-1,
	CM_ROAM_PREF_HOME   = 0x01,
	CM_ROAM_PREF_AFFIL  = 0x03,
	CM_ROAM_PREF_ANY	= 0xFF,
	CM_ROAM_PREF_NO_CHANGE,
	CM_ROAM_PREF_MAX
} CM_ROAM_PREF_E_TYPE;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_Digital_Mode - Digital mode
//
// Purpose:     This enumerates the Digital mode
//				returned in the notification.
//
// Members:  	SWI_HDR_MODE_NO_SERVICE
//				SWI_HDR_MODE_AMPS
// 	    		SWI_HDR_MODE_CDMA
//				SWI_HDR_MODE_GSM
//				SWI_HDR_MODE_HDR
//				SWI_HDR_MODE_WCDMA
//				SWI_HDR_MODE_GPS
// 	    
// Notes:	    
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_HDR_MODE_NO_SERVICE	    = 0,
	SWI_HDR_MODE_AMPS,
	SWI_HDR_MODE_CDMA,
	SWI_HDR_MODE_GSM,
	SWI_HDR_MODE_HDR,
	SWI_HDR_MODE_WCDMA,
	SWI_HDR_MODE_GPS
} SWI_TYPE_Digital_Mode;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_Idle_Digital_Mode - Idle Digital Mode data structure
//
// Purpose:     This data structure is used to hold the Idle Digital Mode.
//
// Members:		sizeStruct				- size of this structure
//				iPrevIdleDigitalMode	- previous mode (see SWI_TYPE_Digital_Mode)
//				iCurrIdleDigitalMode	- current mode (see SWI_TYPE_Digital_Mode)
//
// Notes:	    
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct
{
    SWI_U32					sizeStruct;     
    SWI_TYPE_Digital_Mode	iPrevIdleDigitalMode;   
    SWI_TYPE_Digital_Mode	iCurrIdleDigitalMode;   
} SWI_STRUCT_Idle_Digital_Mode;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_DDTM_Pref - DDTM Pref
//
// Purpose:     This enumerates the DDTM Pref 
//				returned in the notification.
//
// Members:  	SWI_HDR_DDTM_PREF_MODE_OFF
//				SWI_HDR_DDTM_PREF_MODE_ON
// 	    		SWI_HDR_DDTM_PREF_MODE_NO_CHANGE
// 	    
// Notes:	    
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_HDR_DDTM_PREF_MODE_OFF			= 0,
	SWI_HDR_DDTM_PREF_MODE_ON,
	SWI_HDR_DDTM_PREF_MODE_NO_CHANGE
} SWI_TYPE_DDTM_Pref;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_DDTM_Pref - DDTM Pref data structure
//
// Purpose:     This data structure is used to hold the DDTM Preference.
//
// Members:		sizeStruct		- size of this structure
//				iDDTMPref		- DDTm pref (see SWI_TYPE_DDTM_Pref)
//
// Notes:	    
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct
{
    SWI_U32				sizeStruct;     
    SWI_TYPE_DDTM_Pref	iDDTMPref;   
} SWI_STRUCT_DDTM_Pref;

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_EMIOTA_EVENT_TYPE - Evnet type like stat session ,end session 
//
// Purpose:	This is the enumeration of Embedded IOTA event type.
//
// Members:	13 members see below for description
//
// Notes:	
//
///////////////////////////////////////////////////////////////////////////////////
enum SWI_EMIOTA_EVENT_TYPE 
{
	SWI_EMIOTA_SESSION_START,				    // 0:EM IOTA session started
	SWI_EMIOTA_SESSION_END,				      // 1:EM IOTA session end
};


/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_EMIOTA_EVENT_RESULT - Evnet type sucess or failure  
//
// Purpose:	This is the enumeration of Embedded IOTA event type result.
//
// Members:	SWI_EMIOTA_EVENT_RESULT_SUCCESS,				// event successfull
//          SWI_EMIOTA_EVENT_RESULT_FAILURE,				// event failed
//
//
// Notes:	
//
///////////////////////////////////////////////////////////////////////////////////
enum SWI_EMIOTA_EVENT_RESULT 
{
	SWI_EMIOTA_EVENT_RESULT_SUCCESS,				// 0:event successful
	SWI_EMIOTA_EVENT_RESULT_FAILURE,				// 1:event failed	
};



/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_EMIOTA_EVENT_FAIL_REASON - Evnet type failure reason. 
//
// Purpose:	This is the enumeration of Embedded IOTA event type failure reason.
//
// Members:	17 members see below for description
//
// Notes:	
//
///////////////////////////////////////////////////////////////////////////////////

enum SWI_EMIOTA_EVENT_FAIL_REASON 
{
	SWI_EMIOTA_STATUS_MIN = -1,		              // -1:IOTA status min
	SWI_EMIOTA_STATUS_SUCCESS ,		              // 0:IOTA status success
	SWI_EMIOTA_STATUS_ERROR_DISCONNECT,	        // 1:status error disconnect
	SWI_EMIOTA_STATUS_ERROR_NOT_ALLOWED,	      // 2:status error iota session is not allowed
	SWI_EMIOTA_STATUS_ERROR_ALREADY_ACTIVE,	    // 3:status error iota sesstion is already in progress
	SWI_EMIOTA_STATUS_ERROR_CLIENT_ABORT,	      // 4:status error client aborted iota session
	SWI_EMIOTA_STATUS_ERROR_HTTP,	              // 5:status error HTTP
	SWI_EMIOTA_STATUS_ERROR_MIME,	              // 6:status error MIME
	SWI_EMIOTA_STATUS_ERROR_XML,	              // 7:status error XML
	SWI_EMIOTA_STATUS_ERROR_MMC,	              // 8:status error MMC
	SWI_EMIOTA_STATUS_ERROR_NOT_TRUSTED,	      // 9:status error not trusted domain
	SWI_EMIOTA_STATUS_ERROR_SESSION_TIMEOUT,    // 10:status error session timed out
	SWI_EMIOTA_STATUS_ERROR_UNKNOWN,	          // 11:status error unknown
	SWI_EMIOTA_STATUS_ERROR_INTERNAL,	          // 12:status error internal
	SWI_EMIOTA_STATUS_ERROR_NO_SERVICE,	        // 13:status error no service
	SWI_EMIOTA_STATUS_ERROR_ACTIVE_DATA_CALL,	  // 14:status error user is in active data call
	SWI_EMIOTA_STATUS_ERROR_ACTIVE_VOICE_CALL,	// 15:status error user is in active voice call
	SWI_EMIOTA_STATUS_ERROR_NO_DIGITAL_SERVICE,	// 16:status error user is no digital service ( roaming  mode )
	SWI_EMIOTA_STATUS_MAX,	                    // 17:iota status max
};



/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_EMIOTA_EVENT_ERR_CODE - Evnet type failure error code
//
// Purpose:	This is the enumeration of Embedded IOTA event failure error code.
//
// Members:	24 members see below for description
//
// Notes:	
//
///////////////////////////////////////////////////////////////////////////////////

enum SWI_EMIOTA_EVENT_ERR_CODE 
{
	SWI_EMIOTA_ERR_MMC_DISCONNECT,      // 0:Normal Release (MMC "disconnect")
	SWI_EMIOTA_ERR_INVALID_VALREF,	    // 1:MMC_RESULT_INVALID_VALUEREF
	SWI_EMIOTA_ERR_CID_MISSING,				  // 2:MMC_RESULT_CID_MISSING
	SWI_EMIOTA_ERR_DLD_FAILED,	  			// 3:MMC_RESULT_DOWNLOAD_FAILED
	SWI_EMIOTA_ERR_RESERVED,			      // 4:reserved
	SWI_EMIOTA_ERR_INVALID_CONTENT,     // 5:MMC_RESULT_INVALID_CONTENT
	SWI_EMIOTA_ERR_USR_DENIED,		      // 6:MMC_RESULT_USER_DENIED
	SWI_EMIOTA_ERR_BAD_VALUE,		        // 7:MMC_RESULT_BAD_VALUE
	SWI_EMIOTA_ERR_TIMEOUT,             // 8:MMC_RESULT_TIMEOUT
	SWI_EMIOTA_ERR_NONEW_DOC, 			    // 9:MMC_RESULT_NEW_DOC_ARRIVED
	SWI_EMIOTA_ERR_DELETE_FAILED,		    // 10:MMC_RESULT_DELETE_FAILED
	SWI_EMIOTA_ERR_BAD_DATA,			      // 11:MMC_RESULT_BAD_DATA
	SWI_EMIOTA_ERR_DISPLAY_DISABLED,    // 12:MMC_RESULT_DISPLAY_DISABLED
	SWI_EMIOTA_ERR_WRITE_ONLY,		      // 13:MMC_RESULT_WRITE_ONLY
	SWI_EMIOTA_ERR_RESULT_ABORT,	      // 14:MMC_RESULT_ABORT
	SWI_EMIOTA_ERR_RESERVED1,			      // 15:reserved
	SWI_EMIOTA_ERR_BAD_OBJECT,		      // 16:MMC_RESULT_BAD_OBJECT
	SWI_EMIOTA_ERR_UNKNOWN_RESULT,      // 17:MMC_RESULT_UNKNOWN_ERROR
	SWI_EMIOTA_ERR_FILE_LOCKED,		      // 18:MMC_RESULT_FILE_LOCKED
	SWI_EMIOTA_ERR_FILE_OPEN, 		      // 19:MMC_RESULT_FILE_OPEN
	SWI_EMIOTA_ERR_CHECK_FAILED,	      // 20:MMC_RESULT_CHECK_FAILED
	SWI_EMIOTA_ERR_INVALID_SIZE,	      // 21:MMC_RESULT_INVALID_SIZE
	SWI_EMIOTA_ERR_INVALID_OFFSET,      // 22:MMC_RESULT_INVALID_OFFSET
	SWI_EMIOTA_ERR_DEVICE_BUSY,		      // 23:MMC_RESULT_DEVICE_BUSY
	SWI_EMIOTA_ERR_RESERVED2,			      // 24:reserved
                                      //For HTTP Error - actual HTTP error code so other than these error actual http
                                      // errror codes should be captured
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_IOTA_Status - IOTA Status data structure
//
// Purpose:     This data structure is used to hold the IOTA status.
//
// Members:		sizeStruct		- size of this structure
//				iEvent			-
//				iEventStatus	-
//				iReason			-
//				iExtendedReason	-
//
// Notes:	    
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct
{
    SWI_U32						sizeStruct;
	SWI_U16						iEvent;
	SWI_U16						iEventStatus; 
	SWI_U16						iReason;
	SWI_U16						iExtendedReason;
} SWI_STRUCT_IOTA_Status;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_CallByteCounter - Byte Counter notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_CallByteCounter.  Refer to the description of
//				SWI_NOTIFY_CallByteCounter for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				nTxBytes					- bytes transmitted
//				nRxBytes					- bytes received
//
// Notes:	    The counters measure traffic over the local (host/
//				modem) interface. The counter resets when the
//				call is disconnected.
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct
{
    SWI_U32				sizeStruct;     
    SWI_U32				nTxBytes;
    SWI_U32				nRxBytes;
} SWI_STRUCT_CallByteCounter;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_CallConnecting - Call Connecting notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_CallConnecting.  Refer to the description of
//				SWI_NOTIFY_CallConnecting for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				eType						- Type of call being connected.
//											  See SWI_TYPE_CallType for details.
//				eSource				  		- This indicates if the connection was
//											  requested by AT command or CnS (API)
//											- See SWI_TYPE_CallSource for details.
//				szNum			 			- Reports the standard caller ID of
//											  incoming calls (if available from 
//											  the network).
//											  Use SWI_NOTIFY_CallCallerID to determine
//											  CallerID prior to connecting.
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct
{
    SWI_U32					sizeStruct;
	SWI_TYPE_CallType		eType;
	SWI_TYPE_CallSource		eSource;
    SWI_U8					szNum[LENGTH_CallNumber + 1];   
} SWI_STRUCT_CallConnecting;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_CallConnected - Call Connected notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_CallConnected.  Refer to the description of
//				SWI_NOTIFY_CallConnected for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				eState						- Call State bit mask.  
//											  See SWI_TYPE_CallState for details 
//				nSo							- The service option of the call. 
//											  This should be ignored. 
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct
{
    SWI_U32					sizeStruct;
	SWI_TYPE_CallState		eState;
	SWI_U32					nSo;
} SWI_STRUCT_CallConnected;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_CallIncoming - Call Incoming notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_CallIncoming.  Refer to the description of
//				SWI_NOTIFY_CallIncoming for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				eType						- Call Incoming call type.  
//											  See SWI_TYPE_CallType for details 
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct
{
    SWI_U32					sizeStruct;
	SWI_TYPE_CallType		eType;
} SWI_STRUCT_CallIncoming;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_CallCallerID - Caller ID notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_CallCallerID.  Refer to the description of
//				SWI_NOTIFY_CallCallerID for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				szNum						- Caller ID string
//
// Notes:	    The Caller ID string is provided by the network.
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct
{
    SWI_U32			sizeStruct;     
    SWI_U8			szNum[LENGTH_CallNumber + 1];   
} SWI_STRUCT_CallCallerID;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_CallExtendedCallerID - Extended Caller ID notification 
//				data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_CallExtendedCallerID.  Refer to the description of
//				SWI_NOTIFY_CallExtendedCallerID for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				szNum						- Extended Caller ID string
//
// Notes:	    The Extended Caller ID string is provided by the network.
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct
{
    SWI_U32			sizeStruct;   
    SWI_U8			szNum[LENGTH_CallExtendedNumber + 1];   
} SWI_STRUCT_CallExtendedCallerID;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_CallDisconnected - Call Disconnected notification 
//				data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_CallDisconnected.  Refer to the description of
//				SWI_NOTIFY_CallDisconnected for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				eState						- Call State bit mask.  
//											  See SWI_TYPE_CallState for details.
//				eReason						- The reason the call was disconnected.
//											  See SWI_TYPE_EndReason for details.
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct
{
    SWI_U32					sizeStruct;    
	SWI_TYPE_CallState		eState;
	SWI_TYPE_EndReason		eReason;
} SWI_STRUCT_CallDisconnected;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_CallError - Call Error enumeration
//
// Purpose:     This enumerates the call errors provided by the notification
//				SWI_NOTIFY_CallError.
//
// Members:  	SW_CALL_ERROR_None			- No errors found
//
//				SW_CALL_ERROR_InvalidClientID
//											- Invalid client ID - null or not initialized
//
//				SW_CALL_ERROR_BadCallTypeParameter
//											- Bad call type parameter
//
//				SW_CALL_ERROR_BadServiceTypeParameter
//											- Bad service type parameter
//
//				SW_CALL_ERROR_BadServiceOptionParameter
//											- Bad service option parameter
//
//				SW_CALL_ERROR_ExpectingNumber
//											- Expecting a number to be provided via the number parameter
//
//				SW_CALL_ERROR_NumberLengthGreaterThanZeroBufferNull
//											- Number length is > 0, but number buffer points to NULL
//
//				SW_CALL_ERROR_InvalidDigitsNumberBuffer
//											- Invalid digits found in number buffer
//
//				SW_CALL_ERROR_OutOfRangeNumberLength
//											- Out of range value found in number length field
//
//				SW_CALL_ERROR_AlphaLengthGreaterThanZeroBufferNull
//											- Alpha length is > 0, but alpha buffer points to NULL
//
//				SW_CALL_ERROR_OutOfRangeAlphaLength
//											- Out of range value found in alpha length field
//
//				SW_CALL_ERROR_InvalidOtaspActivationCode
//											- Invalid OTASP activation code
//
//				SW_CALL_ERROR_PhoneOffline	- Phone is offline
//
//				SW_CALL_ERROR_PhoneCdmaLocked
//											- Phone is CDMA locked
//
//				SW_CALL_ERROR_ClientSendingFlasForUnsupportdFlashCall
//											- Client tried to send a flash while a call that not supporting flashes is in progress
//
//				SW_CALL_ERROR_DialedNumberNotPermitted
//											- Dialed number is not allowed under the current origination restriction
//
//				SW_CALL_ERROR_NonE911CallWhileE911PreferenceInEffect
//											- Client tried to originate a NONE E911 call while E911 mode preference is in effect
//
//				SW_CALL_ERROR_InvalidCmdWhilePhoneInUse
//											- Can't perform the command in question while phone is in-use
//
//				SW_CALL_ERROR_ServiceTypeNotSupportedByPhonePrl
//											- Client originated with service type that is currently not supported by the phone/PRL
//
//				SW_CALL_ERROR_ClientAnsweredWithWrongCallType
//											- Client answered with inappropriate call type relative to the type of the incoming call
//
//				SW_CALL_ERROR_CmdInvalidForCurrentState
//											- The command in question is invalid in the current call state 
//
//				SW_CALL_ERROR_CmdInvalidForCurrentPhoneServingState
//											- The command in question is invalid in the current Phone serving state 
//
//				SW_CALL_ERROR_NoServiceFoundForAutomatic
//											- no valid service found for origination with AUTOMATIC or CDMA_AUTOMATIC service type
//
//				SW_CALL_ERROR_ClientCannotAnswerIncomingCall
//											- Client is not allowed to answer the incoming call
//
//				SW_CALL_ERROR_BadPrivacyPref
//											- Bad privacy preference setting
//
//				SW_CALL_ERROR_NoAvailableCmdBuffers
//											- No available CM command buffers to queue the command
//
//				SW_CALL_ERROR_CommunicationProblemsWithMc
//											- Communication problems with MC 
//
//				SW_CALL_ERROR_Unspecified	- A problem other than the above was found
//				
// 	    
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SW_CALL_ERROR_None,
	SW_CALL_ERROR_InvalidClientID,
	SW_CALL_ERROR_BadCallTypeParameter,
	SW_CALL_ERROR_BadServiceTypeParameter,
	SW_CALL_ERROR_BadServiceOptionParameter,
	SW_CALL_ERROR_ExpectingNumber,
	SW_CALL_ERROR_NumberLengthGreaterThanZeroBufferNull,
	SW_CALL_ERROR_InvalidDigitsNumberBuffer,
	SW_CALL_ERROR_OutOfRangeNumberLength,
	SW_CALL_ERROR_AlphaLengthGreaterThanZeroBufferNull,
	SW_CALL_ERROR_OutOfRangeAlphaLength,
	SW_CALL_ERROR_InvalidOtaspActivationCode,
	SW_CALL_ERROR_PhoneOffline,
	SW_CALL_ERROR_PhoneCdmaLocked,
	SW_CALL_ERROR_ClientSendingFlasForUnsupportdFlashCall,
	SW_CALL_ERROR_DialedNumberNotPermitted,
	SW_CALL_ERROR_NonE911CallWhileE911PreferenceInEffect,
	SW_CALL_ERROR_InvalidCmdWhilePhoneInUse,
	SW_CALL_ERROR_ServiceTypeNotSupportedByPhonePrl,
	SW_CALL_ERROR_ClientAnsweredWithWrongCallType,
	SW_CALL_ERROR_CmdInvalidForCurrentState,
	SW_CALL_ERROR_CmdInvalidForCurrentPhoneServingState,
	SW_CALL_ERROR_NoServiceFoundForAutomatic,
	SW_CALL_ERROR_ClientCannotAnswerIncomingCall,
	SW_CALL_ERROR_BadPrivacyPref,
	SW_CALL_ERROR_NoAvailableCmdBuffers,
	SW_CALL_ERROR_CommunicationProblemsWithMc,
	SW_CALL_ERROR_Unspecified
} SWI_TYPE_CallError;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_CallCmd - Call Command enumeration
//
// Purpose:     This enumerates the call commands provided by the notification
//				SWI_NOTIFY_CallError.
//
// Members:  	SWI_CALL_CMD_None			- No command
//				SWI_CALL_CMD_Orig			- Call origination command
//				SWI_CALL_CMD_Answer	 		- Call answer command
//				SWI_CALL_CMD_End			- Call end command
//				SWI_CALL_CMD_Flash			- Flash command
//				SWI_CALL_CMD_PrivacyPref	- Privacy Pref. Command
//				SWI_CALL_CMD_InfoGet	 	- Info command
//				SWI_CALL_CMD_Hold			- Hold command
// 	    
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_CALL_CMD_Orig,
	SWI_CALL_CMD_Answer,
	SWI_CALL_CMD_End,
	SWI_CALL_CMD_Flash,
	SWI_CALL_CMD_PrivacyPref,
	SWI_CALL_CMD_InfoGet,
	SWI_CALL_CMD_Hold,
	SWI_CALL_CMD_None = 0x00FF
} SWI_TYPE_CallCmd;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_CallError - Call Error notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_CallError.  Refer to the description of
//				SWI_NOTIFY_CallError for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				eCmd						- The command or action being used
//											  when the error occured.
//										  	  See SWI_TYPE_CallCmd for details.
//				eError						- The nature of the error.
//											  See SWI_TYPE_CallError for details.
//				eSource						- This indicates if the action was
//											  requested by AT command or CnS (API)
//											  See SWI_TYPE_CallSource for details.
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct
{
    SWI_U32					sizeStruct;    
	SWI_TYPE_CallCmd		eCmd;
	SWI_TYPE_CallError		eError;
    SWI_TYPE_CallSource		eSource;
} SWI_STRUCT_CallError;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_CallDormant - Dormant state notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_CallDormant.  Refer to the description of
//				SWI_NOTIFY_CallDormant for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				eState						- Call State bit mask.  
//											  See SWI_TYPE_CallState for details
//				eReason						- Not Used.
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct
{
    SWI_U32					sizeStruct;
	SWI_TYPE_CallState		eState;
	SWI_TYPE_EndReason		eReason;
} SWI_STRUCT_CallDormant;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_OTASPState - OTASP State enumeration
//
// Purpose:     This enumeration type identifies the available OTASP progress
//				states.
//
// Members:  	SWI_OTASP_STATE_PROG_START	- Programming started
//				SWI_OTASP_STATE_SPL_UNLOCK	- SPL unlock - required to access certain parameters
//				SWI_OTASP_STATE_AKEY_EXCHG	- AKey exchange - Authentication key has been exchanged
//				SWI_OTASP_STATE_SSD_UPDT	- Shared Secret Data has been updated
// 				SWI_OTASP_STATE_NAM_DL		- New NAM parameters have been downloaded
//				SWI_OTASP_STATE_MDN_DL		- New MDM has been downloaded  
//				SWI_OTASP_STATE_IMSI_DL		- IMSI has been downloaded  
// 				SWI_OTASP_STATE_PRL_DL		- PRL has been downloaded  
//				SWI_OTASP_STATE_COMMIT		- Newly downloaded parameters have been transferred to NV-RAM
//				SWI_OTASP_STATE_PROG_END	- Programming ended
//
// Notes:	    A successful OTASP session assumes no failures for any states,
//				and a successful commit.
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_OTASP_STATE_PROG_START		= 0x0000,
	SWI_OTASP_STATE_SPL_UNLOCK		= 0x0001,
	SWI_OTASP_STATE_AKEY_EXCHG		= 0x0002,
	SWI_OTASP_STATE_SSD_UPDT		= 0x0003,
	SWI_OTASP_STATE_NAM_DL			= 0x0004,
	SWI_OTASP_STATE_MDN_DL			= 0x0005,
	SWI_OTASP_STATE_IMSI_DL			= 0x0006,
	SWI_OTASP_STATE_PRL_DL			= 0x0007,
	SWI_OTASP_STATE_COMMIT			= 0x0008,
	SWI_OTASP_STATE_PROG_END		= 0x0009
} SWI_TYPE_OTASPState;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_OTASPState - OTASP State notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_OTASPState.  Refer to the description of
//				SWI_NOTIFY_OTASPState for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				eState						- The current stage in the OTASP
//											  process.
//										  	  SWI_TYPE_OTASPState for details.
//				nSuccess					- Indicates the success (1) or failure (0)
//											  of the stage indicated by eState.
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct
{
    SWI_U32					sizeStruct;     
	SWI_TYPE_OTASPState		eState;
	SWI_U16					nSuccess;
} SWI_STRUCT_OTASPState;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_Privacy - Privacy state enumeration
//
// Purpose:     The data enumerates as privacy either on or off
//
// Members:  	SWI_PRIVACY_Off				- Privacy off
// 	    		SWI_PRIVACY_On				- Privacy on
// 	    
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_PRIVACY_Off	= 0,
	SWI_PRIVACY_On
} SWI_TYPE_Privacy;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_CallPrivacy - Privacy notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_CallPrivacy.  Refer to the description of
//				SWI_NOTIFY_CallPrivacy for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				eMode						- Privacy state.  See
//											  SWI_TYPE_Privacy for details.
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct
{
    SWI_U32				sizeStruct;     
	SWI_TYPE_Privacy	eMode;
} SWI_STRUCT_CallPrivacy;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_E911Mode - Emergency 911 mode enumeration
//
// Purpose:     This enumerates the Emergency 911 modes available
//
// Members:  	SWI_E911_MODE_Off			- E911 mode off
// 	    		SWI_E911_MODE_On			- E911 mode on
// 	    
// Notes:	    When in E911 mode, some modem functionality
//				may not be available. The modem can forced out
//				of E911 mode using SwiSetE911Mode.
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_E911_MODE_Off	= 0,
	SWI_E911_MODE_On
} SWI_TYPE_E911Mode;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_E911Mode - Emergency 911 notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_E911Mode.  Refer to the description of
//				SWI_NOTIFY_E911Mode for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				eMode						- Emergency 911 mode.  See
//											  SWI_TYPE_E911Mode for details.
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct
{
    SWI_U32					sizeStruct;
	SWI_TYPE_E911Mode		eMode;
} SWI_STRUCT_E911Mode;

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_Reset - Reset notification data structure
//
// Purpose:	This data structure is used as a member of the notification
//			SWI_NOTIFY_Reset.  Refer to the description of 
//			SWI_NOTIFY_Reset for more detail.
//
// Members:	sizeStruct			- size of this structure
//
// Notes:	No data.
//
////////////////////////////////////////////////////////////////////////////////
typedef struct
{
	SWI_U32					sizeStruct;
	// no data
} SWI_STRUCT_Reset;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_PowerSaveEnter - PowerSave (Enter) notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_PowerSaveEnter.  Refer to the description of
//				SWI_NOTIFY_PowerSaveEnter for more detail.
//
// Members:  	sizeStruct					- size of this structure
//
// Notes:	    No data.
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct
{
	SWI_U32					sizeStruct; 
	// no data
} SWI_STRUCT_PowerSaveEnter;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_PowerSaveExit - PowerSave (Exit) notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_PowerSaveExit.  Refer to the description of
//				SWI_NOTIFY_PowerSaveExit for more detail.
//
// Members:  	sizeStruct					- size of this structure
//
// Notes:	    No data.
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct
{
	SWI_U32					sizeStruct;
	// no data
} SWI_STRUCT_PowerSaveExit;

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_HeadsetState - headset state
//
// Purpose:	This enumeration contains the headset states
//
// Members:	SWI_HEADSET_Unplugged	- The headset is unplugged.
//
//			SWI_HEADSET_Plugged		- The headset is plugged in.
//
// Notes:	None
//
///////////////////////////////////////////////////////////////////////////////////
typedef enum
{
    SWI_HEADSET_Unplugged,			//unplugged
    SWI_HEADSET_Plugged				//plugged
} SWI_TYPE_HeadsetState;

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_HeadsetState - headset state
//
// Purpose:	This structure is used by the SWI_NOTIFY_HeadsetState notification 
//			to indicate the state of the headset: plugged in or not.	
//
// Members:	sizeStruct		- size of this structure
//
//			eHeadsetState	- currect headset state
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
typedef struct
{
    SWI_U32					sizeStruct;        //size of this structure
    SWI_TYPE_HeadsetState	eHeadsetState;     //Currect headset state
} SWI_STRUCT_HeadsetState;

typedef enum
{
	SWI_FW_Upgrade_Available,		// Modem firmware upgrade is available
	SWI_PRL_Upgrade_Available,		// PRL upgrade is available
	SWI_No_Upgrade_Required,		// No need to do upgrade
	SWI_No_Upgrade_Available,		// Modem Upgrade package not available
	SWI_Invalid_Upgrade_Path,		// Input upgrade path is not valid
	SWI_Small_File_Name_Buffer,		// File name buffer is too small
	SWI_ProdID_Not_Supported,		// ProductID cannot be translated to product name, e.g. 12 is PC5220.
	SWI_FW_SKU_Not_Set,				// FW SKU not set in the mode. MdmUpgrade check cannot be performed.
	SWI_Error_Unknown				// Some errors caused by calling other SwiApis, e.g. SwiGetFirmwareVersion() fails.
} SWI_TYPE_MdmUpgradeCheck;

typedef struct SWI_STRUCT_MeidEsn
{
	SWI_U32						sizeStruct;     //size of this structure
	SWI_U16						nMeidEnabled;	// TRUE - MEID/pESN is used in the modem; FALSE - tESN is used in the modem
	SWI_U16						nMeidPresent;	// TRUE - MEID provisioned in the modem; FALSE - MEID has never been written
	SWI_U32						nMeidHigh;		// (high word of qword) 56 bits of MEID if MEID is provisioned; otherwise, all 0's
	SWI_U32						nMeidLow;		// (low word of qword) 56 bits of MEID if MEID is provisioned; otherwise, all 0's
	SWI_U32						nPEsn;			// 32 bits of pESN if MEID  is provisioned; otherwise, all 0's
	SWI_U16						nTEsnPresent;	// TRUE - tESN provisioned in the modem; FALSE - tESN has never been written
	SWI_U32						nEsn;			// 32 bits of tESN if tESN provisioned; otherwise, all 0's
} SWI_STRUCT_MeidEsn;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_CarrierID - Carrier ID enumeration
//
// Purpose:     The enumerated values identify the various
//				carriers a modem may be configured for
//
// Members:  	SWICARRIER_UNDEFINED		- Not defined
//				SWICARRIER_RESERVED			- (reserved)
//				SWICARRIER_AC555_GENERIC	- Generic
//				SWICARRIER_AC550_SPRINT		- Sprint
//				SWICARRIER_AC555_BELL		- Bell Mobility
//				SWICARRIER_AC555_TELUS		- Telus
//				SWICARRIER_AC555_VZW		- Verizon Wireless
//				SWICARRIER_AC555_WESTERNWIRELESS
//											- Western Wireless
//				SWICARRIER_AC555_SMARTCOM	- SmartCom
//				SWICARRIER_AC555_ALLTEL		- AllTel
//				SWICARRIER_AC555_USCELLULAR	- US Cellular
//				SWICARRIER_SB550T_SPRINT	- (Thera) Sprint
//				SWICARRIER_SB555T_BELL		- (Thera) Bell Mobility
//				SWICARRIER_SB555T_TELUS		- (Thera) Telus
//				SWICARRIER_SB555T_VZW		- (Thera) Verizon Wireless
//				SWICARRIER_AC555_CHINAUNICOM
//											- China Unicom
//				SWICARRIER_AC555_HUTCHISONTHAILAND
//											- Hutchison Thailand
//				SWICARRIER_AC555_MOVILNET	- MovilNet
//				SWICARRIER_AC555_TARJETAS_IUSACELL_MEXICO
//											- Iusacell Mexico
//				SWICARRIER_AC555_TELECOMNEWZEALAND
//											- Telecom NewZealand
//				SWICARRIER_AC555_RELIANCE	- Reliance
//				SWICARRIER_AC555_TELSTRA	- Telstra
//				SWICARRIER_AC555_MOBILITYCANADA
//											- Mobility Canada
//				SWICARRIER_AC555_VZW_PUERTO_RICO
//											- Verizon Wireless Puerto Rico
//				SWICARRIER_AC555_PELEPHONE	- Pelephone
//				SWICARRIER_AC555_BELL_CANADA
//											- Bell Canada
//				SWICARRIER_AC555_INDOSOL_INDONESIA
//											- Indosol
//				SWICARRIER_AC555_MIDWEST_WIRELESS
//											- MidWest Wireless
//        SWI_CARRIER_AC555_BELL_SOUTH_CHILE,
//        SWI_CARRIER_AC555_BELL_SOUTH_PANAMA,
//        SWI_CARRIER_AC555_TATA
//        
//
//
//
//
// Notes:	    The Carrier IDs no longer represent the Product type (AC555 vs AC580).
//            supported.  The SBXXX items are kept only for backwards compatibility.
//            (ie.  The AC580 for Verizon carrier ID will be SWI_CARRIER_AC555_VZW)
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_CARRIER_UNDEFINED						= -1,
	SWI_CARRIER_RESERVED						= 0,
	SWI_CARRIER_AC555_GENERIC,
	SWI_CARRIER_AC550_SPRINT,
	SWI_CARRIER_AC555_BELL,
	SWI_CARRIER_AC555_TELUS,
	SWI_CARRIER_AC555_VZW,
	SWI_CARRIER_AC555_WESTERNWIRELESS,
	SWI_CARRIER_AC555_SMARTCOM,
	SWI_CARRIER_AC555_ALLTEL,
	SWI_CARRIER_AC555_USCELLULAR,
	SWI_CARRIER_SB550T_SPRINT,
	SWI_CARRIER_SB555T_BELL,
	SWI_CARRIER_SB555T_TELUS,
	SWI_CARRIER_SB555T_VZW,
	SWI_CARRIER_AC555_CHINAUNICOM,
	SWI_CARRIER_AC555_HUTCHISONTHAILAND,
	SWI_CARRIER_AC555_MOVILNET,
	SWI_CARRIER_AC555_TARJETAS_IUSACELL_MEXICO,
	SWI_CARRIER_AC555_TELECOMNEWZEALAND,
	SWI_CARRIER_AC555_RELIANCE,
	SWI_CARRIER_AC555_TELSTRA,
	SWI_CARRIER_AC555_MOBILITYCANADA,
	SWI_CARRIER_AC555_VZW_PUERTO_RICO,
	SWI_CARRIER_AC555_PELEPHONE,
	SWI_CARRIER_AC555_BELL_CANADA,
	SWI_CARRIER_AC555_INDOSOL_INDONESIA,
	SWI_CARRIER_AC555_MIDWEST_WIRELESS,
	SWI_CARRIER_AC555_BELL_SOUTH_CHILE,
	SWI_CARRIER_AC555_BELL_SOUTH_PANAMA,
	SWI_CARRIER_AC555_TATA
} SWI_TYPE_CarrierID;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_DistributorID - Distributor ID enumeration
//
// Purpose:     The enumerated values identify the various
//				distributors a modem may be configured for
//
// Members:		SWI_DISTRIBUTOR_UNDEFINED
//				SWI_DISTRIBUTOR_NONE
//				SWI_DISTRIBUTOR_SIERRA_WIRELESS
//				SWI_DISTRIBUTOR_EASTCOM
//				SWI_DISTRIBUTOR_TONGFANG
//				SWI_DISTRIBUTOR_ZTE
//				SWI_DISTRIBUTOR_CHINA_PUTIAN
//				SWI_DISTRIBUTOR_NCL
//				SWI_DISTRIBUTOR_SHANGHAI_BELL
//				SWI_DISTRIBUTOR_SK_EARTHLINK
//				SWI_DISTRIBUTOR_US_LEC
//				SWI_DISTRIBUTOR_COMCAST
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_DISTRIBUTOR_UNDEFINED			= -1,
	SWI_DISTRIBUTOR_NONE				= 0,
	SWI_DISTRIBUTOR_SIERRA_WIRELESS		= 1,
	SWI_DISTRIBUTOR_EASTCOM				= 2,
	SWI_DISTRIBUTOR_TONGFANG			= 3,
	SWI_DISTRIBUTOR_ZTE					= 4,
	SWI_DISTRIBUTOR_CHINA_PUTIAN		= 5,
	SWI_DISTRIBUTOR_NCL					= 6,
	SWI_DISTRIBUTOR_SHANGHAI_BELL		= 7,
	SWI_DISTRIBUTOR_SK_EARTHLINK		= 8,
	SWI_DISTRIBUTOR_US_LEC				= 9,
	SWI_DISTRIBUTOR_COMCAST				= 10,
	SWI_DISTRIBUTOR_IWIRELESS			= 11,
} SWI_TYPE_DistributorID;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_PRI_VoiceDataMask - Voice/Data Support mask bit enumeration
//
// Purpose:     The enumerated mask bits identifies the voice/data features
//				supported by the modem
//
// Members:  	SWI_PRI_DATA_1X				- 1x data calls supported
//				SWI_PRI_DATA_IS95			- IS95 (QNC/Fax/Dialup) data calls supported
//				SWI_PRI_DATA_AUTOCONNECT	- Internal use for Watcher only
//				SWI_PRI_VOICE				- Voice calls supported
//				SWI_PRI_VOICE				- Internal Use
//				SWI_PRI_VD_ALL				- Internal Use
//				SWI_PRI_VD_MASK_ENABLED		- Internal Use
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_PRI_VoiceDataMask
{
	SWI_PRI_DATA_1X						= 0x0001,
	SWI_PRI_DATA_IS95					= 0x0002,	
	SWI_PRI_DATA_AUTOCONNECT			= 0x0004,	
#if FUTURE_USE												// { bits 4-7 reserved for future use }
	SWI_PRI_DATA_						= 0x0008,
	SWI_PRI_DATA_						= 0x0010,
	SWI_PRI_DATA_						= 0x0020,
	SWI_PRI_DATA_						= 0x0040,
#endif
	SWI_PRI_VOICE						= 0x0080,  
	SWI_PRI_VD_ALL						= 0xFFFF,
	SWI_PRI_VD_MASK_ENABLED				= 0x8000	// Enabled bit (Internal use only)
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_Device - device types
//
// Purpose:	This enumerates the device type
//
// Members:	SWI_DEVICE_None		- none
//
//			SWI_DEVICE_AC300	- AC300
//
//			SWI_DEVICE_AC400	- AC400
//
//			SWI_DEVICE_AC55x	- AC55x
//
//			SWI_DEVICE_SB555	- SB555
//
//			SWI_DEVICE_AC710	- AC710
//
//			SWI_DEVICE_SB750	- SB750
//
//			SWI_DEVICE_AC550	- AC550
//
//			SWI_DEVICE_AC575	- AC575
//			
//			SWI_DEVICE_MP555	- MP555
//
//			SWI_DEVICE_MP700	- MP700
//
//			SWI_DEVICE_PC3320	- PC Card 3320
//			
//			SWI_DEVICE_EM3420	- EM3420
//
//			SWI_DEVICE_PC3310	- PC Card 3310 RUIM
//
//			SWI_DEVICE_AC580	- PC Card AC580
//
//			SWI_DEVICE_PC5220	- PC Card 5220
//
//			SWI_DEVICE_EM5625	- EM5625
//		
//			SWI_DEVICE_MC5720	- MC5720	
//
//			SWI_DEVICE_EMMC5X	- EM & MC products
//
//			SWI_DEVICE_AC595	- AC595
//
//			SWI_DEVICE_MC5725	- MC5725
//
//			SWI_DEVICE_AC585U	- AC585U
// Notes:	None
//
//	TODO: Make these enums the USB Product ID
//
/////////////////////////////////////////////////////////////////////////////////

typedef enum
{
	SWI_DEVICE_None = 0,
	// Legacy ids
	SWI_DEVICE_EMMC5X = 18,	// Used as a "universal" match for SwiApiOpen()

	// PC Cards
	SWI_DEVICE_AC550,
	SWI_DEVICE_AC575,
	SWI_DEVICE_AC580,
	SWI_DEVICE_AC595,
	SWI_DEVICE_AC710 = 100,
	SWI_DEVICE_AC750,
	SWI_DEVICE_AC775,
	SWI_DEVICE_AC850,
	SWI_DEVICE_AC860,
	SWI_DEVICE_AC875,
	SWI_DEVICE_AC880,
	SWI_DEVICE_AC881,
	SWI_DEVICE_AC885,
	// Embedded Modules
	SWI_DEVICE_MC5720 = 200,
	SWI_DEVICE_MC5725,
	SWI_DEVICE_MC5727,
	SWI_DEVICE_MC5728,		//203
	SWI_DEVICE_MC8755 = 300,
	SWI_DEVICE_MC8765,
	SWI_DEVICE_MC8775,
	SWI_DEVICE_MC8780,
	SWI_DEVICE_MC8781,
	SWI_DEVICE_MC8785,
	SWI_DEVICE_EM5625 = 400,
	SWI_DEVICE_EM5725,
	SWI_DEVICE_EM8780 = 500,
	SWI_DEVICE_EM8781,
	SWI_DEVICE_M81A,
	SWI_DEVICE_M81B,
	// MP
	SWI_DEVICE_MP555 = 600,
	SWI_DEVICE_MP595,
	SWI_DEVICE_MP750 = 700,
	SWI_DEVICE_MP775,
	SWI_DEVICE_MP875,
	// ExpressCards
	SWI_DEVICE_AC597E = 1000,
	SWI_DEVICE_AC402E,     
	SWI_DEVICE_AC875E = 1100,
	SWI_DEVICE_AC880E,
	SWI_DEVICE_AC881E,
	SWI_DEVICE_AC885E,
	// USB Modems
	SWI_DEVICE_AC595U = 1200,
	SWI_DEVICE_COMPASS597,	// 1201
	SWI_DEVICE_USB598,		// 1202
	SWI_DEVICE_USB11,		// 1203
	SWI_DEVICE_AC875U = 1300,
	SWI_DEVICE_AC880U,
	SWI_DEVICE_AC881U,
	SWI_DEVICE_AC885U,

	// Mass Storage
	SWI_DEVICE_MassStorage = 2000,

	SWI_DEVICE_END
} SWI_TYPE_Device;

#if 0	// old SWI_TYPE_Device enum values; no longer valid.
typedef enum
{
	SWI_DEVICE_None = 0,
	SWI_DEVICE_AC300,
	SWI_DEVICE_AC400,
	SWI_DEVICE_AC55x,
	SWI_DEVICE_SB555,
	SWI_DEVICE_AC710,	//5
	SWI_DEVICE_SB750,
	SWI_DEVICE_AC550,
	SWI_DEVICE_AC575,
	SWI_DEVICE_MP555,
	SWI_DEVICE_MP700,	//10
	SWI_DEVICE_PC3320,
	SWI_DEVICE_EM3420,
	SWI_DEVICE_PC3310,
	SWI_DEVICE_AC580,
	SWI_DEVICE_PC5220,	//15
	SWI_DEVICE_EM5625, 
	SWI_DEVICE_MC5720,
	SWI_DEVICE_EMMC5X,
	SWI_DEVICE_AC595,
	SWI_DEVICE_MC5725,	//20
	SWI_DEVICE_AC585U,
	SWI_DEVICE_AC597E,
	SWI_DEVICE_AC595U,
	SWI_DEVICE_EM5725,
	SWI_DEVICE_AC597,	// 25
	SWI_DEVICE_C597 = SWI_DEVICE_AC597,		// 25

	//SWI_DEVICE_T598,	// TODO: Add this properly
	//SWI_DEVICE_T11,	// TODO: Add this properly

	SWI_DEVICE_AC881U,

	SWI_DEVICE_END
} SWI_TYPE_Device;
#endif // old SWI_TYPE_Device enum values

////////////////////////////////////////////////////////////////////////////////
//
// Name:       SWI_STRUCT_POWER - Radio power State structure
//
// Purpose:    Defines the Software/Firmware Radio Power States.
//
// Members:    mode - radio power mode; used for setting and retrieving
//             reason - 
//             request - notification where modem requests a radio power mode
//             requestReason - why the modem is requesting a radio power mode change
//
// Notes:      None.
//
////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_POWER_MODE_LOW					= 0x00,
	SWI_POWER_MODE_FULL,				//0x01
	SWI_POWER_MODE_OFFLINE,				//0x02
	SWI_POWER_MODE_POWERING_OFF,		//0x03
	SWI_POWER_MODE_RX_ONLY,				//0x04 New mode
} SWI_TYPE_POWER_MODE;

#define	SWI_BITMASK_POWER_REASON_W_DISABLE		0x0001
#define	SWI_BITMASK_POWER_REASON_USER_REQ		0x0002
#define	SWI_BITMASK_POWER_REASON_TEMPERATURE	0x0004
#define	SWI_BITMASK_POWER_REASON_VOLTAGE		0x0008
typedef SWI_U16 SWI_BITMASK_POWER_REASON;
	
typedef enum
{
	SWI_POWER_REQUEST_NONE,				//0x00
	SWI_POWER_REQUEST_SHUTDOWN,			//0x01
} SWI_TYPE_POWER_REQUEST;

typedef enum
{
	SWI_POWER_REQUEST_REASON_NONE,		//0x00
	SWI_POWER_REQUEST_REASON_TEMP,		//0x01
	SWI_POWER_REQUEST_REASON_VOLTAGE,	//0x02
	SWI_POWER_REQUEST_REASON_NETWORK,	//0x03
	SWI_POWER_REQUEST_REASON_OTHER,		//0x04
} SWI_TYPE_POWER_REQUEST_REASON;

	
typedef struct
{
	SWI_U32							sizeStruct;
	SWI_TYPE_POWER_MODE				mode;
	SWI_BITMASK_POWER_REASON		reason;
	SWI_TYPE_POWER_REQUEST			request;		// Only valid in notification
	SWI_TYPE_POWER_REQUEST_REASON	requestReason;	// Only valid in notification
} SWI_STRUCT_POWER;

typedef struct
{
	SWI_U16	error;				// 0 => failure; 1 => success
	SWI_U16	wimaxOperatingMode;	// R/W; type: SWI_TYPE_WIMAX_OP_MODE
} SWI_STRUCT_WIMAX_OPERATING_MODE;
	
//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_Power - Power State enumeration
//
// Purpose:     Defines the Software/Firmware Power States.
//
// Members:    SWI_TYPE_PowerFull,      - Turn the radio on (after RFPowerOff)
//             SWI_TYPE_PowerOffline    - modem is in offline state. Same as SwiSetModemOffline
//             SWI_TYPE_PowerReset      - modem is reset. For command part, calling
//                                        SwiPowerControl (SET, SWI_TYPE_PowerReset) is
//                                        the same as SwiResetModem
//             SWI_TYPE_PowerOff        - power off (used to indicate NDIS shutdown)
//             SWI_TYPE_PowerSystemOff  - Request to close SWI because system goes
//                                          to S3, S4 and S5 state (standby or hibernate)
//             SWI_TYPE_RFPowerOff      - Turn the radio off, a kind of STICKY offline
//
// Notes:      None.
//
///////////////////////////////////////////////////////////////////
typedef enum
{
  SWI_TYPE_PowerFull		= 0,
  SWI_TYPE_PowerOffline		= 1,
  SWI_TYPE_PowerReset		= 2,
  SWI_TYPE_PowerOff			= 3,  
  SWI_TYPE_PowerSystemOff	= 4,
  SWI_TYPE_RFPowerOff		= 5
} SWI_TYPE_Power;

typedef enum
{
  POWER_MODE_LOW,
  POWER_MODE_ONLINE,
} radio_power_mode_enum;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_SidNid - SID/NID pair structure
//
// Purpose:     This structure is used as a member of 
//				SWI_STRUCT_HomeSidNid.
//
// Members:  	Sid				- SID value
//				Nid				- NID value
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct SWI_STRUCT_SidNid
{
	SWI_U16 Sid;
	SWI_U16 Nid;
} SWI_STRUCT_SidNid;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_HomeSidNid - Home SID/NID pairs structure
//
// Purpose:     This structure is used to report (SwiPstGetHomeSidNid) or set
//              (SwiPstSetHomeSidNid) the home (non-roaming)
//              SID / NID table for an account profile.
//
// Members:  	SidNid				- SID NID pair array.  See
//									  SWI_STRUCT_SidNid for details
//
// Notes:	    The table supports twenty entries.
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct SWI_STRUCT_HomeSidNid
{
	SWI_STRUCT_SidNid SidNid[20];
} SWI_STRUCT_HomeSidNid;

//////////////////////////////////////////////////////////////////////////////////
//
// SMS Messaging
//
// CDMA2000 1X modems can send and receive
// SMS messages. To handle SMS messages, there
// are many data types and structures involved.
// Most of these relate to header content. The
// details of the parameters in the SMS header are
// defined in the CDMA specification and are
// beyond the scope of this manual.
//
// Consult the documentation for a discussion of the SMS message handling process.
//
//////////////////////////////////////////////////////////////////////////////////

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_SMS_Status - status of SMS messages on the modem
//
// Purpose:     This structure reports the number of SMS
//				messages in each of the three buffers in the
//				modem: urgent, regular, and voice.
//
// Members: 	sizeStruct			- size of this structure
//
//				cntUrgentMsg		- urgent msg count
//
//				cntRegularMsg		- regular msg count
//
//				cntVoiceMsg			- voice msg count
//
//
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct SWI_STRUCT_SMS_Status
{
	SWI_U32 sizeStruct;	   
	SWI_U16 cntUrgentMsg;  
	SWI_U16 cntRegularMsg; 
	SWI_U16 cntVoiceMsg;   
} SWI_STRUCT_SMS_Status;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_SMS_ErrorClass - SMS Send Error Class enumeration
//
// Purpose:     This enumeration identifies the possible Error Class values
//				that may be returned with the notification SWI_NOTIFY_SmsSendStatus
//
// Members: 	SWI_SMS_ERRORCLASS_NoError	- No Error 
//				SWI_SMS_ERRORCLASS_Reserved	- Reserved (Ignore)
//				SWI_SMS_ERRORCLASS_Temporary
//											- Temporary.  A retry is recommended.
//				SWI_SMS_ERRORCLASS_Permanent
//											- Permanent.  A retry is not recommened.
//
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum SWI_TYPE_SMS_ErrorClass
{
	SWI_SMS_ERRORCLASS_NoError,
	SWI_SMS_ERRORCLASS_Reserved,
	SWI_SMS_ERRORCLASS_Temporary,
	SWI_SMS_ERRORCLASS_Permanent
} SWI_TYPE_SMS_ErrorClass;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_SMS_CauseCode - SMS Send Cause Code enumeration
//
// Purpose:     This enumeration identifies the possible Cause Code values
//				that may be returned with the notification SWI_NOTIFY_SmsSendStatus
//
// Members: 	( Network problems )
//				SWI_SMS_CAUSECODE_AddressVacant 					
//				SWI_SMS_CAUSECODE_AddressTranslationFailure
//				SWI_SMS_CAUSECODE_NetworkResourceShortage
//				SWI_SMS_CAUSECODE_NetworkFailure
//				SWI_SMS_CAUSECODE_InvalidTeleserviceId
//				SWI_SMS_CAUSECODE_OtherNetworkProblem
//				SWI_SMS_CAUSECODE_OtherNetworkProblemMoreFirst		
//				SWI_SMS_CAUSECODE_OtherNetworkProblemMoreLast		
//				
//				( Terminal Problems )
//				SWI_SMS_CAUSECODE_NoPageResponse 					
//				SWI_SMS_CAUSECODE_DestinationBusy
//				SWI_SMS_CAUSECODE_NoAck
//				SWI_SMS_CAUSECODE_DestinationResourceShortage
//				SWI_SMS_CAUSECODE_SmsDeliveryPostponed
//				SWI_SMS_CAUSECODE_DestinationOutOfService
//				SWI_SMS_CAUSECODE_DestinationNoLongerAtThisAddress
//				SWI_SMS_CAUSECODE_OtherTerminalProblem
//				SWI_SMS_CAUSECODE_OtherTerminalProblemMoreFirst		
//				SWI_SMS_CAUSECODE_OtherTerminalProblemMoreLast		
//				SWI_SMS_CAUSECODE_SmsDeliveryPostponedMoreFirst		
//				SWI_SMS_CAUSECODE_SmsDeliveryPostponedMoreLast		
//				
//				( Radio Interface Problems )
//				SWI_SMS_CAUSECODE_Radio_If_Resource_Shortage		
//				SWI_SMS_CAUSECODE_RadioIfIncompatible
//				SWI_SMS_CAUSECODE_OtherRadioIfProblem
//				SWI_SMS_CAUSECODE_OtherRadioIfProblemMoreFirst		
//				SWI_SMS_CAUSECODE_OtherRadioIfProblemMoreLast		
//
//				( General Problems )
//				SWI_SMS_CAUSECODE_UnexpectedParmSize				
//				SWI_SMS_CAUSECODE_SmsOriginationDenied
//				SWI_SMS_CAUSECODE_SmsTerminationDenied
//				SWI_SMS_CAUSECODE_SupplServiceNotSupported
//				SWI_SMS_CAUSECODE_SmsNotSupported
//				SWI_SMS_CAUSECODE_Reserved101
//				SWI_SMS_CAUSECODE_MissingExpectedParm
//				SWI_SMS_CAUSECODE_MissingMandatoryParm
//				SWI_SMS_CAUSECODE_UnrecognizedParmValue
//				SWI_SMS_CAUSECODE_UnexpectedParmValue
//				SWI_SMS_CAUSECODE_UserDataSizeError
//				SWI_SMS_CAUSECODE_OtherGeneralProblems
//				SWI_SMS_CAUSECODE_OtherGeneralProblemsMoreFirst		
//				SWI_SMS_CAUSECODE_OtherGeneralProblemsMoreLast		
//				
//				( Internal SMS Cause Code (From the Mobile Station) )
//				SWI_SMS_CAUSECODE_DtcCallDisconnect  				
//				SWI_SMS_CAUSECODE_DtcCallError						
//				SWI_SMS_CAUSECODE_Ok								
//				SWI_SMS_CAUSECODE_WaitingForTlAck
//				SWI_SMS_CAUSECODE_OutOfResources
//				SWI_SMS_CAUSECODE_AccesTooLarge
//				SWI_SMS_CAUSECODE_DtcTooLarge
//				SWI_SMS_CAUSECODE_NetworkNotReady
//				SWI_SMS_CAUSECODE_PhoneNotReady
//				SWI_SMS_CAUSECODE_NotAllowedInAmps
//				SWI_SMS_CAUSECODE_CannotSendBroadcast
//				SWI_SMS_CAUSECODE_InvalidTransactionID
//				SWI_SMS_CAUSECODE_MsgNotSent
//				SWI_SMS_CAUSECODE_MsgBeingSent
//
// Notes:	    For detailed explanation of each of the codes, please refer to
//				the IS-41 SMS Standard.
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum SWI_TYPE_SMS_CauseCode
{
	// Network problems
	SWI_SMS_CAUSECODE_AddressVacant 					= 0x00,
	SWI_SMS_CAUSECODE_AddressTranslationFailure,
	SWI_SMS_CAUSECODE_NetworkResourceShortage,
	SWI_SMS_CAUSECODE_NetworkFailure,
	SWI_SMS_CAUSECODE_InvalidTeleserviceId,
	SWI_SMS_CAUSECODE_OtherNetworkProblem,
	SWI_SMS_CAUSECODE_OtherNetworkProblemMoreFirst		= 0x06,
	SWI_SMS_CAUSECODE_OtherNetworkProblemMoreLast		= 0x1F,

	// Terminal Problems
	SWI_SMS_CAUSECODE_NoPageResponse 					= 0x20,
	SWI_SMS_CAUSECODE_DestinationBusy,
	SWI_SMS_CAUSECODE_NoAck,
	SWI_SMS_CAUSECODE_DestinationResourceShortage,
	SWI_SMS_CAUSECODE_SmsDeliveryPostponed,
	SWI_SMS_CAUSECODE_DestinationOutOfService,
	SWI_SMS_CAUSECODE_DestinationNoLongerAtThisAddress,
	SWI_SMS_CAUSECODE_OtherTerminalProblem,
	SWI_SMS_CAUSECODE_OtherTerminalProblemMoreFirst		= 0x28,
	SWI_SMS_CAUSECODE_OtherTerminalProblemMoreLast		= 0x2F,
	SWI_SMS_CAUSECODE_SmsDeliveryPostponedMoreFirst		= 0x30,
	SWI_SMS_CAUSECODE_SmsDeliveryPostponedMoreLast		= 0x3F,

	// Radio Interface Problems
	SWI_SMS_CAUSECODE_Radio_If_Resource_Shortage		= 0x40,
	SWI_SMS_CAUSECODE_RadioIfIncompatible,
	SWI_SMS_CAUSECODE_OtherRadioIfProblem,
	SWI_SMS_CAUSECODE_OtherRadioIfProblemMoreFirst		= 0x43,
	SWI_SMS_CAUSECODE_OtherRadioIfProblemMoreLast		= 0x5F, 

	// General Problems
	SWI_SMS_CAUSECODE_UnexpectedParmSize				= 0x60,
	SWI_SMS_CAUSECODE_SmsOriginationDenied,
	SWI_SMS_CAUSECODE_SmsTerminationDenied,
	SWI_SMS_CAUSECODE_SupplServiceNotSupported,
	SWI_SMS_CAUSECODE_SmsNotSupported,
	SWI_SMS_CAUSECODE_Reserved101,
	SWI_SMS_CAUSECODE_MissingExpectedParm,
	SWI_SMS_CAUSECODE_MissingMandatoryParm,
	SWI_SMS_CAUSECODE_UnrecognizedParmValue,
	SWI_SMS_CAUSECODE_UnexpectedParmValue,
	SWI_SMS_CAUSECODE_UserDataSizeError,
	SWI_SMS_CAUSECODE_OtherGeneralProblems,
	SWI_SMS_CAUSECODE_OtherGeneralProblemsMoreFirst		= 0x6C,
	SWI_SMS_CAUSECODE_OtherGeneralProblemsMoreLast		= 0xFF,

	// Internal SMS Cause Code (From the Mobile Station)
	SWI_SMS_CAUSECODE_DtcCallDisconnect  				= 0x4000,
	SWI_SMS_CAUSECODE_DtcCallError						= 0x4001, 
	SWI_SMS_CAUSECODE_Ok								= 0x8000,
	SWI_SMS_CAUSECODE_WaitingForTlAck,
	SWI_SMS_CAUSECODE_OutOfResources,
	SWI_SMS_CAUSECODE_AccesTooLarge,
	SWI_SMS_CAUSECODE_DtcTooLarge,
	SWI_SMS_CAUSECODE_NetworkNotReady,
	SWI_SMS_CAUSECODE_PhoneNotReady,
	SWI_SMS_CAUSECODE_NotAllowedInAmps,
	SWI_SMS_CAUSECODE_CannotSendBroadcast,
	SWI_SMS_CAUSECODE_InvalidTransactionID,
	SWI_SMS_CAUSECODE_MsgNotSent,
	SWI_SMS_CAUSECODE_MsgBeingSent,
} SWI_TYPE_SMS_CauseCode;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_SMS_SendStatus - SMS Send Status notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_SmsSendStatus.  Refer to the description of
//				SWI_NOTIFY_SmsSendStatus for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				nMsgID	      				- Message ID of the corresponding SMS
//											  that had been sent
//				eErrorClass  				- Error type.  See
//											  SWI_TYPE_SMS_ErrorClass for details.
//				eCauseCode   				- Error cause code.  See
//											  SWI_TYPE_SMS_CauseCode for details.
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct SWI_STRUCT_SMS_SendStatus
{
    SWI_U32                             sizeStruct;    
	SWI_U32	                            nMsgID;	                  
	SWI_TYPE_SMS_ErrorClass		    eErrorClass;                      
	SWI_TYPE_SMS_CauseCode		    eCauseCode;                      
} SWI_STRUCT_SMS_SendStatus;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_SMS_ParamMask - SMS Parameter Mask enumeration
//
// Purpose:     This identifies the meanings of the bits in the
//				SWI_STRUCT_SMS_CdmaHeader parameter mask of available fields.
//
// Memnbers:	SWI_SMS_PARAMASK_NO_PARAMS		- No parameters set
//				SWI_SMS_PARAMASK_BEARER_REPLY	- Bearer Reply (TL Ack.)
//				SWI_SMS_PARAMASK_VALID_ABS		- Absolute Validity Time
//				SWI_SMS_PARAMASK_VALID_REL	   	- Relative Validity Time
//				SWI_SMS_PARAMASK_DEFER_ABS	   	- Absolute Delivery Deferral Time
//				SWI_SMS_PARAMASK_DEFER_REL	   	- Relative Delivery Deferral Time
//				SWI_SMS_PARAMASK_USER_RESP	   	- User Response	
//				SWI_SMS_PARAMASK_ADDRESS	   	- Address
//				SWI_SMS_PARAMASK_SUBADDR	   	- Sub Address
//				SWI_SMS_PARAMASK_USER_DATA	   	- Data Encoding
//				SWI_SMS_PARAMASK_PRIORITY	   	- Priority
//				SWI_SMS_PARAMASK_PRIVACY	   	- Privacy
//				SWI_SMS_PARAMASK_REPLY_OPT	   	- Reply Option (DAK & User Ack)
//				SWI_SMS_PARAMASK_NUM_OF_MSG	   	- Number of Messages
//				SWI_SMS_PARAMASK_ALERT		   	- Delivery Alert
//				SWI_SMS_PARAMASK_LANGUAGE	   	- Language
//				SWI_SMS_PARAMASK_CALL_BACK	   	- Call Back Number 
//				SWI_SMS_PARAMASK_MC_TIME_STAMP 	- Time Stamp 
//				SWI_SMS_PARAMASK_DISP_MODE	   	- Display Mode
//
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_SMS_PARAMASK_NO_PARAMS,
	SWI_SMS_PARAMASK_BEARER_REPLY,
	SWI_SMS_PARAMASK_VALID_ABS,
	SWI_SMS_PARAMASK_VALID_REL		= 0x00000004,
	SWI_SMS_PARAMASK_DEFER_ABS		= 0x00000008,
	SWI_SMS_PARAMASK_DEFER_REL		= 0x00000010,
	SWI_SMS_PARAMASK_USER_RESP		= 0x00000020,
	SWI_SMS_PARAMASK_ADDRESS		= 0x00000040,
	SWI_SMS_PARAMASK_SUBADDR		= 0x00000080,
	SWI_SMS_PARAMASK_USER_DATA		= 0x00000100,
	SWI_SMS_PARAMASK_PRIORITY		= 0x00000200,
	SWI_SMS_PARAMASK_PRIVACY		= 0x00000400,
	SWI_SMS_PARAMASK_REPLY_OPT		= 0x00000800,
	SWI_SMS_PARAMASK_NUM_OF_MSG		= 0x00001000,
	SWI_SMS_PARAMASK_ALERT			= 0x00002000,
	SWI_SMS_PARAMASK_LANGUAGE		= 0x00004000,
	SWI_SMS_PARAMASK_CALL_BACK		= 0x00008000,
	SWI_SMS_PARAMASK_MC_TIME_STAMP	= 0x00010000,
	SWI_SMS_PARAMASK_DISP_MODE		= 0x00020000
} SWI_TYPE_SMS_ParamMask;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_SMS_MsgCategory - SMS Message Category enumeration
//
// Purpose:     Defines the SMS category
//
// Members:  	SWI_SMS_MSGCAT_POINT_TO_POINT	- IS-637 SMS Point-to-Point Message 
//				SWI_SMS_MSGCAT_BROADCAST_MSG	- IS-637 SMS Broadcast Message  
//				SWI_SMS_MSGCAT_ACK_MSG			- IS-637 SMS Acknowledge Message
//
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_SMS_MSGCAT_POINT_TO_POINT,
	SWI_SMS_MSGCAT_BROADCAST_MSG, 
	SWI_SMS_MSGCAT_ACK_MSG		  
} SWI_TYPE_SMS_MsgCategory;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_SMS_Teleservice - SMS Message Teleservice Type enumeration
//
// Purpose:     Defines the SMS teleservice type.  
//				Refer to TIA/EIA-41-D Table 175 for further information.
//
// Members:  	SWI_SMS_TELESRV_CELL_PAGING		- SMSI_CPT_95: IS-95A Cellular Paging
//				SWI_SMS_TELESRV_CELL_MESSAGING	- SMSI_CMT_95: IS-95A Cellular Messaging
//				SWI_SMS_TELESRV_VOICE_MAIL_NOT	- SMSI_VMN_95: IS-95A Voice Mail Notification
//				SWI_SMS_TELESRV_CLI_ORDER		- SMSI_CMT_91_CLI: IS-91 Extended Protocol - CLI Order
//				SWI_SMS_TELESRV_VOICE_IND		- SMSI_CMT_91_VOICE_MAIL: IS-91 Extended Protocol -
//												  Voice Mail and Embedded Message Waiting Indicator 
//				SWI_SMS_TELESRV_SHORT_MSG		- SMSI_CMT_91_SHORT_MSG: IS-91 Extended Protocol - Short Message
//				SWI_SMS_TELESRV_ALERT_INFO		- SMSI_AWI_95: IS-95A Alert With Info
//				SWI_SMS_TELESRV_WAP				- SMSI_WAP:  WAP Message
//					  
// Notes:	    Refer to TIA/EIA-41-D Table 175 for further info
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_SMS_TELESRV_CELL_PAGING,
	SWI_SMS_TELESRV_CELL_MESSAGING,
	SWI_SMS_TELESRV_VOICE_MAIL_NOT,
	SWI_SMS_TELESRV_CLI_ORDER,
	SWI_SMS_TELESRV_VOICE_IND,
	SWI_SMS_TELESRV_SHORT_MSG,
	SWI_SMS_TELESRV_ALERT_INFO,
	SWI_SMS_TELESRV_WAP
} SWI_TYPE_SMS_Teleservice;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_SMS_MsgIdType - SMS Message ID Type enumeration
//
// Purpose:     Defines the SMS Message ID Type
//
// Members:  	SWI_SMS_MSGIDTYPE_NOTUSED		- NOT USED
//				SWI_SMS_MSGIDTYPE_DELIVER		- Deliver (Regular MT SMS)
//				SWI_SMS_MSGIDTYPE_SUBMIT		- Submit (Regular MO SMS)
//				SWI_SMS_MSGIDTYPE_CANCEL		- Cancellation (MO Only.  
//												  Cancel previous SMS delivery)
//				SWI_SMS_MSGIDTYPE_DELIVERY_ACK	- Delivery Ack.  (MT Only)
//				SWI_SMS_MSGIDTYPE_USER_ACK		- User Acknowledgement (Either Directions)
//
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_SMS_MSGIDTYPE_NOTUSED,
	SWI_SMS_MSGIDTYPE_DELIVER,
	SWI_SMS_MSGIDTYPE_SUBMIT,
	SWI_SMS_MSGIDTYPE_CANCEL,
	SWI_SMS_MSGIDTYPE_DELIVERY_ACK,
	SWI_SMS_MSGIDTYPE_USER_ACK
} SWI_TYPE_SMS_MsgIdType;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_SMS_Priority - SMS Message Priority enumeration
//
// Purpose:     Defines the priority of the SMS Message.
//				
// Members:  	SWI_SMS_PRIORITY_NORMAL			- Normal	
// 				SWI_SMS_PRIORITY_INTERACTIVE	- Interactive	
//				SWI_SMS_PRIORITY_URGENT			- Urgent	
// 				SWI_SMS_PRIORITY_EMERGENCY		- Emergency
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_SMS_PRIORITY_NORMAL,
	SWI_SMS_PRIORITY_INTERACTIVE,
	SWI_SMS_PRIORITY_URGENT,
	SWI_SMS_PRIORITY_EMERGENCY
} SWI_TYPE_SMS_Priority;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_SMS_Privacy - SMS Message Privacy enumeration
//
// Purpose:     Defines the privacy level of the SMS message
//
// Parameters: 	SWI_SMS_PRIVACY_NOT_RESTR		- Not restricted (Level 0)	
//				SWI_SMS_PRIVACY_RESTRICTED		- Restricted (Level 1)	
//				SWI_SMS_PRIVACY_CONFIDENTIAL	- Confidential (Level 2) 	
//				SWI_SMS_PRIVACY_SECRET			- Secret (Level 3)
//
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_SMS_PRIVACY_NOT_RESTR,
	SWI_SMS_PRIVACY_RESTRICTED,
	SWI_SMS_PRIVACY_CONFIDENTIAL,
	SWI_SMS_PRIVACY_SECRET
} SWI_TYPE_SMS_Privacy;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_SMS_Language - SMS Language type enumeration
//
// Purpose:     Defines the language used in the message body
//
// Members:  	SWI_SMS_LANGUAGE_UNSPECIFIED	- UNSPECIFIED	
//				SWI_SMS_LANGUAGE_ENGLISH		- ENGLISH	
//				SWI_SMS_LANGUAGE_FRENCH			- FRENCH	
//				SWI_SMS_LANGUAGE_SPANISH		- SPANISH	
//				SWI_SMS_LANGUAGE_JAPANESE		- JAPANESE	
//				SWI_SMS_LANGUAGE_KOREAN			- KOREAN	
//				SWI_SMS_LANGUAGE_CHINESE		- CHINESE	
//				SWI_SMS_LANGUAGE_HEBREW			- HEBREW
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_SMS_LANGUAGE_UNSPECIFIED,
	SWI_SMS_LANGUAGE_ENGLISH,
	SWI_SMS_LANGUAGE_FRENCH,
	SWI_SMS_LANGUAGE_SPANISH,
	SWI_SMS_LANGUAGE_JAPANESE,
	SWI_SMS_LANGUAGE_KOREAN,
	SWI_SMS_LANGUAGE_CHINESE,
	SWI_SMS_LANGUAGE_HEBREW
} SWI_TYPE_SMS_Language;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_SMS_MsgDispMode - SMS Message Display Mode enumeration
//
// Purpose:     Specifies how the SMS message should be displayed
//
// Members:  	SWI_SMS_MSGDISPMODE_IMMEDIATE		- Immediate Display
//				SWI_SMS_MSGDISPMODE_DEFAULT			- Radio default setting
// 				SWI_SMS_MSGDISPMODE_USER_INVOKE		- User Invoke
//
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_SMS_MSGDISPMODE_IMMEDIATE,
	SWI_SMS_MSGDISPMODE_DEFAULT,
	SWI_SMS_MSGDISPMODE_USER_INVOKE
} SWI_TYPE_SMS_MsgDispMode;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_SMS_DataEncodeType - SMS Data Encoding enumeration
//
// Purpose:     This enumeration identifies the possible data encoding methods
//				used on the SMS message body.  
//
// Members: 	SWI_SMS_DATAENCODE_8bitAscii 	    - Octet, unspecified (i.e. Binary)
//	          SWI_SMS_DATAENCODE_IS91EP         -  varies
//	          SWI_SMS_DATAENCODE_7bitAscii      - Standard ascii, 7-bit 
//	          SWI_SMS_DATAENCODE_IA5            - 7-bit  encoding (  International Alphabet No. 5 same as ASCII )
//	          SWI_SMS_DATAENCODE_Unicode	      - Unicode
//	          SWI_SMS_DATAENCODE_Shift_Jis      -    /* 8 or 16-bit */ It's also known as SJIS or MS Kanji for Japanese support
//	          SWI_SMS_DATAENCODE_Korean         -    /* 8 or 16-bit */ Korean support
//	          SWI_SMS_DATAENCODE_LatinHebrew     -   /* 8 */ specific to the Hebrew script ISO-8859-8 and Windows-1255  
//	          SWI_SMS_DATAENCODE_Latin     		  	- Latin	      
//	          SWI_SMS_DATAENCODE_GSM7BitDefault   - /* 7-bit */ defined in ETSI GSM 03.38.
//            SWI_SMS_DATAENCODE_MAX32

//
// Notes:	    For a more complete list, see SMS standard TSB-58C.
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_SMS_DATAENCODE_8bitAscii = 0,	
	SWI_SMS_DATAENCODE_IS91EP,    
	SWI_SMS_DATAENCODE_7bitAscii,
	SWI_SMS_DATAENCODE_IA5,
	SWI_SMS_DATAENCODE_Unicode,
	SWI_SMS_DATAENCODE_Shift_Jis,
	SWI_SMS_DATAENCODE_Korean,
	SWI_SMS_DATAENCODE_LatinHebrew,    
	SWI_SMS_DATAENCODE_Latin, 		      
	SWI_SMS_DATAENCODE_GSM7BitDefault,
  SWI_SMS_DATAENCODE_MAX32 = 0x10000000
} SWI_TYPE_SMS_DataEncodeType;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_SMS_CdmaHeader - CDMA SMS Header
//
// Purpose:     A portion of SWI_STRUCT_SMS_RetrieveSms,
//				this structure defines the header of incoming
//				SMS messages. Most of the data items are
//				defined in the CDMA specification and are not
//				explained here. The enumerated types are
//				described before this structure.
//
// Members:  	sizeStruct 			- size of this structure
//
//				eParamMask 			- Parameter Mask indicating which of the below fields
//									  are valid.  See SWI_TYPE_SMS_ParamMask.
//
//				eMsgCategory 		- Message Category
//									  See SWI_TYPE_SMS_MsgCategory
//
//				eTeleservice 		- Message Teleservice
//									  See SWI_TYPE_SMS_Teleservice
//
//				serviceCategory 	- Service Category (News, Restaraunts, etc.) 
//									  Refer to TIA/EIA-637 Section 3.4.3.2 for more detail.
//
//				tlAckReq 			- Indicates if the client needs to confirm 
//									  whether the message is received successfully or not.
//
//				eMsgIdType			- Message ID Type
//									  See SWI_TYPE_SMS_MsgIdType
//
//				addrDigitMode 		- Address Digit Mode
//
//				addrNumMode			- Address number mode
//
//				addrNumType			- Address number type
//
//				addrNumPlan			- Address number plan
//
//				addrLen				- Length of Address
//
//			 	szAddress			- Destination address if we are sending out a MO SMS
//									  Origination address if we are retrieving a MT SMS
//
//				subType 			- Sub address type
//
//				subOdd				- Sub Address Odd byte
//
//				subLen				- Length of the sub-address
//
//				szSubAddress		- Destination sub-address if we are sending out a MO SMS
//									  Origination sub-address if we are retrieving a MT SMS
//
//				callBackLen			- Length of the Callback number
//
//				szCallBack			- String containing the Call Back number with a 32 maximum characters
//
//				ePriority			- Message Priority	
//									  See SWI_TYPE_SMS_Priority
//
//				ePrivacy			- Message Privacy Level	
//									  See SWI_TYPE_SMS_Privacy
//
//				eLanguage			- Message Language	
//									  See SWI_TYPE_SMS_Language
//
//				user_ack_req 		- Specify whether user Acknowledgement is required
//									  True/False
//
//				dak_req				- Specify whether delivery acknowledge is required.
//
//				userResp			- User Response Code
//
//				szNumMsg 			- Number of Voice messages (SMSI_VMN_95) on the network
//
//				deliveryAlert 		- Alert on Delivery
//
//				dataEncoding 		- Message Body Data Encoding.
//									  Refer to SWI_TYPE_SMS_DataEncodeType.
//
//				ts_yr				- Time Stamp Year - the value is presented in decimal format.
//
//				ts_mon				- Time Stamp Month - the value is presented in hexadecimal format.  
//									  E.g. December will be interpreted as 0x12
//
//				ts_day				- Time Stamp Day- the value is presented in hexadecimal format.  
//									  E.g. 30th will be interpreted as 0x30.
//
//				ts_hrs				- Time Stamp Hour - the value is presented in hexadecimal format.   
//									  E.g. eleven o'clock is presented as 0x0x11.  
//									  Represented in 24-hour time.
//
//				ts_min				- Time Stamp Minute - the value is presented in hexadecimal format.
//									  E.g. thirty minute is presented as 0x30.
//
//				ts_sec				- Time Stamp Second - the value is presented in hexadecimal format. 
//									  E.g. thirty minute is presented as 0x30.
//
//				abVal_yr 			- Absolute Validity Year - the value is presented in decimal format.  
//
//				abVal_mon			- Absolute Validity Month - the value is presented in hexadecimal format.  
//									  E.g. December will be interpreted as 0x12.
//
//				abVal_day			- Absolute Validity Day- the value is presented in hexadecimal format.  
//									  E.g. 30th will be interpreted as 0x30.
//
//				abVal_hrs			- Absolute Validity Hour - the value is presented in hexadecimal format.   
//									  E.g. eleven o'clock is presented as 0x0x11.
//									  Represented in 24-hour time.
//
//				abVal_min			- Absolute Validity Minute - the value is presented in hexadecimal format.   
//									  Thus, thirty minute is presented as 0x30.
//
//				abVal_sec			- Absolute Validity Second - the value is presented in hexadecimal format.   
//									  E.g. thirty minute is presented as 0x30.
//
//				relVal_time			- Relative Validity Time of a SMS transmission.
//									  See TIA/EIA 637-A Section 4.5.6 for more detail.
//
//				abDef_yr 			- Absolute Delivery Deferral Year - the value is presented in decimal format.  
//
//				abDef_mon			- Absolute Delivery Deferral Month - the value is presented in hexadecimal format.  
//									  E.g. December will be interpreted as 0x12.
//
//				abDef_day			- Absolute Delivery Deferral Day - the value is presented in hexadecimal format.
//									  E.g. 30th will be interpreted as 0x30.
//
//				abDef_hrs			- Absolute Delivery Deferral Hour - the value is presented in hexadecimal format.
//									  E.g. eleven o'clock is presented as 0x0x11.  
//								  	  Represented in 24-hour time.
//
//				abDef_min			- Absolute Delivery Deferral Minute - the value is presented in hexadecimal format.
//									  E.g. thirty minute is presented as 0x30.
//
//				abDef_sec			- Absolute Delivery Deferral Second - the value is presented in hexadecimal format.
//									  E.g. thirty minute is presented as 0x30.
//
//				relDef_time 		- Relative Delivery Deferral Time of a SMS transmission.
//									  See Reference 1 Section 4.5.8 for more detail.
//
//				eMsgDispMode		- Message Display Mode:
//									  See SWI_TYPE_SMS_MsgDispMode
//
// Notes:	    
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct SWI_STRUCT_SMS_CdmaHeader
{
    SWI_U32							sizeStruct;	
	SWI_TYPE_SMS_ParamMask			eParamMask;
	SWI_TYPE_SMS_MsgCategory		eMsgCategory;	
	SWI_TYPE_SMS_Teleservice		eTeleservice;    
	SWI_U16							serviceCategory;
	SWI_U8							tlAckReq;
	SWI_TYPE_SMS_MsgIdType			eMsgIdType;
	SWI_U8							addrDigitMode;
	SWI_U8							addrNumMode;
	SWI_U8							addrNumType;
	SWI_U8							addrNumPlan;
	SWI_U8							addrLen;
	SWI_U8							szAddress[MAX_SMSI_TL_ADDRESS];
	SWI_U8							subType;
	SWI_U8							subOdd;
	SWI_U8							subLen;
	SWI_U8							szSubAddress[MAX_SMSI_TL_ADDRESS];
	SWI_U8							callBackLen;
	SWI_U8							szCallBack[MAX_SMSI_CALL_BACK];
	SWI_TYPE_SMS_Priority			ePriority; 
	SWI_TYPE_SMS_Privacy			ePrivacy;   
	SWI_TYPE_SMS_Language			eLanguage;    
	SWI_U8							user_ack_req;
	SWI_U8							dak_req;
	SWI_U8							userResp;
	SWI_U8							szNumMsg[2];
	SWI_U8							deliveryAlert;
	SWI_TYPE_SMS_DataEncodeType		dataEncoding;
	SWI_U8							ts_yr;        
	SWI_U8							ts_mon;        
	SWI_U8							ts_day;        
	SWI_U8							ts_hrs;        
	SWI_U8							ts_min;
	SWI_U8							ts_sec;
	SWI_U8							abVal_yr;
	SWI_U8							abVal_mon;
	SWI_U8							abVal_day;
	SWI_U8							abVal_hrs;
	SWI_U8							abVal_min;
	SWI_U8							abVal_sec;
	SWI_U8							relVal_time;
	SWI_U8							abDef_yr;
	SWI_U8							abDef_mon;
	SWI_U8							abDef_day;
	SWI_U8							abDef_hrs;
	SWI_U8							abDef_min;
	SWI_U8							abDef_sec;
	SWI_U8							relDef_time;
	SWI_TYPE_SMS_MsgDispMode		eMsgDispMode;
} SWI_STRUCT_SMS_CdmaHeader;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_SMS_RetrieveSms - SMS Retrieve structure
//
// Purpose:     This structure is used to provide input to, and
//				receive output from the SwiRetrieveSMSMessage function.
//
// Members:  	sizeStruct			- size of this structure
//
//				sHeader 			- The SMS header for this message.
//
//				nSMSId 				- The message ID number assigned by
//									  the network.
//
//				cntRemainingSMS 	- The number of SMS
//									  messages remaining in the modem (all three
//									  queues combined).
//
//				pMessage 			- A pointer provided by the application
//									  in which to place the body of the SMS
//									  message.
//
//				sizeBuffer 			- The length in bytes of the buffer
//									  supplied to receive the body of the SMS message.
//									  This should be based on the maximum size of
//									  message supported by the network. The API
//									  currently supports up to 240 bytes, although
//									  most networks limit this to a lower value.
//									  retrievedStatus For future use; ignore.
//                    On return , this parameter will be set to the 
//                    no. of bytes copied into the pMessage buffer
//
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct SWI_STRUCT_SMS_RetrieveSms
{
	SWI_U32							sizeStruct;
	bool							bUnreadSMS;			// Not used
	SWI_STRUCT_SMS_CdmaHeader		sHeader;
	SWI_U16                          nSMSId;
	SWI_U32                          cntRemainingSMS;
	SWI_U8                           *pMessage;
	SWI_U32                          sizeBuffer;
	SWI_U32							retrievedStatus;
} SWI_STRUCT_SMS_RetrieveSms;

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_SMS_Address - SMS address type
//
// Purpose:	This is the enumeration of SMS address types
//
// Members: SWI_SMS_ADDRESS_Unknown			- unknown address type
//
//			SWI_SMS_ADDRESS_International	- international address type
//
//			SWI_SMS_ADDRESS_National		- national address type
//
//			SWI_SMS_ADDRESS_NetworkSpecific	- network specific address type
//
//			SWI_SMS_ADDRESS_Subscriber		- subscriber address type
//
//			SWI_SMS_ADDRESS_Alphanumeric	- alphanumeric address type
//
//			SWI_SMS_ADDRESS_Abbreviated		- addreviated address type
//
// Notes:	None
//
///////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_SMS_ADDRESS_Unknown,				//unknown address
    SWI_SMS_ADDRESS_International,			//international
    SWI_SMS_ADDRESS_National,				//national
    SWI_SMS_ADDRESS_NetworkSpecific,		//network specific
    SWI_SMS_ADDRESS_Subscriber,				//subscriber
    SWI_SMS_ADDRESS_Alphanumeric,			//alphanumeric
    SWI_SMS_ADDRESS_Abbreviated				//abbreviated
} SWI_TYPE_SMS_Address;

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_SMS_AddressNumbering - SMS address numbering type
//
// Purpose:	This is the enumeration of SMS address numbering types
//
// Members:	SWI_SMS_ADDNUMBERING_Unknown	- unknown numbering type
//
//			SWI_SMS_ADDNUMBERING_ISDN		- telephone numbering plan
//
//			SWI_SMS_ADDNUMBERING_DataNumbering	- X.121 numbering plan
//
//			SWI_SMS_ADDNUMBERING_Telex			- Telex numbering plan
//
//			SWI_SMS_ADDNUMBERING_TelexPrivate	- private Telex numbering plan
//
//			SWI_SMS_ADDNUMBERING_ERMES			- ERMES numbering plan
//
//			SWI_SMS_ADDNUMBERING_Abbreviated	- abbreviated numbering plan
//
// Notes:	None
//
///////////////////////////////////////////////////////////////////////////////////
typedef enum
{
    SWI_SMS_ADDNUMBERING_Unknown,			//unknown
    SWI_SMS_ADDNUMBERING_ISDN,              // telephone numbering plan
    SWI_SMS_ADDNUMBERING_DataNumbering,     // X.121
    SWI_SMS_ADDNUMBERING_Telex,				//telex
    SWI_SMS_ADDNUMBERING_TelexPrivate,		//private telex
    SWI_SMS_ADDNUMBERING_ERMES,				//ERMES
    SWI_SMS_ADDNUMBERING_Abbreviated		//abbreviated
} SWI_TYPE_SMS_AddressNumbering;

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_SMS_Protocol - SMS protocol types
//
// Purpose:	This is the enumeration of SMS protocol types
//
// Members:	SWI_SMS_PROTOCOL_AppLayer	- application layer protocol 
//
//			SWI_SMS_PROTOCOL_Telematic	- telematic interworking protocol (default)
//
//			SWI_SMS_PROTOCOL_SMFunctions- SM functions
//
//			SWI_SMS_PROTOCOL_MEFunctions- ME functions
//
//			SWI_SMS_PROTOCOL_SCSpecific	- SC specific
//
//			SWI_SMS_PROTOCOL_RawData	- RAW data
//
// Notes:	None
//
///////////////////////////////////////////////////////////////////////////////////
typedef enum
{
    SWI_SMS_PROTOCOL_AppLayer,              // aplication layer protocol
    SWI_SMS_PROTOCOL_Telematic,             // Telematic interworking (default)
    SWI_SMS_PROTOCOL_SMFunctions,			// simple messaging functions
    SWI_SMS_PROTOCOL_MEFunctions,			// ME functions
    SWI_SMS_PROTOCOL_SCSpecific,			// SC specific
    SWI_SMS_PROTOCOL_RawData				// raw data
} SWI_TYPE_SMS_Protocol;

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_SMS_ProtocolId - SMS protocol id types
//
// Purpose:	This is the enumeration of SMS protocol id types
//
// Members:	SWI_SMS_PROTOCOLID_Implicit		- device type is specific to this SC, 
//			or can be concluded on the basis of the address
//
//			SWI_SMS_PROTOCOLID_Telex		- telex protocol
//
//			SWI_SMS_PROTOCOLID_Group3Fax	- group 3 FAX
//
//			SWI_SMS_PROTOCOLID_Group4Fax	- group 4 FAX
//
//			SWI_SMS_PROTOCOLID_Voice		- voice
//
//			SWI_SMS_PROTOCOLID_ERMES		- ERMES
//
//			SWI_SMS_PROTOCOLID_NationalPagingSystem	- National paging system
//
//			SWI_SMS_PROTOCOLID_Videotex		- VideoTex (T.100 /T.101)
//
//			SWI_SMS_PROTOCOLID_TelexUnsecified		- teletex, carrier unspecified
//
//			SWI_SMS_PROTOCOLID_TelexPSPDN	- teletex, in PSPDN
//
//			SWI_SMS_PROTOCOLID_TelexCSPDN	- teletex, in CSPDN
//
//			SWI_SMS_PROTOCOLID_TelexAnalogPSTN	- teletex, in analog PSTN
//
//			SWI_SMS_PROTOCOLID_TelexDigitalPSTN	- teletex, in digital PSTN
//
//			SWI_SMS_PROTOCOLID_UCI			- Universal Computer Interface
//
//			SWI_SMS_PROTOCOLID_MessageHandling	-Message handling facility
//
//			SWI_SMS_PROTOCOLID_AnyPublicX400	- Any public X.400?based message 
//			handling system
//
//			SWI_SMS_PROTOCOLID_InternalMail		- internet email
//
//			SWI_SMS_PROTOCOLID_Value1SC			- Value #1 specific to the SC, usage 
//			based on mutual agreement between the SME and the SCValue #1 Specific to SC
//
//			SWI_SMS_PROTOCOLID_Value2SC			- Value #2 Specific to SC
//
//			SWI_SMS_PROTOCOLID_Value3SC			- Value #3 Specific to SC
//
//			SWI_SMS_PROTOCOLID_Value4SC			- Value #4 Specific to SC
//
//			SWI_SMS_PROTOCOLID_Value5SC			- Value #5 Specific to SC
//
//			SWI_SMS_PROTOCOLID_Value6SC			- Value #6 Specific to SC
//
//			SWI_SMS_PROTOCOLID_Value7SC			- Value #7 Specific to SC
//
//			SWI_SMS_PROTOCOLID_GSMMobil			- GSM mobile station 
//
// Notes:	None
//
///////////////////////////////////////////////////////////////////////////////////
typedef enum
{
    SWI_SMS_PROTOCOLID_Implicit,				//implicit
    SWI_SMS_PROTOCOLID_Telex,					//telex
    SWI_SMS_PROTOCOLID_Group3Fax,				//group 3 fax
    SWI_SMS_PROTOCOLID_Group4Fax,				//group 4 fax
    SWI_SMS_PROTOCOLID_Voice,					//voice
    SWI_SMS_PROTOCOLID_ERMES,					//ERMES
    SWI_SMS_PROTOCOLID_NationalPagingSystem,	//national paging system
    SWI_SMS_PROTOCOLID_Videotex,				//videotex
    SWI_SMS_PROTOCOLID_TelexUnsecified,			//carrier unspecified
    SWI_SMS_PROTOCOLID_TelexPSPDN,				//telex PSPDN
    SWI_SMS_PROTOCOLID_TelexCSPDN,				//telex CSPDN
    SWI_SMS_PROTOCOLID_TelexAnalogPSTN,			//telex analog PSTN
    SWI_SMS_PROTOCOLID_TelexDigitalPSTN,		//telex digital PSTN
    SWI_SMS_PROTOCOLID_UCI,						//(Universal Computer Interface)
    SWI_SMS_PROTOCOLID_MessageHandling,			//message handling facility
    SWI_SMS_PROTOCOLID_AnyPublicX400,			//public X400
    SWI_SMS_PROTOCOLID_InternalMail,			//internal mail
    SWI_SMS_PROTOCOLID_Value1SC,				// Value #1 Specific to SC
    SWI_SMS_PROTOCOLID_Value2SC,				// Value #2 Specific to SC
    SWI_SMS_PROTOCOLID_Value3SC,				// Value #3 Specific to SC
    SWI_SMS_PROTOCOLID_Value4SC,				// Value #4 Specific to SC
    SWI_SMS_PROTOCOLID_Value5SC,				// Value #5 Specific to SC
    SWI_SMS_PROTOCOLID_Value6SC,				// Value #6 Specific to SC
    SWI_SMS_PROTOCOLID_Value7SC,				// Value #7 Specific to SC
    SWI_SMS_PROTOCOLID_GSMMobil					// GSM mobile station
} SWI_TYPE_SMS_ProtocolId;

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_SMS_CodingScheme - SMS coding schemes
//
// Purpose:	This is the enumeration of SMS coding schemes
//
// Members:	SWI_SMS_CODINGSCHEME_Default	- 7 bit coding (default)
//
//			SWI_SMS_CODINGSCHEME_8bit		- 8 bit coding
//
//			SWI_SMS_CODINGSCHEME_UCS2		- unicode coding
//
//			SWI_SMS_CODINGSCHEME_Unknown	- unknown coding
//
// Notes:	None
//
///////////////////////////////////////////////////////////////////////////////////
typedef enum
{
    SWI_SMS_CODINGSCHEME_Default,		//default
    SWI_SMS_CODINGSCHEME_8bit,			//8-bit
    SWI_SMS_CODINGSCHEME_UCS2,			//UCS2
    SWI_SMS_CODINGSCHEME_Unknown		//unknown
} SWI_TYPE_SMS_CodingScheme;

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_SMS_CodingClass - SMS coding class
//
// Purpose:	This is the enumeration of SMS coding class. 
//
// Members:	SWI_SMS_CODINGCLASS_Class0		- Class 0 DCS class
//
//			SWI_SMS_CODINGCLASS_Class1		- Class 1 (DCS class)
//
//			SWI_SMS_CODINGCLASS_Class2		- Class 2 (DCS class)
//
//			SWI_SMS_CODINGCLASS_Class3		- Class 3 (DCS class)
//
//			SWI_SMS_CODINGCLASS_NotGiven	- The default
//
// Notes:	None
//
///////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_SMS_CODINGCLASS_Class0,         // Class 0 DCS class
	SWI_SMS_CODINGCLASS_Class1,         // Class 1 (DCS class)
	SWI_SMS_CODINGCLASS_Class2,         // Class 2 (DCS class)
	SWI_SMS_CODINGCLASS_Class3,         // Class 3 (DCS class)
	SWI_SMS_CODINGCLASS_NotGiven        // The default
} SWI_TYPE_SMS_CodingClass;

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_SMS_CodingCompression - SMS coding compression
//
// Purpose:	This is the enumeration of SMS coding compression. 
//
// Members:	SWI_SMSCOMPRESSION_Uncompressed	- The SMS text is uncompressed
//
//			SWI_SMSCOMPRESSION_Compressed	- The SMS text is compressed
//
// Notes:	None
//
///////////////////////////////////////////////////////////////////////////////////
typedef enum 
{
    SWI_SMSCOMPRESSION_Uncompressed,    // The SMS text is uncompressed
    SWI_SMSCOMPRESSION_Compressed       // The SMS text is compressed
} SWI_TYPE_SMS_CodingCompression;

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_SMS_Routing - SMS routing
//
// Purpose:	This is the enumeration of SMS routing.
//
// Members:	SWI_SMSROUTE_Gprs			- GPRS
//
//			SWI_SMSROUTE_Csn			- Circuit switched
//
//			SWI_SMSROUTE_GprsPreferred	- GPRS preferred
//
//			SWI_SMSROUTE_CsnPreferred	- Circuit switched preferred
//
// Notes:	None
//
///////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_SMSROUTE_Gprs,           //GPRS
	SWI_SMSROUTE_Csn,            //Circuit switched
	SWI_SMSROUTE_GprsPreferred,  //GPRS preferred
	SWI_SMSROUTE_CsnPreferred    //Circuit switched preferred
} SWI_TYPE_SMS_Routing;

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_SMS_Param - SMS network parameters
//
// Purpose:	This structure is used to report SMS messaging parameters used by 
//			the network via the function SwiGetSMSParam. The data is needed to fill 
//			in the header for MO-SMS messages.    
//
// Members:	sizeStruct				- size of this structure
//
//			bDesAddressPresent		- default destination address present
//									  1 - destination address present
//									  0 - otherwise
//	
//			eDesAddressType			- default destination address type
//
//			eDesAddressNumberingPlan- default destination address numbering plan
//
//			nDefDesAddressLength	- default destination address numbering length
//
//			DefDesAddress			- default destination address number
//
//			bSCAddressPresent		- service center address present
//									  1 - service center address present
//									  0 - otherwise
//
//			eSCAddressType			- service center address type
//
//			eSCAddressNumberingPlan	- service center address numbering plan
//
//			nSCAddressLength		- service center address numbering length
//
//			SCAddressNumber			- service center address number
// 
//			bDefProtocolIDPresent	- default protocol id present
//									  1 - protocol id present
//									  0 - otherwise
//
//			eDefProtocolType		- default protocol type
//
//			eDefProtocolID			- default prototype id
//
//			bDefDCSPresent			- default data coding scheme present
//									  1 - data coding scheme present
//									  0 - otherwise
//
//			eDefDCSDataType			- default data coding scheme data type
//
//			eDefDCSClass			- default data coding scheme class
//
//			eDefDCSCompression		- default data coding scheme compression
//
//			bValidityPeriodPresent	- default validity period present
//									  1 - validity period present
//									  0 - otherwise
//
//			DefValidityPeriod		- default validity period 
//
//			eSMSRoutingOption		- SMS Routing Option
//
// Notes:	The DefValidityPeriod field defines the amount of time for which an 
//			outgoing message will be valid in the network before it is deemed 
//			obsolete and will be purged by the network even if the destination 
//			party does not retrieve the message.  The encoding of this byte is as 
//			follows:The representation of time for this SWI_U8 representing the 
//			Validity Period (VP) is as follows:
//			VP value	Validity period value
//			0 to 143	(VP + 1) x 5 minutes (ie 5 min intervals up to 12 hrs)
//			144 to 167	12 hours + ((VP - 143) x 30 minutes)
//			168 to 196	(VP - 166) x 1 day
//			197 to 255	(VP - 192) x 1 week
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct SWI_STRUCT_SMS_Param
{
	SWI_U32							sizeStruct;					// size of this structure
    bool                            bDesAddressPresent;			// destination address present
    SWI_TYPE_SMS_Address            eDesAddressType;				// destination address type
    SWI_TYPE_SMS_AddressNumbering   eDesAddressNumberingPlan;	// destination address numbering plan
    SWI_U32                          nDefDesAddressLength;		// default destination address length
    SWI_U8                           DefDesAddress[20];			// default destination address
    
    bool							bSCAddressPresent;			// service center address present
    SWI_TYPE_SMS_Address			eSCAddressType;				// service center address type
    SWI_TYPE_SMS_AddressNumbering	eSCAddressNumberingPlan;		// service center address numbering plan
    SWI_U32                          nSCAddressLength;			// service center address length
    SWI_U8                           SCAddressNumber[20];			// service center address number
    
    bool							bDefProtocolIDPresent;		// default protocol ID present
    SWI_TYPE_SMS_Protocol			eDefProtocolType;			// default protocol type
    SWI_TYPE_SMS_ProtocolId			eDefProtocolID;				// default protocol ID
    
    bool							bDefDCSPresent;				// default data coding sheme present
    SWI_TYPE_SMS_CodingScheme		eDefDCSDataType;				// default data coding sheme data type
    SWI_TYPE_SMS_CodingClass		eDefDCSClass;				// default data coding sheme class
    SWI_TYPE_SMS_CodingCompression	eDefDCSCompression;			// default data coding sheme compression
    bool							bValidityPeriodPresent;		// validity present
    SWI_U8                           DefValidityPeriod;			// default validity period
    SWI_TYPE_SMS_Routing			eSMSRoutingOption;			// routing option
} SWI_STRUCT_SMS_Param;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_SMS_StoreSms - Structure used to store SMS
//
// Purpose:     This structure is used to provide input to the
//				SwiStoreSMSMessage function.
//
// Members:  	sizeStruct			- size of this structure
//
//				nSMSId 				- This is a unique identifer set by the
//									  application. The onus is on the application to
//									  ensure message IDs are not duplicated. This ID
//									  is used to report the status of sent messages via
//									  SWI_NOTIFY_SmsSendStatus.
//
//				sSMSHeader 			- The SMS header for this
//									  message, as described on page 52.
//
//				pMsgBody 			- The body of the SMS message. The
//									  true length is stored in another field (limited to
//									  240 bytes by the API).
//
//				sizeSMSBody 		- The length of the message body
//									  in bytes up to 240, or a lower limit imposed by
//									  your service provider.
//
//				bStoreStatus 		- For future use; ignore.
//
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct SWI_STRUCT_SMS_StoreSms
{
	SWI_U32							sizeStruct;		
	SWI_U16							nSMSId; 		
	SWI_STRUCT_SMS_CdmaHeader		sSMSHeader;		
    SWI_U8                           *pMsgBody;		
    SWI_U8                           sizeSMSBody;   	
    SWI_U32                          bStoreStatus;	
} SWI_STRUCT_SMS_StoreSms;

typedef enum
{
	SWI_COMMIT_TYPE_NONPROVISION	= 0x0000,
	SWI_COMMIT_TYPE_PROVISION		= 0x0001,
} SWI_TYPE_CommitType;

typedef enum
{
	SWI_COMMIT_RESULT_Fail = 0x0000,
	SWI_COMMIT_RESULT_Success = 0x0001,
} SWI_TYPE_CommitResult;

typedef enum
{
	SWI_COMMIT_RESULT_MASK_NoError										= 0x0,
	SWI_COMMIT_RESULT_MASK_MobileDirectoryNumberNotProvisioned			= 0x1,
	SWI_COMMIT_RESULT_MASK_ImsiNotProvisioned							= 0x2,
	SWI_COMMIT_RESULT_MASK_NoIpTypeNetworkUserIdPasswordisProvisioned	= 0x4,
	SWI_COMMIT_RESULT_MASK_ProvisioningDateMissing						= 0x8,
	SWI_COMMIT_RESULT_MASK_NamProfileIsNotProvisionedInRightOrder		= 0x10
} SWI_TYPE_CommitResultMask;

//////////////////////////////////////////////////////////////////////////////////
//
//		LBS -  LOCATION BASED SERVICE
//
//////////////////////////////////////////////////////////////////////////////////

	// PDSM - End Status Values
	
typedef enum
{
	SWI_PDSM_PD_EndStatus_Offline,	// 0
	SWI_PDSM_PD_EndStatus_No_Service,
	SWI_PDSM_PD_EndStatus_No_Connection,
	SWI_PDSM_PD_EndStatus_No_Data,
	SWI_PDSM_PD_EndStatus_Session_Busy,
	SWI_PDSM_PD_EndStatus_CDMA_Lock,	// 5
	SWI_PDSM_PD_EndStatus_GPS_Lock,
	SWI_PDSM_PD_EndStatus_Connection_Failed,
	SWI_PDSM_PD_EndStatus_Error_State,
	SWI_PDSM_PD_EndStatus_Client_Ended,
	SWI_PDSM_PD_EndStatus_UI_Ended,	// 10
	SWI_PDSM_PD_EndStatus_Network_Ended,
	SWI_PDSM_PD_EndStatus_Timeout,
	SWI_PDSM_PD_EndStatus_Privacy_Level,
	SWI_PDSM_PD_EndStatus_Network_Access_Error,
	SWI_PDSM_PD_EndStatus_Fix_Error,
	SWI_PDSM_PD_EndStatus_PDE_Rejected,
	SWI_PDSM_PD_EndStatus_Traffic_Channel_Exited,
	SWI_PDSM_PD_EndStatus_E911,
	SWI_PDSM_PD_EndStatus_Server_Error,
	SWI_PDSM_PD_EndStatus_Stale_BS_Information,
	SWI_PDSM_PD_EndStatus_MSBasedSmartModeFallback		= 1024,	// 0x400
	SWI_PDSM_PD_EndStatus_StandaloneSmartModeFallback	= 1025,	// 0x401
} SWI_PDSM_PD_EndStatus;

	// PDSM - Error Type Values
	
typedef enum
{
	SWI_PDSM_PD_ErrType_NoError,
	SWI_PDSM_PD_ErrType_Internal_Modem_Error,
	SWI_PDSM_PD_ErrType_Bad_Service_Type,
	SWI_PDSM_PD_ErrType_Bad_Session_Type,
	SWI_PDSM_PD_ErrType_Invalid_Privacy,
	SWI_PDSM_PD_ErrType_Invalid_Data_Download,
	SWI_PDSM_PD_ErrType_Invalid_Network_Access,
	SWI_PDSM_PD_ErrType_Invalid_Operation_Mode,
	SWI_PDSM_PD_ErrType_Invalid_Number_of_Fixes,
	SWI_PDSM_PD_ErrType_Invalid_Server_Info,
	SWI_PDSM_PD_ErrType_Invalid_Timeout,
	SWI_PDSM_PD_ErrType_Invalid_QOS_Parameter,
	SWI_PDSM_PD_ErrType_No_Session_Active,
	SWI_PDSM_PD_ErrType_Session_Already_Active,
	SWI_PDSM_PD_ErrType_Session_Busy,
	SWI_PDSM_PD_ErrType_Phone_Is_Offline,
	SWI_PDSM_PD_ErrType_CDMA_Lock_Error,
	SWI_PDSM_PD_ErrType_GPS_Lock_Error,
	SWI_PDSM_PD_ErrType_Invalid_State,
	SWI_PDSM_PD_ErrType_Connection_Failure,
	SWI_PDSM_PD_ErrType_No_Buffers_Available,
	SWI_PDSM_PD_ErrType_Searcher_Error,
	SWI_PDSM_PD_ErrType_Cannot_Report_Now,
	SWI_PDSM_PD_ErrType_Mode_Not_Supported,
	SWI_PDSM_PD_ErrType_Other_Error,
	SWI_PDSM_PD_ErrType_Fix_Rate_For_Tracking_Too_Large
} SWI_PDSM_PDErrType;

	// PDSM - Service Type Mask Values
	
typedef enum
{
	SWI_PDSM_PD_ServiceType_Position	= 0x01,
	SWI_PDSM_PD_ServiceType_Velocity	= 0x02,
	SWI_PDSM_PD_ServiceType_Height		= 0x04
} SWI_PDSM_PDServiceType;

	// PDSM - Download Option Values
	
typedef enum
{
	SWI_PDSM_PD_DloadOptionPeriodic	= 0x01,
	SWI_PDSM_PD_DloadOptionSingle
} SWI_PDSM_PDDloadOption;

	// PDSM - Transport Mechanism Values
	
typedef enum
{
	SWI_PDSM_PD_TransportMechDefault,
	SWI_PDSM_PD_TransportTcpIp,
	SWI_PDSM_PD_TransportDataBurst
} SWI_PDSM_DP_TransportMech;

	// PDSM - Session Type Values
	
typedef enum
{
	SWI_PDSM_PD_LocationFix,
	SWI_PDSM_PD_Download
} SWI_PDSM_SessionType;

	// PDSM - GPS Lock Values
	
typedef enum
{
	SWI_PDSM_PA_No_GPS_Lock_Active,
	SWI_PDSM_PA_MI_GPS_Sessions_Locked,
	SWI_PDSM_PA_MT_GPS_Sessions_Locked,
	SWI_PDSM_PA_All_Sessions_Locked
} SWI_PDSM_GpsLock;

	// PDSM - Privacy Values
	
typedef enum
{
	SWI_PDSM_PA_Privacy_High,
	SWI_PDSM_PA_Privacy_Medium,
	SWI_PDSM_PA_Privacy_Low
} SWI_PDSM_Privacy;

	// PDSM - Network Access Values
	
typedef enum
{
	SWI_PDSM_PA_Network_Only,
	SWI_PDSM_PA_No_Network_Access,
	SWI_PDSM_PA_Network_With_Demodulation,
	SWI_PDSM_PA_Network_Without_Demodulation
} SWI_PDSM_PA_NetAccess;

	// PDSM - PA Error Type values
	
typedef enum
{
	SWI_PDSM_PA_Err_No_Error,
	SWI_PDSM_PA_Err_Internal_Error,
	SWI_PDSM_PA_Err_Invalid_Client_ID,
	SWI_PDSM_PA_Err_Error_In_Param_To_Set,
	SWI_PDSM_PA_Err_Error_In_Lock_Type,
	SWI_PDSM_PA_Err_Phone_Offline,
	SWI_PDSM_PA_Err_Param_Command_Already_Active,
	SWI_PDSM_PA_Err_Incorrect_App_Specific_Info
} SWI_PDSM_PA_ErrType;

typedef enum
{
  CNS_PDSM_PD_Begin_Mask			= 0x0001,
  CNS_PDSM_PD_Data_Mask				= 0x0002,
  CNS_PDSM_PD_End_Mask				= 0x0004,
  CNS_PDSM_PD_Done_Mask				= 0x0008,
  CNS_PDSM_PD_UpdateFailure_Mask	= 0x0010
} SWI_TYPE_Notify_PDSMLocNotifyStatus_Mask;

typedef enum
{
  CNS_PDSM_PD_Dload_Begin_Mask		= 0x0001,
  CNS_PDSM_PD_Dload_Data_Mask		= 0x0002,
  CNS_PDSM_PD_Dload_End_Mask		= 0x0004,
  CNS_PDSM_PD_Dload_Done_Mask		= 0x0008
} SWI_TYPE_Notify_PDSMDloadNotifyStatus_Mask;

typedef enum
{
  CNS_PDSM_PA_Address_Mask			= 0x0001,
  CNS_PDSM_PA_GpsLock_Mask			= 0x0002,
  CNS_PDSM_PA_PtlmMode_Mask			= 0x0004,
  CNS_PDSM_PA_PortID_Mask			= 0x0008,
  CNS_PDSM_PA_Privacy_Mask			= 0x0010,
  CNS_PDSM_PA_NetAccess_Mask		= 0x0020
} SWI_TYPE_Notify_PDSMParamNotifyStatus_Mask;

//////////////////////////////////////////////////////////////////////////////////
//
//		LBS/GPS structures
//
//////////////////////////////////////////////////////////////////////////////////

	// CNS_PDSM_LOC_NOTIFY_STATUS

typedef struct SWI_STRUCT_PDSMLocNotifyStatus
{
    SWI_U32				sizeStruct;     
    SWI_U16				iNotifyFlag;		// 0x0000 = Off, Ox0001 = On
} SWI_STRUCT_PDSMLocNotifyStatus;

	// CNS_PDSM_DLOAD_NOTIFY_STATUS
	
typedef struct SWI_STRUCT_PDSMDloadNotifyStatus
{
    SWI_U32             sizeStruct;     
    SWI_U16             iNotifyFlag;			// 0x0000 = Off, Ox0001 = On
} SWI_STRUCT_PDSMDloadNotifyStatus;

	// CNS_PDSM_PARAM_NOTIFY_STATUS
	
typedef struct SWI_STRUCT_PDSMParamNotifyStatus
{
    SWI_U32             sizeStruct;     
    SWI_U16             iNotifyFlag;			// 0x0000 = Off, Ox0001 = On
} SWI_STRUCT_PDSMParamNotifyStatus;

	// CNS_PDSM_ERR_NOTIFY_STATUS - Not Supported

	// CNS_PDSM_PD_DOWNLOAD
	
typedef struct SWI_STRUCT_PDSM_PD_Download
{
	SWI_U32				sizeStruct;     
	SWI_U16				nOption;			//	0x0001: Periodic, 0x002: Single
	SWI_U32				nDuration;			//	mns: Used only with Periodic option
} SWI_STRUCT_PDSM_PD_Download;

typedef enum
{
  SWI_PDSM_FIX_TYPE_AUTONOMOUS          = 1, //Mobile does everything involved in computing its position.  No PDE required
  SWI_PDSM_FIX_TYPE_MS_BASED            = 2, //Mobile gets assistance from the PDE but the mobile computes position.
  SWI_PDSM_FIX_TYPE_MS_ASSISTED         = 3, //Mobile provides information to the PDE so that the PDE can compute the mobiles position.
  SWI_PDSM_FIX_TYPE_OPTIMIZED_SPEED     = 4, //MS Based or MS Assisted depending on Performance and Accuracy settings.
  SWI_PDSM_FIX_TYPE_OPTIMIZED_ACCURACY  = 5, //MS-Assisted preferred, MS-Based if MS-Assisted fails
  SWI_PDSM_FIX_TYPE_OPTIMIZED_DATA      = 6  //MS-Based preferred, MS-Assisted if MS-Based fails
} SWI_TYPE_PDSM_Fix_Type;

typedef enum
{
	SWI_LBS_FIX_TYPE_AUTONOMOUS          = 1, //Mobile does everything involved in computing its position.  No PDE required
	SWI_LBS_FIX_TYPE_MS_BASED            = 2, //Mobile gets assistance from the PDE but the mobile computes position.
	SWI_LBS_FIX_TYPE_MS_ASSISTED         = 3, //Mobile provides information to the PDE so that the PDE can compute the mobiles position.
	SWI_LBS_FIX_TYPE_OPTIMIZED_SPEED     = 4, //MS Based or MS Assisted depending on Performance and Accuracy settings.
	SWI_LBS_FIX_TYPE_OPTIMIZED_ACCURACY  = 5, //MS-Assisted preferred, MS-Based if MS-Assisted fails
	SWI_LBS_FIX_TYPE_OPTIMIZED_DATA      = 6  //MS-Based preferred, MS-Assisted if MS-Based fails
} SWI_TYPE_LBS_Fix_Type;

	// CNS_PDSM_PD_GET_POS
	
typedef struct SWI_STRUCT_PDSM_PD_GetPos
{
	SWI_U32				sizeStruct;
	SWI_U16				iFixType; 
	SWI_U16				iPerformance;		//Number of seconds MS should look for satellites
	SWI_U32				iAccuracy;			//Amount in meters MS should use to determine validity of computed fix.
} SWI_STRUCT_PDSM_PD_GetPos;

typedef enum
{
  SWI_PDSM_FIX_STATUS_NONE              = 0, //No status to report
  SWI_PDSM_FIX_STATUS_IN_PROGRESS       = 1, //Fix is currently is progress
  SWI_PDSM_FIX_STATUS_SUCCESS           = 2, //Fix attempt successful
  SWI_PDSM_FIX_STATUS_ERROR             = 3, //Error occurred while obtaining fix
} SWI_TYPE_PDSM_Fix_Status;

	// CNS_PDSM_PD_GET_STATUS
	
typedef struct SWI_STRUCT_PDSM_PD_GetStatus
{
	SWI_U32				sizeStruct;
	char				cLastFixTimeStamp[16];			//last single fix timestamp
	SWI_U16				nLastFixStatus;                 //Status for last single fix -- see SWI_TYPE_PDSM_Fix_Status
	SWI_U16				nLastFixError;                  //Error for last single fix -- see SWI_PDSM_PDErrType
	char				cLastDownloadTimestamp[16];
	SWI_U16				nLastDownloadStatus;
	SWI_U16				nLastDownloadError;
	char				cLastFixSessionTimestamp[16];	//Last tracking Timestamp 
	SWI_U16				nLastFixSesssionStatus;         //Status for tracking fix -- see SWI_TYPE_PDSM_Fix_Status
	SWI_U16				nLastFixSesssionError;          //Error for tracking fix -- see SWI_PDSM_PDErrType
	char				cLastDownloadSessionTimestamp[16];
	SWI_U16				nLastDownloadSesssionStatus;
	SWI_U16				nLastDownloadSesssionError;
} SWI_STRUCT_PDSM_PD_GetStatus;

	// CNS_PDSM_PD_TRACK
	
typedef struct SWI_STRUCT_PDSM_PD_Track
{
	SWI_U32				sizeStruct;
	SWI_U16				nFixType;				//see SWI_TYPE_PDSM_Fix_Type (SWI_PDSM_FIX_TYPE_MS_ASSISTED should not be used as it requires too much PDE activity)
	SWI_U16				nPerformance;			//same as for single fix
	SWI_U32				nAccuracy;				//same as for single fix
	SWI_U16				nFixCount;				//Number of fixes. 0 - 999 fixes -OR- 1000 for continuous fixes
	SWI_U32				nFixRate;				//How often fixes occur.  1 - 1,799,999 seconds 
} SWI_STRUCT_PDSM_PD_Track;

	// CNS_PDSM_PD_END_SESSION
	
typedef struct SWI_STRUCT_PDSM_PD_EndSession
{
	SWI_U32				sizeStruct;     
	SWI_U16				iSessionType;			//	0 = Location Fix, 1 = Download
} SWI_STRUCT_PDSM_PD_EndSession;

	// CNS_PDSM_PA_GET_PARAM
	
typedef struct SWI_STRUCT_PDSM_PA_GetParam
{
	SWI_U32				sizeStruct; 
	SWI_U32				iIPAddress;
	SWI_U32				iPortID;
	SWI_U16				iGpsLock;				// See GPS Lock Values above
	SWI_U16				iTransportMech;			// See Transport Mechanism Values above
	SWI_U16				iPrivacy;				// See Privacy Values above
	SWI_U16				iNetworkAccess;			// See Network Access Level above
} SWI_STRUCT_PDSM_PA_GetParam;

	//Standard Deviation Position Uncertainty Table from IS801-1
	// return values are 0 - 31 and map to the list below it (uncertainty values are in Meters)
	// 0,  1,2, 3, 4,5,6,7,8, 9,10,11,12,13,14,15, 16, 17, 18, 19, 20, 21,  22,  23,  24,  25,  26,  27,  28,   29,   30,31,32
	//.5,.75,1,1.5,2,3,4,6,8,12,16,24,32,48,64,96,128,192,256,384,512,768,1024,1536,2048,3072,4096,6144,8192,12288,12288, 0,0
	// 

	// CNS_PDSM_PD_DATA
	
typedef struct SWI_STRUCT_PDSM_PD_Data
{
	SWI_U32				sizeStruct;
	SWI_S32				iLatitude;			//To convert to decimal degrees:  double float_val =  iLatitude /186413.5111;
	SWI_S32				iLongitude;			//To convert to decimal degrees:  double float_val =  iLongitude /186413.5111;
	SWI_U32				iTimeStamp;			//To convert time: CTime t(nValue+315964800L);    // 315964800L is the number of seconds between January 6, 1980 and January 1, 1970
	SWI_U16				iLocUncAngle;		//In units of 5.625 degrees from 0 to 84.375 with 0 being true North increasing to the east.
	SWI_U16				iLocUncA;			//Standard deviation of axis along angle specified for position uncertainty <Use table above for translation>.
	SWI_U16				iLocUncP;			//Standard deviation of axis perpedicular to angle specified for position uncertainty <Use table above for translation>.
	SWI_U16				iFix;				//0 = 2-D fix, 1 = 3-D fix
	SWI_U16				iHeightIncl;		//0 = Height info not available, 1 = Height info included
	SWI_S16				iAltitude;			//Valid if iHeightIncl = 1 : Note that the value returned is altitude(meters) + 500.  Subtract 500 for altitude.
	SWI_U16				iLocUncVe;			//Valid if iHeightIncl = 1, Standard Deviation of Vertical error (use table above)
	SWI_U16				iVelocityIncl;		//0 = Velocity not included, 1 = Velocity included
	SWI_U16				iHeading;			//Valid if iVelocityInc = 1.  To convert to direction (degrees): nHead = iHeading * 0.3515625f);
	SWI_U16				iVelHoriz;			//Valid if iVelocityInc = 1. units of .25m/s in ranch 0 to 127.75m/s
	SWI_S32				iVelVert;			//Valid if iVelocityInc = 1 and Fix type is 1, 2's complement value of Vertical Velocity in units of .5m/s in range of -64m/s to 63.6m/s
	SWI_U16				iUncertaintyA;		//Formatted in integer steps of 0.25 meters
	SWI_U16				iUncertaintyP;		//Formatted in integer steps of 0.25 meters
	SWI_U16				iUncertaintyV;		//If Height Included =1, this field is valid. Formatted in integer steps of 0.25 meters
	SWI_U16				iHEPE;				//Formatted in integer steps of 0.1 meters
	SWI_U8				iSatelliteNum;		//Number of Satellites used in Position Fix (Max 12)
} SWI_STRUCT_PDSM_PD_Data;

	// CNS_PDSM_PD_DONE
	
typedef struct SWI_STRUCT_PDSM_PD_Done
{
    SWI_U32				sizeStruct;     
} SWI_STRUCT_PDSM_PD_Done;

	// CNS_PDSM_PD_END
	
typedef struct SWI_STRUCT_PDSM_PD_End
{
	SWI_U32					sizeStruct;
	SWI_PDSM_PD_EndStatus	eEndStatus;
} SWI_STRUCT_PDSM_PD_End;

	// CNS_PDSM_PD_BEGIN
	
typedef struct SWI_STRUCT_PDSM_PD_Begin
{
	SWI_U32				sizeStruct;
} SWI_STRUCT_PDSM_PD_Begin;

	// CNS_PDSM_PD_UPDATE_FAILURE

typedef struct SWI_STRUCT_PDSM_PD_Update_Failure
{
	SWI_U32				sizeStruct;
} SWI_STRUCT_PDSM_PD_Update_Failure;

	// CNS_PDSM_PD_DLOAD_BEGIN
	
typedef struct SWI_STRUCT_PDSM_PD_DLOAD_Begin
{
	SWI_U32				sizeStruct;     
} SWI_STRUCT_PDSM_PD_DLOAD_Begin;

	// CNS_PDSM_PD_DLOAD_DATA
	
typedef struct SWI_STRUCT_PDSM_PD_DloadData
{
	SWI_U32				sizeStruct;     
	SWI_U16				nValidEntryPairNum;
	SWI_U16				nDataType1;
	SWI_U16				nSource1;
	SWI_U16				nDataType2;
	SWI_U16				nSource2;
	SWI_U16				nDataType3;
	SWI_U16				nSource3;
	SWI_U16				nDataType4;
	SWI_U16				nSource4;
	SWI_U16				nDataType5;
	SWI_U16				nSource5;
} SWI_STRUCT_PDSM_PD_DloadData;

	// CNS_PDSM_PD_DLOAD_DONE
	
typedef struct SWI_STRUCT_PDSM_PD_DLOAD_Done
{
  SWI_U32				sizeStruct;     
} SWI_STRUCT_PDSM_PD_DLOAD_Done;

	// CNS_PDSM_PD_DLOAD_END
	
typedef struct SWI_STRUCT_PDSM_DLOAD_End
{
	SWI_U32				sizeStruct;     
	SWI_PDSM_PD_EndStatus	eEndStatus;			// See End Status Values
} SWI_STRUCT_PDSM_DLOAD_End;

	// CNS_PDSM_PA_IP_ADDR
	
typedef struct SWI_STRUCT_PDSM_PA_IP_Addr
{
	SWI_U32				sizeStruct;
	SWI_U32				iIPAddress;
} SWI_STRUCT_PDSM_PA_IP_Addr;

	// CNS_PDSM_PA_GPS_LOCK
	
typedef struct SWI_STRUCT_PDSM_PA_Gps_Lock
{
	SWI_U32				sizeStruct;
	SWI_U16				iGpsLock;				// See GPS Lock Values
} SWI_STRUCT_PDSM_PA_Gps_Lock;

	// CNS_PDSM_PA_PTLM_MODE
	
typedef struct SWI_STRUCT_PDSM_PA_PTLM_Mode
{
	SWI_U32				sizeStruct;
	SWI_U16				iTransportMech;			// See Transport Mechanism Values
} SWI_STRUCT_PDSM_PA_PTLM_Mode;

	// CNS_PDSM_PA_PORT_ID
	
typedef struct SWI_STRUCT_PDSM_PA_Port_ID
{
  SWI_U32				sizeStruct; 
  SWI_U32				iPortID;
} SWI_STRUCT_PDSM_PA_Port_ID;

	// CNS_PDSM_PA_PRIVACY
	
typedef struct SWI_STRUCT_PDSM_PA_Privacy
{
	SWI_U32				sizeStruct; 
	SWI_U16				iPrivacy;				// See Privacy Values
} SWI_STRUCT_PDSM_PA_Privacy;

	// CNS_PDSM_PA_NET_ACCESS
	
typedef struct SWI_STRUCT_PDSM_PA_Net_Access
{
	SWI_U32				sizeStruct; 
	SWI_U16				iNetAccess;				// See Network Access Values
} SWI_STRUCT_PDSM_PA_Net_Access;

	// CNS_PDSM_PA_BS_INFO
	
typedef struct SWI_STRUCT_PDSM_PA_BS_Info
{
	SWI_U32				sizeStruct; 
	SWI_U16				nInfoStale;				// 0x0000 = Info not stale, 0x0001 = Info stale
	SWI_U16				nId;					// Base Station ID
	SWI_U16				nSid;					// System ID
	SWI_U16				nNid;					// Network ID
	SWI_U32				nInfoTimeHigh;			// Time stamp high DWORD
	SWI_U32				nInfoTimeLow;			// Time stamp low DWORD	
	SWI_S32				nLatitude;				// Station Latitude
	SWI_S32				nLongitude;				// Station Longitude
} SWI_STRUCT_PDSM_PA_BS_Info;

	// CNS_PDSM_PA_SAT_INFO
	
typedef struct SWI_STRUCT_PDSM_SAT_Info
{
	SWI_U32				sizeStruct; 
	SWI_U8				nSVsInView;				// Number of Satellites in View (Max 12)
	struct
	{
		SWI_U8			nSVNumber;				// Bit 7: "1"- Used in latest Fix
												// Bits 0-6: Satellite Number (0-32)
		SWI_U8			nSVElevation;			// Satellite Elevation in degrees (0-90)
		SWI_U16			nSVAzimuth;				// Satellite Azimuth in degrees (0-360)
		SWI_U8			nSVSNR;					// Satellite Signal/Noise Ratio in dB (0-99)
	} sSATView[CNS_PDSM_MAX_NUM_SV];
} SWI_STRUCT_PDSM_SAT_Info;

	// CNS_PDSM_CLEAR_ASSISTANCE
	
typedef struct SWI_STRUCT_PDSM_CLEAR_ASSISTANCE
{
	SWI_U32				sizeStruct; 

	SWI_U8				DelEphemerisData;		// 0: Do nothing 1: Clear Satellite Ephemeris Data
	SWI_U8				DelAlmanacData;			// 0: Do nothing 1: Clear Satellite Almanac Data
	SWI_U8				DelPositionData;		// 0: Do nothing 1: Clear Position and Time information
	SWI_U8				ClrSelfLearningDB;		// 0: Do nothing 1: Clear Standalone Self Learning Data base
	SWI_U8				ClrServingSystemDB;		// 0: Do nothing 1: Clear Standalone Serving System Data Base
	SWI_U8				ClrTimeReference;		// 0: Do nothing 1: Clear Standalone Time Reference
	SWI_U8				ResetThrottleParams;	// 0: Do nothing 1: Reset MS Based Throttling Parameters
} SWI_STRUCT_PDSM_CLEAR_ASSISTANCE;

	// TODO: Tech Hdr Structures

typedef struct SWI_STRUCT_Tech_Hdr_Prev
{
	SWI_U32	sizeStruct;
	SWI_U16	hdr_p_rev_min;
	SWI_U16	hdr_p_rev_max;
} SWI_STRUCT_Tech_Hdr_Prev;

typedef struct SWI_STRUCT_Tech_Hdr_Sector			
{
	SWI_U32	sizeStruct;
	SWI_U8	hdr_sector_id[LENGTH_HdrSectorID];		// string; NOT null terminated
	SWI_U16	hdr_subnet_mask;
	SWI_U16	hdr_color_code;
	SWI_U16	hdr_pn_offset;
} SWI_STRUCT_Tech_Hdr_Sector;

typedef enum SWI_TYPE_Tech_Hdr_At_State
{
	SWI_TECH_HDR_AT_STATE_INACTIVE    = 0x0000,
	SWI_TECH_HDR_AT_STATE_ACQUISITION = 0x0001,
	SWI_TECH_HDR_AT_STATE_SYNC        = 0x0002,
	SWI_TECH_HDR_AT_STATE_IDLE        = 0x0003,
	SWI_TECH_HDR_AT_STATE_ACCESS      = 0x0004,
	SWI_TECH_HDR_AT_STATE_CONNECTED   = 0x0005,
} SWI_TYPE_Tech_Hdr_At_State;
	
	
typedef enum SWI_TYPE_Tech_Hdr_Session_State
{
	SWI_TECH_HDR_SESSION_STATE_CLOSE                    = 0x0000,
	SWI_TECH_HDR_SESSION_STATE_ADDR_MGMT_PROTOCOL_SETUP = 0x0001,
	SWI_TECH_HDR_SESSION_STATE_AT_INITIATED             = 0x0002,
	SWI_TECH_HDR_SESSION_STATE_AN_INITIATED             = 0x0003,
	SWI_TECH_HDR_SESSION_STATE_OPEN                     = 0x0004,
} SWI_TYPE_Tech_Hdr_Session_State;

typedef struct SWI_STRUCT_Tech_Hdr_State			
{
	SWI_U32	sizeStruct;
	SWI_U16	hdr_at_state; // See SWI_TYPE_Tech_Hdr_At_State
								// 0x000 - Inactive
								// 0x001 - Acquisition
								// 0x002 - Sync
								// 0x003 - Idle
								// 0x004 - Access
								// 0x005 - Connected

	SWI_U16	hdr_session;	// See SWI_TYPE_Tech_Hdr_Session_State
								// 0x000 - Close
								// 0x001 - Addresss Management Protocol set up
								// 0x002 - AT initiated
								// 0x003 - AN initiated
								// 0x004 - Open
} SWI_STRUCT_Tech_Hdr_State;

typedef struct SWI_STRUCT_Tech_Hdr_Channel			
{
	SWI_U32	sizeStruct;
	SWI_U16	hdr_channel;	// 0xFFFF = No service
} SWI_STRUCT_Tech_Hdr_Channel;

typedef struct SWI_STRUCT_Tech_Hdr_Session			
{
	SWI_U32	sizeStruct;
	SWI_U8	hdr_uati[LENGTH_HdrUati];	// string; NOT null terminated
	SWI_U16	hdr_uati_color_code;
	SWI_U32	hdr_rati;
	SWI_U16	hdr_session_duration;
	SWI_U64	hdr_session_start;			// SWI_U32 - high word of qword, SWI_U32 - low word of qword
	SWI_U64	hdr_session_end;			// SWI_U32 - high word of qword, SWI_U32 - low word of qword
} SWI_STRUCT_Tech_Hdr_Session;

typedef enum SWI_TYPE_Tech_Hdr_An_Auth
{
	SWI_TECH_HDR_AN_AUTH_NOT_AUTHENTICATED            = 0x0000,
	SWI_TECH_HDR_AN_AUTH_AUTHENTICATED                = 0x0001,
	SWI_TECH_HDR_AN_AUTH_AUTHENTICATION_FAILED        = 0x0002,
	SWI_TECH_HDR_AN_AUTH_AUTHENTICATION_DISABLED      = 0x00FF,
} SWI_TYPE_Tech_Hdr_An_Auth;

typedef struct SWI_STRUCT_Tech_Hdr_An_Auth			
{
	SWI_U32	sizeStruct;
	SWI_U16	hdr_an_auth;	// 0x0000 - Not authenticated
							// 0x0001 - Authenticated
							// 0x0002 - Authentication failed
							// 0x00FF - Authentication disabled
} SWI_STRUCT_Tech_Hdr_An_Auth;

typedef struct SWI_STRUCT_Tech_Hdr_Drc_Val			
{
	SWI_U32	sizeStruct;
	SWI_U16	hdr_drc_value;
} SWI_STRUCT_Tech_Hdr_Drc_Val;

typedef struct SWI_STRUCT_Tech_Hdr_Drc_Cover		
{
	SWI_U32	sizeStruct;
	SWI_U16	hdr_drc_cover;
} SWI_STRUCT_Tech_Hdr_Drc_Cover;

typedef struct SWI_STRUCT_Tech_Hdr_Rri				
{
	SWI_U32	sizeStruct;
	SWI_U16	hdr_rri;		// 0x00 - Pilot Only
							// 0x01 - 9.6 Kbps
							// 0x02 - 19.2 Kbps
							// 0x03 - 38.4 Kbps
							// 0x04 - 76.8 Kbps
							// 0x05 - 153.6 Kbps
} SWI_STRUCT_Tech_Hdr_Rri;

typedef struct SWI_STRUCT_Tech_Hdr_Stats			
{
	SWI_U32	sizeStruct;
	SWI_S16	hdr_rx_agc0;	// HDR Receiver Gain Control for Antenna 0,
							// main path, range is +/- 128. Note: it is
							// a signed 16 bit value.
	SWI_S16	hdr_rx_agc1;	// HDR Receiver Gain Control for Antenna 1,
							// diversity path, range is +/- 128. Note:
							// it is a signed 16 bit value.
	SWI_S16	hdr_tx_total;	// HDR TX Total Power in dbm. Note: it is
							// a signed 16 bit value.
	SWI_S16	hdr_tx_adj;		// HDR TX gain adjust in dbm. Note: it is a
							// signed 16 bit value.
	SWI_U16	hdr_c2i;		// HDR C/I carrier-to-interference ratio.
	SWI_U16	hdr_ecio;		// in 0.5 dBm units
	SWI_U16	hdr_rssi;
} SWI_STRUCT_Tech_Hdr_Stats;

typedef struct SWI_STRUCT_Tech_Hdr_Su_Fwd_Stats	
{
	SWI_U32	sizeStruct;
	SWI_U16	objectVersion;					// current object version
	SWI_U32	goodTrafficChannelCount[15];	// # of good packet count for each of 15 supported Traffic Channel rates.
	SWI_U32	badTrafficChannelCount[15];		// # of bad packet count for each of 15 supported Traffic Channel rates.
	SWI_U32	goodControlChannelCount[2];		// # of good packet count for each of 2 supported Control Channel rates.
	SWI_U32	badControlChannelCount[2];		// # of good packet count for each of 2 supported Control Channel rates.
	SWI_U16	tcPacketErrorRate;				// Traffic Channel packet error rate (%)
	SWI_U32	tcThroughputServed;				// Traffic Channel throughput in Kbps when served at requested DRC.
	SWI_U32	tcInstantaneousThroughput;		// Traffic Channel throughput in Kbps.
	SWI_U32	tcAverageThroughput;			// Traffic Channel average (1 sec) throughput in Kbps.
	SWI_U32	ccThroughputServed;				// Control Channel throughput in Kbps when served at requested DRC.
	SWI_U32	ccInstantaneousThroughput;		// Control Channel throughput in Kbps.
	SWI_U32	ccAverageThroughput;			// Control Channel average (1 sec) throughput in Kbps.
} SWI_STRUCT_Tech_Hdr_Su_Fwd_Stats;

typedef struct SWI_STRUCT_Tech_Hdr_Su_Fwd_Slot_Cnt		
{
	SWI_U32	sizeStruct;
	SWI_U16	objectVersion;				// current object version
	SWI_U32	tcDRC0EarlyTermination[16];	// # of Traffic Channel DRC0 packets that terminated at slot 1-16
	SWI_U32	tcDRC1EarlyTermination[16];	// # of Traffic Channel DRC1 packets that terminated at slot 1-16
	SWI_U32	tcDRC2EarlyTermination[8];	// # of Traffic Channel DRC2 packets that terminated at slot 1-8
	SWI_U32	tcDRC3EarlyTermination[4];	// # of Traffic Channel DRC3 packets that terminated at slot 1-4
	SWI_U32	tcDRC4EarlyTermination[2];	// # of Traffic Channel DRC4 packets that terminated at slot 1-2
	SWI_U32	tcDRC5EarlyTermination[4];	// # of Traffic Channel DRC5 packets that terminated at slot 1-4
	SWI_U32	tcDRC6EarlyTermination;		// # of Traffic Channel DRC6 packets that terminated at slot 1
	SWI_U32	tcDRC7EarlyTermination[2];	// # of Traffic Channel DRC7 packets that terminated at slot 1-2
	SWI_U32	tcDRC8EarlyTermination;		// # of Traffic Channel DRC8 packets that terminated at slot 1
	SWI_U32	tcDRC9EarlyTermination;		// # of Traffic Channel DRC9 packets that terminated at slot 1
} SWI_STRUCT_Tech_Hdr_Su_Fwd_Slot_Cnt;

typedef struct SWI_STRUCT_Tech_Hdr_Su_Fwd_Slot_Cnt2		
{
	SWI_U32	sizeStruct;
	SWI_U16	objectVersion;					// current object version
	SWI_U32	tcDRC10EarlyTermination[2];		// # of Traffic Channel DRC10 packets that terminated at slot 1-2
	SWI_U32	tcDRC11EarlyTermination;		// # of Traffic Channel DRC11 packets that terminated at slot 1
	SWI_U32	tcDRC12EarlyTermination;		// # of Traffic Channel DRC12 packets that terminated at slot 1
	SWI_U32	tcDRC13EarlyTermination[2];		// # of Traffic Channel DRC13 packets that terminated at slot 1-2
	SWI_U32	tcDRC14EarlyTermination;		// # of Traffic Channel DRC14 packets that terminated at slot 1
	SWI_U32	ccDRC15EarlyTermination[16];	// # of Control Channel DRC1 packets that terminated at slot 1-16
	SWI_U32	ccDRC2EarlyTermination[8];		// # of Control Channel DRC2 packets that terminated at slot 1-8

} SWI_STRUCT_Tech_Hdr_Su_Fwd_Slot_Cnt2;

typedef struct SWI_STRUCT_Tech_Hdr_Mu_Fwd_Stats	
{
	SWI_U32	sizeStruct;
	SWI_U16	objectVersion;					// current object version

	SWI_U32	goodDRC3_128PacketCount;		// Number of good DRC3 [128,4,256] short MU packets.
	SWI_U32	goodDRC3_256PacketCount;		// Number of good DRC3 [256,4,256] short MU packets.
	SWI_U32	goodDRC3_512PacketCount;		// Number of good DRC3 [512,4,256] short MU packets.
	SWI_U32	goodDRC3_1024PacketCount;		// Number of good DRC3 [1024,4,256] MU packets.
	SWI_U32	goodDRC5_2048PacketCount;		// Number of good DRC5 [2048,4,128] MU packets.
	SWI_U32	goodDRC8_3072PacketCount;		// Number of good DRC8 [3072,2,64] MU packets.
	SWI_U32	goodDRC10_4096PacketCount;		// Number of good DRC10 [4096,2,64] MU packets.
	SWI_U32	goodDRC13_5120PacketCount;		// Number of good DRC13 [5120,2,64] MU packets.

	SWI_U32	badDRC3PacketCount;				// Number of bad DRC3 [1024,4,256] MU packets.
	SWI_U32	badDRC5PacketCount;				// Number of bad DRC5 [2048,4,128] MU packets.
	SWI_U32	badDRC8PacketCount;				// Number of bad DRC8 [3072,2,64] MU packets.
	SWI_U32	badDRC10PacketCount;			// Number of bad DRC10 [4096,2,64] MU packets.
	SWI_U32	badDRC13PacketCount;			// Number of bad DRC13 [5120,2,64] MU packets.

	SWI_U32	DRC3_128TerminationSlotCount[4];	// Number of DRC3 [128,4,256] packets terminated at slots 1-4.
	SWI_U32	DRC3_256TerminationSlotCount[4];	// Number of DRC3 DRC3 [256,4,256] packets terminated at slots 1-4.
	SWI_U32	DRC3_512TerminationSlotCount[4];	// Number of DRC3 DRC3 [512,4,256] packets terminated at slots 1-4.
	SWI_U32	DRC3_1024TerminationSlotCount[4];	// Number of DRC3 DRC3 [1024,4,256] packets terminated at slots 1-4.
	SWI_U32	DRC5_2048TerminationSlotCount[4];	// Number of DRC5 DRC5 [2048,4,128] packets terminated at slots 1-4.
	SWI_U32	DRC8_3072TerminationSlotCount[2];	// Number of DRC6 DRC8 [3072,2,64] packets terminated at slots 1-2.
	SWI_U32	DRC10_4096TerminationSlotCount[2];	// Number of DRC10 DRC10 [4096,2,64] packets terminated at slots 1-2.
	SWI_U32	DRC13_5120TerminationSlotCount[2];	// Number of DRC13 DRC13 [5120,2,64] packets terminated at slots 1-2.
	SWI_U16	tcPacketErrorRate;			// Traffic Channel packet error rate (%)
	SWI_U32	tcThroughputServed;			// Traffic Channel throughput in Kbps when served at requested DRC.
	SWI_U32	tcInstantaneousThroughput;	// Traffic Channel throughput in Kbps.
	SWI_U32	tcAverageThroughput;		// Traffic Channel average (1 sec) throughput in Kbps.
} SWI_STRUCT_Tech_Hdr_Mu_Fwd_Stats;

typedef struct SWI_STRUCT_Tech_Hdr_Personality		
{
	SWI_U32	sizeStruct;
	SWI_U16	objectVersion;					// current object version
	SWI_U16	activePersonality;
	SWI_U16	personalityProtocolSubtypes[12];

} SWI_STRUCT_Tech_Hdr_Personality;

#pragma mark == UMTS ==
	
typedef struct SWI_STRUCT_UMTS_SERVICE_ICON
{
	SWI_U32	sizeStruct;
	SWI_U8	displayIcon;
	SWI_U8	serviceType;
	SWI_U8	attached;
	SWI_U8	pktSessionActive;
} SWI_STRUCT_UMTS_SERVICE_ICON;

typedef enum
{
	SWI_SIM_STATUS_OK = 0x00,				// 0x00
	SWI_SIM_STATUS_Not_Inserted,			// 0x01
	SWI_SIM_STATUS_Removed,					// 0x02
	SWI_SIM_STATUS_Initialize_Failure,		// 0x03
	SWI_SIM_STATUS_General_Failure,			// 0x04
	SWI_SIM_STATUS_Locked,					// 0x05
	SWI_SIM_STATUS_PIN1_Blocked,			// 0x06
	SWI_SIM_STATUS_PIN2_Blocked,			// 0x07
	SWI_SIM_STATUS_PIN1_Rejected,			// 0x08
	SWI_SIM_STATUS_PIN2_Rejected,			// 0x09
	SWI_SIM_STATUS_MEP_Locked,				// 0x0A
	SWI_SIM_STATUS_Network_Reject,			// 0x0B
} SWI_SIM_STATUS;
	
typedef enum
{
	SWI_SIM_REQUIRED_OP_No_Operation = 0x00,	// 0x00
	SWI_SIM_REQUIRED_OP_Enter_PIN,				// 0x01
	SWI_SIM_REQUIRED_OP_Enter_PIN2,				// 0x02
	SWI_SIM_REQUIRED_OP_Enter_PUK,				// 0x03
	SWI_SIM_REQUIRED_OP_Enter_PUK2,				// 0x04
	SWI_SIM_REQUIRED_OP_Enter_MEP,				// 0x05
} SWI_SIM_REQUIRED_OP;
	
typedef enum
{
	SWI_SIM_PREVIOUS_OP_No_Operation = 0x00,			// 0x00
	SWI_SIM_PREVIOUS_OP_Change_PIN,						// 0x01
	SWI_SIM_PREVIOUS_OP_Change_PIN2,					// 0x02
	SWI_SIM_PREVIOUS_OP_Enable_Disable_Verification,	// 0x03
	SWI_SIM_PREVIOUS_OP_Verify_PIN,						// 0x04
	SWI_SIM_PREVIOUS_OP_Verify_PIN2,					// 0x05
	SWI_SIM_PREVIOUS_OP_Verify_PUK,						// 0x06
	SWI_SIM_PREVIOUS_OP_Verify_PUK2,					// 0x07
	SWI_SIM_PREVIOUS_OP_MEP_Unlock,						// 0x08
	SWI_SIM_PREVIOUS_OP_Enable_PIN_Verification,		// 0x09
	SWI_SIM_PREVIOUS_OP_Disable_PIN_Verification,		// 0x0A
} SWI_SIM_PREVIOUS_OP;

typedef enum
{
	SWI_SIM_PREVIOUS_RESULT_Success = 0x00,			// 0x00
	SWI_SIM_PREVIOUS_RESULT_Failed,					// 0x01
	SWI_SIM_PREVIOUS_RESULT_Failed_PIN_Disabled,	// 0x02 PIN Verification has to be enabled before this operation can be attempted
	SWI_SIM_PREVIOUS_RESULT_Failed_PIN_Emergency,	// 0x03 Operation Failed because the PIN starts with the same digits as an emergency number
} SWI_SIM_PREVIOUS_RESULT;

typedef enum
{
	SWI_SIM_RETRY_INFO_PRESENT_No = 0x00,	// 0x00
	SWI_SIM_RETRY_INFO_PRESENT_Yes,			// 0x01
} SWI_SIM_RETRY_INFO_PRESENT;

typedef enum
{
	SWI_SIM_RETRY_INFO_PIN = 0x00,	// 0x00
	SWI_SIM_RETRY_INFO_PIN2,		// 0x01
	SWI_SIM_RETRY_INFO_PUK,			// 0x02
	SWI_SIM_RETRY_INFO_PUK2,		// 0x03
} SWI_SIM_RETRY_INFO;
	

typedef struct SWI_STRUCT_UMTS_SIM_STATUS_EXP
{
	SWI_U32						sizeStruct;
	SWI_SIM_STATUS				status;
	SWI_SIM_REQUIRED_OP			requiredOperation;
	SWI_SIM_PREVIOUS_OP			previousOperation;
	SWI_SIM_PREVIOUS_RESULT		previousResult;
	SWI_SIM_RETRY_INFO_PRESENT	retryInformationPresent;
	SWI_SIM_RETRY_INFO			retryInformation;
	SWI_U8						retryCount;
} SWI_STRUCT_UMTS_SIM_STATUS_EXP;
	
#pragma mark Basic
/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_DRV_INT_Query - SW MUX Drv Interface Query command
//
// Purpose:	This is the enumeration of Query commands to get information from 
//			SW MUX Drviver interface. 
//
// Members:	SWI_Get_Version	- Version Information of the MUX Driver
//			SWI_Get_Port_Info - Port Information for the DLCI value set
//
// Notes:	None
//
///////////////////////////////////////////////////////////////////////////////////
typedef enum 
{
    SWI_Get_Version = 1,	// Version Information of the MUX Driver
    SWI_Get_Port_Info      // Port Information for the DLCI value set
} SWI_TYPE_DRV_INT_Query;

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_DRV_VER_INFO - MUX driver information
//
// Purpose:	This structure contains MUX driver version information.
//
// Members:	MajorVersion	- Major version number of the MUX driver.	
//			MinorVersion	- Minor Vesion number of the MUX driver.
//			BuildNumber		- Build number of the MUX driver.
//
// Notes:	This structure is valid only for MUX 27.010 supported devices. 
//			Use this structure when querying SWI_Get_Version using SwiGetDrvIntInfo().
//
///////////////////////////////////////////////////////////////////////////////////
typedef struct SWI_DRV_VER_INFO
{
	SWI_U32		MajorVersion;	// Get only
	SWI_U32		MinorVersion;	// Get only
	SWI_U32		BuildNumber;	// Get only
} SWI_DRV_VER_INFO;

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_DEVICE_DLC - Device DLCI list 
//
// Purpose:	This is the enumeration of device DLCI channels supportred by MUX devices.
//
// Members:	SWI_DEVICE_DLC_ATPPP	- AT/PPP channel
//			SWI_DEVICE_DLC_DM - DM (Diagnostic monitoring) channel
//			SWI_DEVICE_DLC_CNS	- CNS (Control and Status, proprietory SW) Channel
//
// Notes:	None
//
///////////////////////////////////////////////////////////////////////////////////
typedef enum 
{
    SWI_DEVICE_DLC_ATPPP	= 1,	// DLC for AT/PPP
    SWI_DEVICE_DLC_DM		= 2,    // DLC for DM
	SWI_DEVICE_DLC_CNS		= 3,	// DLC for CNS
	SWI_DEVICE_DLC_NMEA		= 4		// DLC for NMEA
} SWI_TYPE_DEVICE_DLC;

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_SUBTYPE_DEVICE - Device type enumeration
//
// Purpose:	This is the enumeration of DLCI device type.
//
// Members:	SWI_DEVICE_MODEM	- Modem device type (For eg.AT/PPP is type modem) 
//			SWI_DEVICE_SERIAL	- Serial device type (For eg.DM is type Serial)
//			SWI_DEVICE_NETWORK	- NDIS device type (For eg.CNS can be type Network)
//
// Notes:	None
//
///////////////////////////////////////////////////////////////////////////////////
typedef enum 
{
    SWI_DEVICE_MODEM		= 0,	// Device type Modem
    SWI_DEVICE_SERIAL		= 1,    // Device type Serial
	SWI_DEVICE_NETWORK		= 2		// device type Network
} SWI_SUBTYPE_DEVICE;

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_DEVICE_STATE - Device mode state - MUX 27.010 driver specifications
//
// Purpose:	This is the enumeration of device state.
//
// Members:	SWI_DEVICE_STATE_UNKNOWN	- Device in unknown modem 
//			SWI_DEVICE_STATE_MUXMODE	- Device in MUX mode
//			SWI_DEVICE_STATE_NONMUX		- Device in Non-MUX mode
//			SWI_DEVICE_STATE_TRANSITION	- Device in transistioning mode
//			SWI_DEVICE_STATE_SYNCMODE	- Device in synchronous mode
//
// Notes:	None
//
///////////////////////////////////////////////////////////////////////////////////
typedef enum 
{
	SWI_DEVICE_STATE_UNKNOWN,	// Unknown mode
	SWI_DEVICE_STATE_MUXMODE,	// MUX mode
	SWI_DEVICE_STATE_NONMUX,	// Non-MUX mode
	SWI_DEVICE_STATE_TRANSITION,// Transition mode
	SWI_DEVICE_STATE_SYNCMODE	// Synchronizing mode
} SWI_DEVICE_STATE;

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_Port_Info - Port and device information
//
// Purpose:	This structure contains DLCI Port requested and also device state information.
//
// Members:	Dlci		- Dlci value of the port. Use this information to query for 
//					Port/Device information. This is set value in the structure.
//					Fill this value in the structure when querying SWI_Get_Port_Info
//					using SwiGetDrvIntInfo().	
//			SubType		- Dlci type if modem or serial or network
//			Acquired	- Notifies if the port is acquired by some other application.
//			ProcessId	- If port is acquired by some one, use processid to determine 
//					who owns the port.
//			ThreadId	- ThreadID of the owned process of the port.
//			State		- Device mode state. DM/CNS/other PPP ports are available only 
//					id device is in MUX mode. Non-MUX mode only AT/PPP port is available.
//			InstanceSuffix	- Suffex of the port index. For eg. if there are multiple devices
//					or ports, devices will have to be appended with the index. (For eg.
//					Friendly name for two modem devices can be Sierra Wireless Modem Device
//					and Sierra Wireless Modem Device #2, 2 is the instance suffix.)
//			Name		- Name of the port. (for eg. Com4 name is \\.\COM4)
//			InstanceId	- Unique identifier of port.
//			FriendlyName	- Friendly name of the device. (See device manager for more info)
//
// Notes:	This structure is valid only for MUX 27.010 supported devices. 
//			Check error codes for more information.
//
///////////////////////////////////////////////////////////////////////////////////
typedef struct SWI_STRUCT_Port_Info
{
	SWI_TYPE_DEVICE_DLC		Dlci;		// Set only
	SWI_SUBTYPE_DEVICE		SubType;	// Get only

	struct
	{
		bool				Acquired;	// Get only
			// owner
		SWI_U32				ProcessId;	// Get only
		SWI_U32				ThreadId;	// Get only
	} DeviceLock;

	struct
	{
		bool				Acquired;	// Get only
			// owner
		SWI_U32				ProcessId;	// Get only
		SWI_U32				ThreadId;	// Get only
	} PortAcquired;
	
	SWI_TYPE_Device			DeviceType;	// Get only

		// state	
	SWI_DEVICE_STATE		State;									// Get only
	char					InstanceSuffix[SWI_SUFFIX_ID_SIZE];		// Get only
	char					Name[SWI_PORT_NAME_SIZE];				// Get only
	char					InstanceId[SWI_INSTANCE_ID_SIZE];		// Get only
	char					FriendlyName[SWI_FRIENDLY_NAME_SIZE];	// Get only
	bool					bNDISSupported;							// Get only
	SWI_U16					usbVendorID;							// Get only	// 2008-10-02 [mdj] Added. Mac only.
	SWI_U16					usbProductID;							// Get only	// 2008-10-02 [mdj] Added. Mac only.
} SWI_STRUCT_Port_Info;

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_DRV_INT_QUERY - Generic structure for querying MUX 27.010 drivers
//
// Purpose:	This structure contains union for driver version and port information.
//			The information is returned based on the query type.
//
// Members:	eQueryType		- Fill in this information to query either Version or 
//							port information.	
//			FileVersion		- Fileversion information returned when SWI_Get_Version 
//							is used as query type.
//			PortInfo		- Port information returned when SWI_Get_Port_Info is 
//							used as query type.
//
// Notes:	This structure is valid only for MUX 27.010 supported devices. 
//			Make sure to set query type before calling SwiGetDrvIntInfo() API.
//			And if query type is SWI_Get_Port_Info, then make sure to set Dlci value 
//			for PortInfo structure.			
//
///////////////////////////////////////////////////////////////////////////////////
typedef struct SWI_DRV_INT_QUERY
{
	SWI_TYPE_DRV_INT_Query eQueryType;
	union
	{
		SWI_DRV_VER_INFO		FileVersion;
		SWI_STRUCT_Port_Info	PortInfo;
	} uResult;
} SWI_DRV_INT_QUERY;

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_NDIS_PREF_MODE - NDIS PREF Mode supported to get and set values
//
// Purpose:	This is the enumeration of NDIS Pref Mode.
//
// Members:	SWI_NDIS_PREF_ENABLED			- NDIS is enabled 
//			SWI_NDIS_PREF_DISABLED			- NDIS is disabled
//
// Notes:	NDIS when loaded aquires DATA & CNS port to talk to the modem. In some 
//			cases like Async data or fax calls, data call has to go thru DUN using
//			data channel and not over NDIS interface. In order for NDIS to release 
//			handle on data/cns even when NDIS driver is loaded, make use of Pref 
//			mode to disable/enable NDIS.
//
///////////////////////////////////////////////////////////////////////////////////
typedef enum SWI_NDIS_PREF_MODE 
{
	SWI_NDIS_PREF_DISABLED,				// Get and Set
	SWI_NDIS_PREF_ENABLED				// Get and Set	
} SWI_NDIS_PREF_MODE;

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_NDIS_MUX_MODE - Structure for querying MUX NDIS driver mode
//
// Purpose:	This structure contain values to determine NDIS supported and NDIS 
//			Pref mode stored in the modem. These values can be queried to determine
//			the current NDIS mode. 
//
// Members:	bNDISSupported	- This value will determine NDIS is supported for the
//								product or not. 	 
//			eNDISPrefMode	- This value will determine if NDIS is enabled or disabled 
//								This flag will have significance only if NDIS supported
//								flag is set to true.
//
// Notes:	NDIS driver is loaded by USB MUX drivers when NDIS supported and NDIS 
//			Pref mode are both set to true and device is in MUX mode. 			
//
///////////////////////////////////////////////////////////////////////////////////
typedef struct SWI_NDIS_MUX_MODE
{
	bool					bNDISSupported;
	SWI_NDIS_PREF_MODE		eNDISPrefMode;
} SWI_NDIS_MUX_MODE;

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_DEV_ARRIVAL_REMOVAL - Structure containing USB-level,
//			device information
//
// Purpose:	This structure contains device information passed by device "arrival"
//			and device "removal" notifications from the OS.
//
// Members:	bNDISSupported	- This value will determine NDIS is supported for the
//								product or not. 	 
//			eNDISPrefMode	- This value will determine if NDIS is enabled or disabled 
//								This flag will have significance only if NDIS supported
//								flag is set to true.
//
// Notes:	NDIS driver is loaded by USB MUX drivers when NDIS supported and NDIS 
//			Pref mode are both set to true and device is in MUX mode. 			
//
///////////////////////////////////////////////////////////////////////////////////
#define SWI_DEVICE_DETAILS_MODEM_NAME_LENGTH	32
#define SWI_DEVICE_DETAILS_BSD_PATH_LENGTH		64
#define SWI_DEVICE_DETAILS_SERVICE_TYPE_LENGTH	32

typedef struct SWI_STRUCT_DEV_ARRIVAL_REMOVAL
{
	SWI_U16		vendorID;		// should always be 0x1199, for Sierra devices
	SWI_U16		productID;
	SWI_U32		locationID;		// USB address
	SWI_CHAR	modemName[SWI_DEVICE_DETAILS_MODEM_NAME_LENGTH];
	SWI_CHAR	bsdPath[SWI_DEVICE_DETAILS_BSD_PATH_LENGTH];
	SWI_CHAR	serviceType[SWI_DEVICE_DETAILS_SERVICE_TYPE_LENGTH];
} SWI_STRUCT_DEV_ARRIVAL_REMOVAL;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_Tech_Packet_Call_Control_State 
//
// Purpose:     Contains the last call control state.
//
// Members:     state[OUT]   - the call control state
//
// Notes:       Packet call control state (uint16)
//                  Enum name                  Value   Description
//                  CALL_STATE_NO_SERVICE        0     No service or Idle
//                  CALL_STATE_CONNECTING        1     Connecting
//                  CALL_STATE_AUTHENTICATING    2     Authenticating
//                  CALL_STATE_CONNECTED_ACTIVE  3     Connected Active
//                  CALL_STATE_CONNECTED_DORMANT 4     Connected Dormant
//                  CALL_STATE_DISCONNECTING     5     Disconnecting
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct SWI_STRUCT_Tech_Packet_Call_Control_State
{
	SWI_U32	sizeStruct;
	SWI_U16	state;
} SWI_STRUCT_Tech_Packet_Call_Control_State;
	
	
//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_Notify - Notification Types
//
// Purpose:	This enumerated data type defines a variety of notification types.
//
// Members:
//			SWI_NOTIFY_null					- Null notification
//	
//			SWI_NOTIFY_HeartBeat				- Not supported in the SDK.
//
//			SWI_NOTIFY_Rssi					- The Received Signal Strength Indicator (RSSI) 
//				is reported whenever the value changes.
//				Using this notification type, the application can keep the user aware of 
//				changes in the received signal strength (RSSI). The polling equivalent is
//				SwiGetRssi.
//				The notification is issued at the slot cycle index as set by the service 
//				provider. For larger slot cycle indexes, the notification is issued less often.
//				A slot cycle index of 1 generates this notification at about 2-second intervals.
//				See also:	SWI_STRUCT_Rssi
//
//			SWI_NOTIFY_ChannelNumber		- Reports each channel number the radio tunes to.
//				Using this notification type, the application is advised each time the radio 
//				tunes to a different channel. This can be very frequent when the radio is 
//				scanning for a usable channel. The polling equivalent is SwiGetChannelNumber.
//				See Also:	SWI_STRUCT_ChannelNumber
//
//			SWI_NOTIFY_ChannelState			- Reports channel acquisition and scanning.
//				Using this notification type, the application can keep the user aware of 
//				changes in the channel lock of the radio. Whenever the radio acquires or
//				loses a channel, this notification is issued. There is no polling equivalent.
//				See Also:	SWI_STRUCT_ChannelState
//
//			SWI_NOTIFY_ServiceIndication	- Reports entering and leaving coverage.
//				Using this notification type, the application can keep the user aware of 
//				changes in the channel lock of the radio. Whenever the radio acquires or
//				loses a channel, this notification is issued. 
//				The polling equivalent is SwiGetServiceIndication.
//				See Also:	SWI_STRUCT_ServiceIndication
//
//			SWI_NOTIFY_RoamingStatus		- Reports the current roaming state of the modem.
//				Using this notification type, the application can keep the user aware of 
//				changes in the received signal strength (RSSI). The polling equivalent is
//				SwiGetRoamingStatus.
//				The notification is issued whenever there is a change in the RSSI.
//				See Also:	SWI_TYPE_RoamingState, SWI_STRUCT_RoamingStatus
//
//			SWI_NOTIFY_Ecio					- Not supported in the SDK.
//
//			SWI_NOTIFY_AuthenticationStatus	- Not supported in the SDK.
//
//			SWI_NOTIFY_CallByteCounter		- Reports data traffic received and transmitted.
//				Using this notification type, the application can keep the user aware of 
//				the amount of traffic on the current connection. The polling equivalent is
//				SwiGetByteCounter.
//				The notification is issued at 1-second intervals during a data connection.
//				See Also:	SWI_STRUCT_CallByteCounter
//
//			SWI_NOTIFY_CallConnecting		- Reports when a call connection is initiated.
//				This notification advises the application that the process of connecting a 
//				call has initiated. There is no polling equivalent.
//				This notification is enabled and disabled via SWI_NOTIFY_CallNotificationStatus.
//				See Also:	SWI_STRUCT_CallConnecting, SWI_NOTIFY_CallNotificationStatus
//
//			SWI_NOTIFY_CallConnected		- Reports the successful connection of a call.
//				This notification advises the application that a call has been successfully 
//				connected. There is no polling equivalent.
//				This notification is enabled and disabled via SWI_NOTIFY_CallNotificationStatus.
//				See Also:	SWI_STRUCT_CallConnected, SWI_NOTIFY_CallNotificationStatus,
//							SWI_NOTIFY_CallDormant
//
//			SWI_NOTIFY_CallIncoming			- Equivalent to a ring, this advises of the 
//				incoming call type as well.
//				This notification advises the application that there is an incoming call request. 
//				There is no polling equivalent.
//				This notification is enabled and disabled via SWI_NOTIFY_CallNotificationStatus.
//				See Also:	SWI_STRUCT_CallIncoming, SWI_NOTIFY_CallNotificationStatus
//
//			SWI_NOTIFY_CallCallerID			- Reports the standard caller ID of incoming 
//				calls (where supported by the network).
//				This notification type passes the caller ID string to the application for 
//				incoming calls (where supported by the network). The polling equivalent is 
//				SwiGetCallerID.
//				The format of the string is determined by the network. Both the standard and 
//				extended caller IDs are sent if enabled.
//				See Also:	SWI_STRUCT_CallCallerID
//
//			SWI_NOTIFY_CallExtendedCallerID	- Reports the extended caller ID of incoming 
//				calls (where supported by the network).
//				This notification type passes an extended caller ID string to the application 
//				for incoming calls (where supported by the network). The polling equivalent 
//				is SwiGetCallerID.
//				The format of the string is determined by the network. Both the standard and 
//				extended caller IDs are sent if enabled.
//				See Also:	SWI_STRUCT_CallExtendedCallerID
//
//			SWI_NOTIFY_CallDisconnected		- Reports when a call is disconnected.
//				This notification advises the application that a call has been disconnected. 
//				There is no polling equivalent.
//				This notification is enabled and disabled via SWI_NOTIFY_CallNotificationStatus.
//				See Also:	SWI_STRUCT_CallDisconnected, SWI_NOTIFY_CallNotificationStatus
//
//			SWI_NOTIFY_CallError			- Reports errors in call management operations.
//				This notification advises the application that an error or fault has been 
//				detected in a call. This can happen anytime during a connection. There is
//				no polling equivalent.
//				This notification is enabled and disabled via SWI_NOTIFY_CallNotificationStatus.
//				See Also:	SWI_STRUCT_CallError, SWI_TYPE_CallError, SWI_TYPE_CallCmd,
//							SWI_NOTIFY_CallNotificationStatus
//
//		    SWI_NOTIFY_SmsStatus			- Reports the status of SMS records on the modem
//				whenever a new message arrives.
//				Whenever an SMS message arrives, the modem can generate this event notification. 
//				The data reported advises the application of the number of SMS messages stored 
//				in the modem.
//				This SmsStatus notification will trigger on the arrival of any SMS message that 
//				can be stored in the modem. If the modem memory fills, and additional messages 
//				are declined, there is no further notification.
//				See Also:	SWI_STRUCT_SMS_Status
//
//			SWI_NOTIFY_SmsSendStatus		- Reports the results of sending a mobile 
//				originated SMS message.
//				This notification type passes the networkís acknowledgement to the application 
//				for SMS messages sent. There is no polling equivalent.
//				See Also:	SWI_TYPE_SMS_ErrorClass, SWI_TYPE_SMS_CauseCode,
//							SWI_STRUCT_SMS_SendStatus
//
//			SWI_NOTIFY_Prev					- Reports changes in the protocol revision 
//				available from the serving base station.
//				This notification type advises the application when there is a change in the 
//				protocol revision supported by the serving base station. The polling 
//				equivalent is SwiGetCurrentBaseStation.
//				See Also:	SWI_STRUCT_Prev
//
//			SWI_NOTIFY_HeadsetState			- Reports when the headset is attached or removed.
//				Note: Headset state is not supported on the SB555.
//				This notification type informs the application whenever the voice headset is 
//				attached or removed.
//				The polling equivalent is SwiGetHeadsetState.
//				See Also:	SWI_STRUCT_HeadsetState
//
//			SWI_NOTIFY_ActiveNam			- Not yet implemented.
//
//			SWI_NOTIFY_TechSid				- Not yet implemented.
//
//			SWI_NOTIFY_TechNid				- Not yet implemented.
//
//			SWI_NOTIFY_TechBsInfo			- Not yet implemented.
//
//			SWI_NOTIFY_TechBandClass		- Reports changes in the radio band being used 
//				(cellular or PCS).
//				This notification type informs the application of changes in the radio band 
//				being used: cellular or PCS. There is no polling equivalent.
//				The notification is issued whenever there is a change in the radio tuning band.
//				See Also:	SWI_STRUCT_TechBandClass
//
//			SWI_NOTIFY_TechRegZone			- Not yet implemented.
//
//			SWI_NOTIFY_TechPacketZone		- Not yet implemented.
//
//			SWI_NOTIFY_TechPcsBlock			- Not yet implemented.
//
//			SWI_NOTIFY_TechCellChannel		- Not yet implemented.
//
//			SWI_NOTIFY_SystemTime			- Not yet implemented.
//
//			SWI_NOTIFY_ActivationStatus		- Not yet implemented.
//
//			SWI_NOTIFY_V42BisEnabled		- Not yet implemented.
//
//			SWI_NOTIFY_CallNotificationStatus	
//											- Enables and disables a group of
//				notifications related to call management.
//				This notification type is used to enable and disable the following call 
//				management notifications as a single block:
//					- SWI_NOTIFY_CallConnecting
//					- SWI_NOTIFY_CallConnected
//					- SWI_NOTIFY_CallIncoming
//					- SWI_NOTIFY_CallDisconnected
//					- SWI_NOTIFY_CallError
//					- SWI_NOTIFY_CallDormant
//					- SWI_NOTIFY_OTASPState
//				There is no actual notification data associated with CallNotificationStatus 
//				itself.
//
//			SWI_NOTIFY_CallDormant			- Reports when a call enters dormant state.
//				This notification advises the application that a call has been placed in 
//				dormant state. There is no polling equivalent.
//				When a call leaves dormant state, the SWI_NOTIFY_CallConnected notification 
//				is issued.
//				This notification is enabled and disabled via SWI_NOTIFY_CallNotificationStatus.
//				See Also:	SWI_STRUCT_CallDormant
//
//			SWI_NOTIFY_CallPrivacy			- Reports changes in voice call privacy.
//				When the Enhanced Privacy Option is enabled (at manufacturing time), the modem 
//				issues a request to use the Call Privacy feature whenever a voice call (both 
//				incoming and outgoing) is established. The base station can accept or reject
//				the request depending on its settings. If voice privacy is successfully 
//				established, this notification indicates that call privacy is on. In addition, 
//				when a handover to a new base station occurs, the voice privacy feature may or 
//				may not be available at the new base station; again triggering the notificiation 
//				if there is a change.
//				There is no polling equivalent to this notification.
//				See Also:	SWI_STRUCT_CallPrivacy
//
//			SWI_NOTIFY_E911Mode				- Reports entry to, and exit from, E911 mode.
//				This notification type advised the application when the modem enters or 
//				leaves E911 mode.
//				The polling equivalent is SwiGetE911Mode.
//				See Also:	SWI_STRUCT_E911Mode
//
//			SWI_NOTIFY_ModemTooHotIndication	
//											- Not yet implemented.
//
//			SWI_NOTIFY_OTASPState			- Reports each stage of the OTASP process.
//				This notification advises the application that a call has been placed in 
//				dormant state. There is no polling equivalent.
//				This notification is enabled and disabled via SWI_NOTIFY_CallNotificationStatus.
//				See Also:	SWI_STRUCT_OTASPState, SWI_NOTIFY_CallNotificationStatus
//
//			SWI_NOTIFY_PowerSaveEnter		- Reports entry to power-save mode.
//				This notification type advised the application when the modem enters  
//				power-save mode.
//				The polling equivalent is SwiGetTechPowersaveMode.
//				See Also:	SWI_STRUCT_PowerSaveEnter
//
//			SWI_NOTIFY_PowerSaveExit		- Reports exit from power-save mode.
//				This notification type advised the application when the modem leaves
//				power-save mode.
//				The polling equivalent is SwiGetTechPowersaveMode.
//				See Also:	SWI_STRUCT_PowerSaveExit
//
//			SWI_NOTIFY_FlashBurn			- Not supported in the SDK.
//
//			SWI_NOTIFY_ExcessSPCFailure		- Not supported in the SDK.
//
//			SWI_NOTIFY_Band					- Not yet implemented.
//
//			SWI_NOTIFY_TransmitAlert		- Not yet implemented.
//
//			SWI_NOTIFY_Reset				- AirCard products only (not SB555) NDIS
//				reports to the application when the modem has completed a reset.
//				This is critical to restoring other desired notifications.
//				This notification is always enabled. It is sent to the application when the 
//				modem as completed a reset. This is needed to advise the application 
//				that all other notifications have been disabled (the default at power up and 
//				reset).
//				When received, the application must re-enable all desired notifications.
//				* Note, this notification may also erroneously appear after ejecting & 
//				reinserting the	modem.  
//				See Also:	SWI_STRUCT_Reset
//
//			SWI_NOTIFY_Power				- AirCard products only (not SB555) NDIS 
//				reports changes in PC Card state.
//				This notification is always enabled in AirCard products (EXCEPT AC580);
//        it is not supported by the SB555.
//				It is sent to the application when the NDIS driver detects the modem power 
//				state has changed. This typically indicates the user has ejected the PC Card.
//				See Also:	SWI_STRUCT_Power
//
//			SWI_NOTIFY_Dhcp					- Not yet implemented.
//
//			SWI_NOTIFY_PPP					- AirCard products only (not SB555) NDIS reports 
//				PPP connection status.
//				This notification is always enabled in AirCard products; it is not supported 
//				by the SB555.
//				It is sent to the application by the NDIS driver to track the progress of 
//				PPP connections. -- NOT SUPPORTED by AC580
//				See Also:	SWI_STRUCT_PPP
//
//			SWI_NOTIFY_Hdr_Acq				- Not supported/used -- use SWI_NOTIFY_Hdr_Srv_State
//
//		  SWI_NOTIFY_Hdr_Rssi				- Not supported/used -- use SWI_NOTIFY_Rssi_Ecio
//
//      SWI_NOTIFY_HdrNotificationStatus, -- Not implemented yet
//
//      SWI_NOTIFY_Rssi_Ecio    - Indicates a threshold change in RSSI or EcIo
//
//      SWI_NOTIFY_Hdr_Roam_Status - Indicates a change in HDR Roam status
//
//      SWI_NOTIFY_Hdr_Srv_State  - Indicates a change in HDR Service State
//
//      SWI_NOTIFY_Hdr_Hybr_Pref  - Indicates a change in HDR Hybrid Pref
//
//      SWI_NOTIFY_Idle_Digital_Mode -- Not supported/used
//
//      SWI_NOTIFY_DDTM_Pref      - Indicates a change in DDTM pref
//
//      SWI_NOTIFY_Hdr_PowerSave_Enter - Indicates when modem has entered
//                                       HDR Power save mode.
//
//      SWI_NOTIFY_Hdr_PowerSave_Exit - Indicates when modem has exited
//                                      HDR power save mode            
//
//
//      SWI_NOTIFY_TechHdrNotificationStatus, 
//			SWI_NOTIFY_Tech_Hdr_Prev,
//			SWI_NOTIFY_Tech_Hdr_Sector,
//			SWI_NOTIFY_Tech_Hdr_State,
//			SWI_NOTIFY_Tech_Hdr_Channel,
//			SWI_NOTIFY_Tech_Hdr_Session,
//			SWI_NOTIFY_Tech_Hdr_An_Auth,
//			SWI_NOTIFY_Tech_Hdr_Drc_Val,
//			SWI_NOTIFY_Tech_Hdr_Drc_Cover,
//			SWI_NOTIFY_Tech_Hdr_Rri,
//			SWI_NOTIFY_Tech_Hdr_Stats,
//
//		SWI_NOTIFY_PDSMLocNotificationStatus	
//			- Enables and disables a group of notifications related to PDSM location session data.
//				- SWI_NOTIFY_PDSM_PD_Begin
//				- SWI_NOTIFY_PDSM_PD_Data
//				- SWI_NOTIFY_PDSM_PD_End
//				- SWI_NOTIFY_PDSM_PD_Done
//				- SWI_NOTIFY_PDSM_PD_UpdateFailure
//			There is no actual notification data associated with DPSMLocNotificationStatus 
//			itself.
//
//		SWI_NOTIFY_PDSMDloadNotificationStatus
//			- Enables and disables a group of notifications related to PDSM notification for any changes made to LBS nv items.
//				- SWI_NOTIFY_PDSM_PD_Dload_Begin
//				- SWI_NOTIFY_PDSM_PD_Dload
//				- SWI_NOTIFY_PDSM_PD_Dload_End
//				- SWI_NOTIFY_PDSM_PD_Dload_Done
//		SWI_NOTIFY_PDSMParamNotificationStatus
//			- Enables and disables a group of notifications related to PDSM notification for Data download.
//				- SWI_NOTIFY_PDSM_PA_Address
//				- SWI_NOTIFY_PDSM_PA_GpsLock
//				- SWI_NOTIFY_PDSM_PA_PtlmMode
//				- SWI_NOTIFY_PDSM_PA_PortID
//				- SWI_NOTIFY_PDSM_PA_Privacy
//				- SWI_NOTIFY_PDSM_PA_NetAccess
//
//		SWI_NOTIFY_DebugRevMsg			- Not supported in the SDK.
//
//		SWI_NOTIFY_SPCS_HIOTA_STATUS	- Not yet implemented.
//
//		SWI_NOTIFY_Debug				- Not supported in the SDK.
//
//		SWI_NOTIFY_FwDownload		- Provides firmware download progress status.  Errors
//										  during the firmware download process are also reported.
//		
// MP555 objects
//
//			SWI_NOTIFY_Gps					- Not supported in the SDK.
//
//			SWI_NOTIFY_ExtDio				- Not supported in the SDK.
//
//			SWI_NOTIFY_ExtAi				- Not supported in the SDK.
//
//			SWI_NOTIFY_GpsCommand			- Not supported in the SDK.
//
//			SWI_NOTIFY_MpByteCount			- Not supported in the SDK.
//
//			SWI_NOTIFY_MPIgnSense			- Not supported in the SDK.
//
//			SWI_NOTIFY_RfDownload			- Not supported in the SDK.
//
//			SWI_NOTIFY_SimSled				- Not supported in the SDK.
//
//			SWI_NOTIFY_LowBattery			- Not supported in the SDK.
//
//			SWI_NOTIFY_MpShutdown			- Not supported in the SDK.
//
//			SWI_NOTIFY_MpConnect			- Not supported in the SDK.
//
//			SWI_NOTIFY_MpStartupDiag		- Not supported in the SDK.
//
//			SWI_NOTIFY_END_MP				- Not supported in the SDK.
//
//			SWIHW_NOTIFY_Power				- Supported via SWI[OEM name]Aux.dll only
//
//			SWI_NOTIFY_IOTA_Status			- Supported only for sprint network
//
//			SWI_NOTIFY_IOTA_WAPPush			- Supported only for sprint network
//
//			SWI_NOTIFY_END_NOTIFY			- Not supported in the SDK.
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	SWI_NOTIFY_null,	/* 0x0000 (0)*/
	SWI_NOTIFY_HeartBeat,
	SWI_NOTIFY_Rssi,
	SWI_NOTIFY_ChannelNumber,
	SWI_NOTIFY_ChannelState,
	SWI_NOTIFY_ServiceIndication,	/* 0x0005 (5) */
	SWI_NOTIFY_RoamingStatus,
	SWI_NOTIFY_Ecio,
	SWI_NOTIFY_AuthenticationStatus,
	SWI_NOTIFY_CallByteCounter,
	SWI_NOTIFY_CallConnecting,	/* 0x000A (10) */
	SWI_NOTIFY_CallConnected,
	SWI_NOTIFY_CallIncoming,
	SWI_NOTIFY_CallCallerID,
	SWI_NOTIFY_CallExtendedCallerID,
	SWI_NOTIFY_CallDisconnected,	/* 0x000F (15) */
	SWI_NOTIFY_CallError,
	SWI_NOTIFY_SmsStatus,
	SWI_NOTIFY_SmsSendStatus,
	SWI_NOTIFY_Prev,
	SWI_NOTIFY_HeadsetState,	/* 0x0014 (20) */
	SWI_NOTIFY_ActiveNam,
	SWI_NOTIFY_TechSid,
	SWI_NOTIFY_TechNid,
	SWI_NOTIFY_TechBsInfo,
	SWI_NOTIFY_TechBandClass,	/* 0x0019 (25) */
	SWI_NOTIFY_TechRegZone,
	SWI_NOTIFY_TechPacketZone,
	SWI_NOTIFY_TechPcsBlock,
	SWI_NOTIFY_TechCellChannel,
	SWI_NOTIFY_SystemTime,	/* 0x001e (30) */
	SWI_NOTIFY_ActivationStatus,
	SWI_NOTIFY_V42BisEnabled,
	SWI_NOTIFY_CallNotificationStatus,
	SWI_NOTIFY_CallDormant,
	SWI_NOTIFY_CallPrivacy,	/* 0x0023 (35) */
	SWI_NOTIFY_E911Mode,
	SWI_NOTIFY_ModemTooHotIndication,
	SWI_NOTIFY_OTASPState,
	SWI_NOTIFY_PowerSaveEnter,
	SWI_NOTIFY_PowerSaveExit,	/* 0x0028 (40) */
	SWI_NOTIFY_FlashBurn,
	SWI_NOTIFY_ExcessSPCFailure,

	SWI_NOTIFY_Band,
	SWI_NOTIFY_TransmitAlert,
	SWI_NOTIFY_Reset,				// 0x002d (45)
	SWI_NOTIFY_Power,				// Software power state change. No need to enable mask
	SWI_NOTIFY_Dhcp,
	SWI_NOTIFY_PPP,

	SWI_NOTIFY_HdrNotificationStatus,
	SWI_NOTIFY_Hdr_Acq,				// 0x0032 (50)
	SWI_NOTIFY_Hdr_Rssi,
	SWI_NOTIFY_Rssi_Ecio,
	SWI_NOTIFY_Hdr_Roam_Status,
	SWI_NOTIFY_Hdr_Srv_State,
	SWI_NOTIFY_Hdr_Hybr_Pref,	/* 0x0037 (55) */
	SWI_NOTIFY_Idle_Digital_Mode,
	SWI_NOTIFY_DDTM_Pref,
	SWI_NOTIFY_Hdr_PowerSave_Enter,
	SWI_NOTIFY_Hdr_PowerSave_Exit,

	SWI_NOTIFY_TechHdrNotificationStatus,	// 0x003c (60)
	SWI_NOTIFY_Tech_Hdr_Prev,
	SWI_NOTIFY_Tech_Hdr_Sector,
	SWI_NOTIFY_Tech_Hdr_State,
	SWI_NOTIFY_Tech_Hdr_Channel,
	SWI_NOTIFY_Tech_Hdr_Session,	/* 0x0041 (65) */
	SWI_NOTIFY_Tech_Hdr_An_Auth,
	SWI_NOTIFY_Tech_Hdr_Drc_Val,
	SWI_NOTIFY_Tech_Hdr_Drc_Cover,
	SWI_NOTIFY_Tech_Hdr_Rri,
	SWI_NOTIFY_Tech_Hdr_Stats,				// 0x0046 (70)
	SWI_NOTIFY_DebugRevMsg,
	SWI_NOTIFY_SPCS_HIOTA_STATUS,

	SWI_NOTIFY_RuimStatus,

	SWI_NOTIFY_Debug,				//debug string

	// MP555 objects
	SWI_NOTIFY_MpFwDownload,		// 0x004b (75) MP Firmware download state
	SWI_NOTIFY_Gps,
	SWI_NOTIFY_ExtDio,
	SWI_NOTIFY_ExtAi,
	SWI_NOTIFY_GpsCommand,
	SWI_NOTIFY_MpByteCount,			// 0x0050 (80)
	SWI_NOTIFY_MPIgnSense,
	SWI_NOTIFY_RfDownload,			// RF download progress
	SWI_NOTIFY_SimSled,				// SIM sled
	SWI_NOTIFY_BatteryStatus,		// low batter alert
	SWI_NOTIFY_MpShutdown,			// MP shutdown	/* 0x0055 (85) */
	SWI_NOTIFY_MpConnect,
	SWI_NOTIFY_MpStartupDiag,
	SWI_NOTIFY_MpDisconnect,		// MP disconnect notification

	SWI_NOTIFY_END_MP,				// place holder - end of MP notifications

	SWI_NOTIFY_SwiApi_State,		// SwiApi state changed (swiapi opened, cloesed, etc.)	// 0x005a (90) 
	
	SWIHW_NOTIFY_Power,				// Hardware power state change. No need to unenable mask.
	
	SWI_NOTIFY_IOTA_Status,		// Embedded IOTA  status notification. need to enable/disable the mask.

	SWI_NOTIFY_IOTA_WAPPush,		// Embedded IOTA  WAP URI notification this should be enabled to receive the wap trigger 
                              // mostly used for logging.
/////// Location Based Service ////////////
	SWI_NOTIFY_PDSMLocNotifyStatus, // WRONG!
	//SWI_NOTIFY_PDSMLocNotificationStatus,
	SWI_NOTIFY_PDSM_PD_Data,	/* 0x005f (95) */
	SWI_NOTIFY_PDSM_PD_End,
	SWI_NOTIFY_PDSM_PD_Done,
	SWI_NOTIFY_PDSM_PD_Begin,
	SWI_NOTIFY_PDSM_PD_UpdateFailure,
	
	SWI_NOTIFY_PDSMDloadNotifyStatus,  // WRONG!	// 0x0064 (100)
	//SWI_NOTIFY_PDSMDloadNotificationStatus,
	SWI_NOTIFY_PDSM_PD_Dload_Begin,
	SWI_NOTIFY_PDSM_PD_Dload_Data,
	SWI_NOTIFY_PDSM_PD_Dload_End,
	SWI_NOTIFY_PDSM_PD_Dload_Done,

	SWI_NOTIFY_PDSMParamNotifyStatus, // WRONG!	/* 0x0069 (105) */
	//SWI_NOTIFY_PDSMParamNotificationStatus,
	SWI_NOTIFY_PDSM_PA_Address,
	SWI_NOTIFY_PDSM_PA_GpsLock,
	SWI_NOTIFY_PDSM_PA_PtlmMode,
	SWI_NOTIFY_PDSM_PA_PortID,
	SWI_NOTIFY_PDSM_PA_Privacy,						// 0x006e (110)
	SWI_NOTIFY_PDSM_PA_NetAccess,
	SWI_NOTIFY_PDSM_PA_BsInfo,
	SWI_NOTIFY_PDSM_SAT_Info,
	////////////////////////////////////////////
		
	// CWE 3.x
	SWI_NOTIFY_RadioPower,
	SWI_NOTIFY_RadioTemp,	/* 0x0073 (115) */
	SWI_NOTIFY_RadioBattery,
	SWI_NOTIFY_NVRAMStore,
	SWI_NOTIFY_HeadsetIcon,
	SWI_NOTIFY_NVUpdateFromFile,

	// Rev A
	SWI_NOTIFY_Tech_Hdr_Su_Fwd_Stats,				// 0x0078 (120)
	SWI_NOTIFY_Tech_Hdr_Su_Fwd_Slot_Cnt,
	SWI_NOTIFY_Tech_Hdr_Su_Fwd_Slot_Cnt2,
	SWI_NOTIFY_Tech_Hdr_Mu_Fwd_Stats,
	SWI_NOTIFY_Tech_Hdr_Personality,

	// Firmware Update
	SWI_NOTIFY_FwDownload,	/* 0x007d (125) */
	SWI_NOTIFY_CurrentRadioBand,

	// OMA-DM
	SWI_NOTIFY_OMADM_Config,						// 0x007f (127)
	SWI_NOTIFY_OMADM_State,
	SWI_NOTIFY_OMADM_NI_Alert,
	SWI_NOTIFY_OMADM_UI_Alert_Display,				// 0x0082 (130)
	SWI_NOTIFY_OMADM_UI_Alert_Confirm,
	SWI_NOTIFY_OMADM_UI_Alert_Input,
	SWI_NOTIFY_OMADM_UI_Alert_Choice,	// 0x0085 (133)

	// FOTA
	SWI_NOTIFY_DM_DL_Progress, // 0x0086 (134)
	SWI_NOTIFY_DM_DL_Alert,
	SWI_NOTIFY_DM_DL_InstallStatus,

	// Tech
	SWI_NOTIFY_Tech_Packet_Call_Control_State,	// 0x0089

	// WiMAX
	SWI_NOTIFY_WIMAX_Operating_Mode,			// 0x008A

	// UMTS/GSM notifications
	SWI_NOTIFY_UMTS_CALL_BYTE_CNT,	// 0x008B
	SWI_NOTIFY_UMTS_SERVICE_ICON,

	// UMTS/GSM SIM Security
	SWI_NOTIFY_UMTS_SIM_STATUS_EXP,	// 0x008D
	
	// Non-modem notifications.
	SWI_NOTIFY_NON_MODEM_NOTIFICATIONS = 512,	// 0x200. Arbitrary. Leave 372 empty "slots" for future modem notifications

	SWI_NOTIFY_USB_Device_Arrival_Notification = SWI_NOTIFY_NON_MODEM_NOTIFICATIONS,
	SWI_NOTIFY_USB_Device_Removal_Notification,

	SWI_NOTIFY_END_NOTIFY			// place holder - must be last entry in this list			
} SWI_TYPE_Notify;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiNotifyVariant - SWI_TYPE_Notify variant
//
// Purpose:     This enumerated data type defines the various
//				types of notifications supported in this edition of the API.
//
// Members:  	SWI_TYPE_Notify members
//
// Notes:	    See description of SWI_TYPE_Notify for more detail
//
//////////////////////////////////////////////////////////////////////////////////
typedef struct SwiNotifyVariant
{
    SWI_TYPE_Notify  eNotify;
	union									// Added as they get done...
	{
		SWI_STRUCT_Rssi					_Rssi;
		SWI_STRUCT_ChannelNumber		_ChannelNumber;
		SWI_STRUCT_ChannelState			_ChannelState;
		SWI_STRUCT_TechBandClass		_TechBandClass;
		SWI_STRUCT_ServiceIndication	_ServiceIndication;
		SWI_STRUCT_RoamingStatus		_RoamingStatus;
		SWI_STRUCT_CallByteCounter		_CallByteCounter;
		SWI_STRUCT_CallConnecting		_CallConnecting;
		SWI_STRUCT_CallConnected		_CallConnected;
		SWI_STRUCT_CallIncoming			_CallIncoming;
		SWI_STRUCT_CallCallerID			_CallCallerID;
		SWI_STRUCT_CallExtendedCallerID	_CallExtendedCallerID;
		SWI_STRUCT_CallDisconnected		_CallDisconnected;
		SWI_STRUCT_CallDormant			_CallDormant;
		SWI_STRUCT_CallError			_CallError;
		SWI_STRUCT_OTASPState			_OTASPState;
		SWI_STRUCT_CallPrivacy			_CallPrivacy;
		SWI_STRUCT_E911Mode				_E911Mode;
		SWI_STRUCT_Reset				_Reset;
		SWI_STRUCT_Prev					_Prev;
		SWI_STRUCT_HeadsetState			_HeadsetState;
		SWI_STRUCT_ActiveNam			_ActiveNam;
		SWI_STRUCT_Rssi_Ecio			_Rssi_Ecio;
		SWI_STRUCT_Hdr_Rssi				_Hdr_Rssi;
		SWI_STRUCT_Hdr_Roam_Status		_Hdr_Roam_Status;
		SWI_STRUCT_Hdr_Srv_State		_Hdr_Srv_State;
		SWI_STRUCT_Hdr_Hybr_Pref		_Hdr_Hybr_Pref;
		SWI_STRUCT_Idle_Digital_Mode	_Idle_Digital_Mode;
		SWI_STRUCT_DDTM_Pref			_DDTM_Pref;
		
		SWI_STRUCT_IOTA_Status			_IOTA_Status;
		
			// PDSM

		SWI_STRUCT_PDSM_PD_Data					_PDSM_PD_Data;
		SWI_STRUCT_PDSM_PD_Done					_PDSM_PD_Done;
		SWI_STRUCT_PDSM_PD_End					_PDSM_PD_End;
		SWI_STRUCT_PDSM_PD_Begin				_PDSM_PD_Begin;
		SWI_STRUCT_PDSM_PD_Update_Failure		_PDSM_PD_Update_Failure;
		SWI_STRUCT_PDSM_PD_DLOAD_Begin			_PDSM_PD_DLoad_Begin;
		SWI_STRUCT_PDSM_PD_DloadData			_PDSM_PD_DloadData;
		SWI_STRUCT_PDSM_PD_DLOAD_Done			_PDSM_PD_Dload_Done;
		SWI_STRUCT_PDSM_DLOAD_End				_PDSM_PD_Dload_End;
		SWI_STRUCT_PDSM_PA_IP_Addr				_PDSM_PA_IP_Addr;
		SWI_STRUCT_PDSM_PA_Gps_Lock				_PDSM_PA_Gps_Lock;
		SWI_STRUCT_PDSM_PA_PTLM_Mode			_PDSM_PA_PTLM_Mode;
		SWI_STRUCT_PDSM_PA_Port_ID				_PDSM_PA_Port_ID;
		SWI_STRUCT_PDSM_PA_Privacy				_PDSM_PA_Privacy;
		SWI_STRUCT_PDSM_PA_Net_Access			_PDSM_PA_Net_Access;
		SWI_STRUCT_PDSM_PA_BS_Info				_PDSM_PA_Bs_Info;
		SWI_STRUCT_PDSM_SAT_Info				_PDSM_SAT_Info;

			// Tech Hdr
		SWI_STRUCT_Tech_Hdr_Prev				_Tech_Hdr_Prev;
		SWI_STRUCT_Tech_Hdr_Sector				_Tech_Hdr_Sector;
		SWI_STRUCT_Tech_Hdr_State				_Tech_Hdr_State;
		SWI_STRUCT_Tech_Hdr_Channel				_Tech_Hdr_Channel;
		SWI_STRUCT_Tech_Hdr_Session				_Tech_Hdr_Session;
		SWI_STRUCT_Tech_Hdr_An_Auth				_Tech_Hdr_An_Auth;
		SWI_STRUCT_Tech_Hdr_Drc_Val				_Tech_Hdr_Drc_Val;
		SWI_STRUCT_Tech_Hdr_Drc_Cover			_Tech_Hdr_Drc_Cover;
		SWI_STRUCT_Tech_Hdr_Rri					_Tech_Hdr_Rri;
		SWI_STRUCT_Tech_Hdr_Stats				_Tech_Hdr_Stats;
		SWI_STRUCT_Tech_Hdr_Su_Fwd_Stats		_Tech_Hdr_Su_Fwd_Stats;
		SWI_STRUCT_Tech_Hdr_Su_Fwd_Slot_Cnt		_Tech_Hdr_Su_Fwd_Slot_Cnt;
		SWI_STRUCT_Tech_Hdr_Su_Fwd_Slot_Cnt2	_Tech_Hdr_Su_Fwd_Slot_Cnt2;
		SWI_STRUCT_Tech_Hdr_Mu_Fwd_Stats		_Tech_Hdr_Mu_Fwd_Stats;
		SWI_STRUCT_Tech_Hdr_Personality			_Tech_Hdr_Personality;


			// OMA-DM
		SWI_STRUCT_OMADM_GET_CONFIG				_OMADM_Config;
		SWI_STRUCT_OMADM_SESSION_STATE			_OMADM_Session_State;
		SWI_STRUCT_OMADM_NI_ALERT				_OMADM_NI_Alert;

			// SMS
		SWI_STRUCT_SMS_Status					_SMS_Status;
		SWI_STRUCT_SMS_SendStatus				_SMS_SendStatus;

			// Firmware Update
		SWI_STRUCT_FU_Status					_FU_Status;
		SWI_STRUCT_NVUpdateFromFile				_NVUpdateFromFile;
		SWI_STRUCT_NVRAMStore					_NVRAMStore;

			// Radio power
		SWI_STRUCT_POWER						_Radio_Power;

			// WiMAX
		SWI_STRUCT_WIMAX_OPERATING_MODE			_WiMAX_Operating_Mode;

			// FOTA
		SWI_STRUCT_DM_DL_PROGRESS				_DM_DL_Progress;		// _FOTA_Progress
		SWI_STRUCT_DM_DL_ALERT					_DM_DL_Alert;
		SWI_STRUCT_DM_DL_INSTALL_STATUS			_DM_DL_InstallStatus;

			// Tech
		SWI_STRUCT_Tech_Packet_Call_Control_State	_Tech_Packet_Call_Control_State;

			// UMTS
		// Using the following for both CDMA and UMTS byte counts
		//SWI_STRUCT_CallByteCounter		_CallByteCounter;
		SWI_STRUCT_UMTS_SERVICE_ICON		_UMTS_ServiceIcon;
		SWI_STRUCT_UMTS_SIM_STATUS_EXP		_UMTS_SIM_STATUS;

			// USB Device Arrival/Removal
		SWI_STRUCT_USB_Device_Arrival_Status	_USB_Device_Arrival_Status;
		SWI_STRUCT_USB_Device_Removal_Status	_USB_Device_Removal_Status;
	};
} SwiNotifyVariant;

typedef void (*SWI_CALLBACK_EX)(SwiNotifyVariant *pNotify);

typedef struct SWI_STRUCT_TechFingerSingle
{
    SWI_U32									sizeStruct;     //size of this structure
	SWI_S32									iPilot;
	SWI_U32									nWalshCode[MAX_WalshCode];
	SWI_S32									iRssi;
} SWI_STRUCT_TechFingerSingle;

typedef struct SWI_STRUCT_TechFinger
{
    SWI_U32									sizeStruct;     //size of this structure
	SWI_U32									nCount;
	SWI_STRUCT_TechFingerSingle				FingerSet[MAX_FingerSet];
} SWI_STRUCT_TechFinger;

typedef struct SWI_STRUCT_TechActiveSetSingle
{
	SWI_U32								sizeStruct;     //size of this structure
	SWI_S32									iPilot;
	SWI_S32									iEcio;
} SWI_STRUCT_TechActiveSetSingle;

typedef struct SWI_STRUCT_TechActiveSet
{
	SWI_U32									sizeStruct;     //size of this structure
	SWI_U32									nCount;
	SWI_STRUCT_TechActiveSetSingle		ActiveSet[MAX_ActiveSet];
} SWI_STRUCT_TechActiveSet;

typedef struct SWI_STRUCT_MipEnabled
{
	SWI_U32	sizeStruct;     //size of this structure
	SWI_U16	nMipEnabled[MAX_ActiveSet];
} SWI_STRUCT_MipEnabled;

typedef struct SWI_STRUCT_Tech_Hdr_Mac_Index
{
	SWI_U32	sizeStruct;

	SWI_U8	mac_index_available;	// Flag for MAC index availability
	SWI_U8	mac_index;				// MAC index
} SWI_STRUCT_Tech_Hdr_Mac_Index;

typedef enum SWI_TYPE_LEDType
{
  SWI_LED_TYPE_UNDEFINED          = 0x00,
  SWI_LED_TYPE_POWER_AMBER        = 0x01,
  SWI_LED_TYPE_SIGNAL_AMBER       = 0x02,
  SWI_LED_TYPE_POWER_BLUE         = 0x03,
  SWI_LED_TYPE_SIGNAL_BLUE        = 0x04,
  SWI_LED_TYPE_GLOWTOP            = 0x05,
  SWI_LED_TYPE_RESVD1             = 0x06,
  SWI_LED_TYPE_RESVD2             = 0x07,
  SWI_LED_TYPE_RESVD3             = 0x08,
  SWI_LED_TYPE_RESVD4             = 0x09,
} SWI_TYPE_LEDType;
 
#define SWI_MAX_LEDS              10
 
typedef struct SWI_TYPE_LED_CFG_ENABLE
{
	SWI_U8	nType[SWI_MAX_LEDS];     // SWI_TYPE_LED_TYPE
	SWI_U8	bEnable[SWI_MAX_LEDS];   // 1 = enabled, 0 - disabled
} SWI_TYPE_LED_CFG_ENABLE;


// Enum for SwiGetTechPacketCallControlState
typedef enum
{
	CALL_STATE_NO_SERVICE = 0,           // No service or Idle
	CALL_STATE_CONNECTING = 1,           // Connecting
	CALL_STATE_AUTHENTICATING = 2,       // Authenticating
	CALL_STATE_CONNECTED_ACTIVE = 3,     // Connected Active
	CALL_STATE_CONNECTED_DORMANT = 4,    // Connected Dormant
	CALL_STATE_DISCONNECTING = 5,        // Disconnecting
} SWI_ENUM_Tech_Packet_Call_Control_State;

// Structures for SwiGetTech1xPilotSet() and SwiGetTechHdrPilotSet()
#define MAX_PILOT_INFO_SETS	40
typedef struct
{
	SWI_U16	pilotOffset;
	SWI_U16 pilotStrength;
} SWI_STRUCT_Pilot_Info;	// Ec/Io

typedef struct
{
	SWI_U16	channel;
	SWI_U16	numPilots;
	SWI_STRUCT_Pilot_Info pilotInfo[MAX_PILOT_INFO_SETS];
} SWI_STRUCT_Pilot_Set;

typedef enum
{
	PILOT_SET_ACTIVE = 0,         // Active Set
	PILOT_SET_NEIGHBOR = 1,       // Neighbor Set
	PILOT_SET_CANDIDATE = 2       // Candidate Set
} SWI_ENUM_Requested_Pilot_Set;

	
#ifdef __cplusplus
}
#endif

#endif	// __SWIMACSTRUCTS__
